#### libraries #####
library(psych)
library(lavaan)
library(semPlot)
library(dplyr)
library(lm.beta)
library(GPArotation)
library(Hmisc)

options(max.print=1000000)



#### set wd ####
setwd("C:/Users/joela/OneDrive/Values Project/1500 Combined Sample")

#Load data
A1miced <- read.csv("A1.5miced.csv")

table(A1miced$Sample)

#CFA Logic from Schwartz et al 2012:
## MLE (Maximum Likelihood Estimator) used
## 19 oblique value factors, each measured with 3 (in my case 10) marker items COMPLETED
## fixed the variance of latent factors to 1 (variance standardization method) COMPLETED
## allowed loadings to be estimated freely (variance standardization method) COMPLETED
## allowed NO covariances between uniquenesses 
## corrected for bias by including a common factor; 
## loadings of all items set to 1 on this common factor

## Evaluated covariance structure models with:
### chi-square
### CFI (values > .90 indicating reasonable fit)
### RMSEA (values < .06 indicating reasonable fit)
### SRMR (values < .08 indicating reasonable fit)

#increase memory maximum
memory.limit(30000)

gc()

# model 1a with common factor

m1.20fs <- '

commonf =~ 
  1*VCAM.V.sdt1 + 1*VCAM.V.sdt2 + 1*VCAM.V.sdt3 + 1*VCAM.V.sdt4 + 1*VCAM.V.sdt5
+ 1*VCAM.S.sdt1 + 1*VCAM.S.sdt2 + 1*VCAM.S.sdt3 + 1*VCAM.S.sdt4 + 1*VCAM.S.sdt5

+ 1*VCAM.V.sda1 + 1*VCAM.V.sda2 + 1*VCAM.V.sda3 + 1*VCAM.V.sda4 + 1*VCAM.V.sda5
+ 1*VCAM.S.sda1 + 1*VCAM.S.sda2 + 1*VCAM.S.sda3 + 1*VCAM.S.sda4 + 1*VCAM.S.sda5

+ 1*VCAM.V.stim1 + 1*VCAM.V.stim2 + 1*VCAM.V.stim3 + 1*VCAM.V.stim4 + 1*VCAM.V.stim5
+ 1*VCAM.S.stim1 + 1*VCAM.S.stim2 + 1*VCAM.S.stim3 + 1*VCAM.S.stim4 + 1*VCAM.S.stim5

+ 1*VCAM.V.hedo1 + 1*VCAM.V.hedo2 + 1*VCAM.V.hedo3 + 1*VCAM.V.hedo4 + 1*VCAM.V.hedo5
+ 1*VCAM.S.hedo1 + 1*VCAM.S.hedo2 + 1*VCAM.S.hedo3 + 1*VCAM.S.hedo4 + 1*VCAM.S.hedo5

+ 1*VCAM.V.achi1 + 1*VCAM.V.achi2 + 1*VCAM.V.achi3 + 1*VCAM.V.achi4 + 1*VCAM.V.achi5
+ 1*VCAM.S.achi1 + 1*VCAM.S.achi2 + 1*VCAM.S.achi3 + 1*VCAM.S.achi4 + 1*VCAM.S.achi5

+ 1*VCAM.V.powd1 + 1*VCAM.V.powd2 + 1*VCAM.V.powd3 + 1*VCAM.V.powd4 + 1*VCAM.V.powd5
+ 1*VCAM.S.powd1 + 1*VCAM.S.powd2 + 1*VCAM.S.powd3 + 1*VCAM.S.powd4 + 1*VCAM.S.powd5

+ 1*VCAM.V.powr1 + 1*VCAM.V.powr2 + 1*VCAM.V.powr3 + 1*VCAM.V.powr4 + 1*VCAM.V.powr5
+ 1*VCAM.S.powr1 + 1*VCAM.S.powr2 + 1*VCAM.S.powr3 + 1*VCAM.S.powr4 + 1*VCAM.S.powr5

+ 1*VCAM.V.face1 + 1*VCAM.V.face2 + 1*VCAM.V.face3 + 1*VCAM.V.face4 + 1*VCAM.V.face5
+ 1*VCAM.S.face1 + 1*VCAM.S.face2 + 1*VCAM.S.face3 + 1*VCAM.S.face4 + 1*VCAM.S.face5

+ 1*VCAM.V.secp1 + 1*VCAM.V.secp2 + 1*VCAM.V.secp3 + 1*VCAM.V.secp4 + 1*VCAM.V.secp5
+ 1*VCAM.S.secp1 + 1*VCAM.S.secp2 + 1*VCAM.S.secp3 + 1*VCAM.S.secp4 + 1*VCAM.S.secp5

+ 1*VCAM.V.secs1 + 1*VCAM.V.secs2 + 1*VCAM.V.secs3 + 1*VCAM.V.secs4 + 1*VCAM.V.secs5
+ 1*VCAM.S.secs1 + 1*VCAM.S.secs2 + 1*VCAM.S.secs3 + 1*VCAM.S.secs4 + 1*VCAM.S.secs5

+ 1*VCAM.V.trad1 + 1*VCAM.V.trad2 + 1*VCAM.V.trad3 + 1*VCAM.V.trad4 + 1*VCAM.V.trad5
+ 1*VCAM.S.trad1 + 1*VCAM.S.trad2 + 1*VCAM.S.trad3 + 1*VCAM.S.trad4 + 1*VCAM.S.trad5

+ 1*VCAM.V.conr1 + 1*VCAM.V.conr2 + 1*VCAM.V.conr3 + 1*VCAM.V.conr4 + 1*VCAM.V.conr5
+ 1*VCAM.S.conr1 + 1*VCAM.S.conr2 + 1*VCAM.S.conr3 + 1*VCAM.S.conr4 + 1*VCAM.S.conr5

+ 1*VCAM.V.coni1 + 1*VCAM.V.coni2 + 1*VCAM.V.coni3 + 1*VCAM.V.coni4 + 1*VCAM.V.coni5
+ 1*VCAM.S.coni1 + 1*VCAM.S.coni2 + 1*VCAM.S.coni3 + 1*VCAM.S.coni4 + 1*VCAM.S.coni5

+ 1*VCAM.V.humi1 + 1*VCAM.V.humi2 + 1*VCAM.V.humi3 + 1*VCAM.V.humi4 + 1*VCAM.V.humi5
+ 1*VCAM.S.humi1 + 1*VCAM.S.humi2 + 1*VCAM.S.humi3 + 1*VCAM.S.humi4 + 1*VCAM.S.humi5

+ 1*VCAM.V.benc1 + 1*VCAM.V.benc2 + 1*VCAM.V.benc3 + 1*VCAM.V.benc4 + 1*VCAM.V.benc5
+ 1*VCAM.S.benc1 + 1*VCAM.S.benc2 + 1*VCAM.S.benc3 + 1*VCAM.S.benc4 + 1*VCAM.S.benc5

+ 1*VCAM.V.bend1 + 1*VCAM.V.bend2 + 1*VCAM.V.bend3 + 1*VCAM.V.bend4 + 1*VCAM.V.bend5
+ 1*VCAM.S.bend1 + 1*VCAM.S.bend2 + 1*VCAM.S.bend3 + 1*VCAM.S.bend4 + 1*VCAM.S.bend5

+ 1*VCAM.V.unic1 + 1*VCAM.V.unic2 + 1*VCAM.V.unic3 + 1*VCAM.V.unic4 + 1*VCAM.V.unic5
+ 1*VCAM.S.unic1 + 1*VCAM.S.unic2 + 1*VCAM.S.unic3 + 1*VCAM.S.unic4 + 1*VCAM.S.unic5

+ 1*VCAM.V.unin1 + 1*VCAM.V.unin2 + 1*VCAM.V.unin3 + 1*VCAM.V.unin4 + 1*VCAM.V.unin5
+ 1*VCAM.S.unin1 + 1*VCAM.S.unin2 + 1*VCAM.S.unin3 + 1*VCAM.S.unin4 + 1*VCAM.S.unin5

+ 1*VCAM.V.unit1 + 1*VCAM.V.unit2 + 1*VCAM.V.unit3 + 1*VCAM.V.unit4 + 1*VCAM.V.unit5
+ 1*VCAM.S.unit1 + 1*VCAM.S.unit2 + 1*VCAM.S.unit3 + 1*VCAM.S.unit4 + 1*VCAM.S.unit5


sdt =~ VCAM.V.sdt1 + VCAM.V.sdt2 + VCAM.V.sdt3 + VCAM.V.sdt4 + VCAM.V.sdt5
+ VCAM.S.sdt1 + VCAM.S.sdt2 + VCAM.S.sdt3 + VCAM.S.sdt4 + VCAM.S.sdt5

sda =~ VCAM.V.sda1 + VCAM.V.sda2 + VCAM.V.sda3 + VCAM.V.sda4 + VCAM.V.sda5
+ VCAM.S.sda1 + VCAM.S.sda2 + VCAM.S.sda3 + VCAM.S.sda4 + VCAM.S.sda5

stim =~ VCAM.V.stim1 + VCAM.V.stim2 + VCAM.V.stim3 + VCAM.V.stim4 + VCAM.V.stim5
+ VCAM.S.stim1 + VCAM.S.stim2 + VCAM.S.stim3 + VCAM.S.stim4 + VCAM.S.stim5

hedo =~ VCAM.V.hedo1 + VCAM.V.hedo2 + VCAM.V.hedo3 + VCAM.V.hedo4 + VCAM.V.hedo5
+ VCAM.S.hedo1 + VCAM.S.hedo2 + VCAM.S.hedo3 + VCAM.S.hedo4 + VCAM.S.hedo5

achi =~ VCAM.V.achi1 + VCAM.V.achi2 + VCAM.V.achi3 + VCAM.V.achi4 + VCAM.V.achi5
+ VCAM.S.achi1 + VCAM.S.achi2 + VCAM.S.achi3 + VCAM.S.achi4 + VCAM.S.achi5

powd =~ VCAM.V.powd1 + VCAM.V.powd2 + VCAM.V.powd3 + VCAM.V.powd4 + VCAM.V.powd5
+ VCAM.S.powd1 + VCAM.S.powd2 + VCAM.S.powd3 + VCAM.S.powd4 + VCAM.S.powd5

powr =~ VCAM.V.powr1 + VCAM.V.powr2 + VCAM.V.powr3 + VCAM.V.powr4 + VCAM.V.powr5
+ VCAM.S.powr1 + VCAM.S.powr2 + VCAM.S.powr3 + VCAM.S.powr4 + VCAM.S.powr5

face =~ VCAM.V.face1 + VCAM.V.face2 + VCAM.V.face3 + VCAM.V.face4 + VCAM.V.face5
+ VCAM.S.face1 + VCAM.S.face2 + VCAM.S.face3 + VCAM.S.face4 + VCAM.S.face5

secp =~ VCAM.V.secp1 + VCAM.V.secp2 + VCAM.V.secp3 + VCAM.V.secp4 + VCAM.V.secp5
+ VCAM.S.secp1 + VCAM.S.secp2 + VCAM.S.secp3 + VCAM.S.secp4 + VCAM.S.secp5

secs =~ VCAM.V.secs1 + VCAM.V.secs2 + VCAM.V.secs3 + VCAM.V.secs4 + VCAM.V.secs5
+ VCAM.S.secs1 + VCAM.S.secs2 + VCAM.S.secs3 + VCAM.S.secs4 + VCAM.S.secs5

trad =~ VCAM.V.trad1 + VCAM.V.trad2 + VCAM.V.trad3 + VCAM.V.trad4 + VCAM.V.trad5
+ VCAM.S.trad1 + VCAM.S.trad2 + VCAM.S.trad3 + VCAM.S.trad4 + VCAM.S.trad5

conr =~ VCAM.V.conr1 + VCAM.V.conr2 + VCAM.V.conr3 + VCAM.V.conr4 + VCAM.V.conr5
+ VCAM.S.conr1 + VCAM.S.conr2 + VCAM.S.conr3 + VCAM.S.conr4 + VCAM.S.conr5

coni =~ VCAM.V.coni1 + VCAM.V.coni2 + VCAM.V.coni3 + VCAM.V.coni4 + VCAM.V.coni5
+ VCAM.S.coni1 + VCAM.S.coni2 + VCAM.S.coni3 + VCAM.S.coni4 + VCAM.S.coni5

humi =~ VCAM.V.humi1 + VCAM.V.humi2 + VCAM.V.humi3 + VCAM.V.humi4 + VCAM.V.humi5
+ VCAM.S.humi1 + VCAM.S.humi2 + VCAM.S.humi3 + VCAM.S.humi4 + VCAM.S.humi5

benc =~ VCAM.V.benc1 + VCAM.V.benc2 + VCAM.V.benc3 + VCAM.V.benc4 + VCAM.V.benc5
+ VCAM.S.benc1 + VCAM.S.benc2 + VCAM.S.benc3 + VCAM.S.benc4 + VCAM.S.benc5

bend =~ VCAM.V.bend1 + VCAM.V.bend2 + VCAM.V.bend3 + VCAM.V.bend4 + VCAM.V.bend5
+ VCAM.S.bend1 + VCAM.S.bend2 + VCAM.S.bend3 + VCAM.S.bend4 + VCAM.S.bend5

unic =~ VCAM.V.unic1 + VCAM.V.unic2 + VCAM.V.unic3 + VCAM.V.unic4 + VCAM.V.unic5
+ VCAM.S.unic1 + VCAM.S.unic2 + VCAM.S.unic3 + VCAM.S.unic4 + VCAM.S.unic5

unin =~ VCAM.V.unin1 + VCAM.V.unin2 + VCAM.V.unin3 + VCAM.V.unin4 + VCAM.V.unin5
+ VCAM.S.unin1 + VCAM.S.unin2 + VCAM.S.unin3 + VCAM.S.unin4 + VCAM.S.unin5

unit =~ VCAM.V.unit1 + VCAM.V.unit2 + VCAM.V.unit3 + VCAM.V.unit4 + VCAM.V.unit5
+ VCAM.S.unit1 + VCAM.S.unit2 + VCAM.S.unit3 + VCAM.S.unit4 + VCAM.S.unit5'

twentyfac190items <- cfa(m1.20fs, data=A1miced, std.lv=TRUE)
summary(twentyfac190items, fit.measures=TRUE, standardized=TRUE)

sink(file='cfa.1cfs.output.txt')
summary(twentyfac190items, fit.measures=TRUE, standardized=TRUE)
sink()

#model 1b with no common factor

m1b.19fs <- '

sdt =~ VCAM.V.sdt1 + VCAM.V.sdt2 + VCAM.V.sdt3 + VCAM.V.sdt4 + VCAM.V.sdt5
+ VCAM.S.sdt1 + VCAM.S.sdt2 + VCAM.S.sdt3 + VCAM.S.sdt4 + VCAM.S.sdt5

sda =~ VCAM.V.sda1 + VCAM.V.sda2 + VCAM.V.sda3 + VCAM.V.sda4 + VCAM.V.sda5
+ VCAM.S.sda1 + VCAM.S.sda2 + VCAM.S.sda3 + VCAM.S.sda4 + VCAM.S.sda5

stim =~ VCAM.V.stim1 + VCAM.V.stim2 + VCAM.V.stim3 + VCAM.V.stim4 + VCAM.V.stim5
+ VCAM.S.stim1 + VCAM.S.stim2 + VCAM.S.stim3 + VCAM.S.stim4 + VCAM.S.stim5

hedo =~ VCAM.V.hedo1 + VCAM.V.hedo2 + VCAM.V.hedo3 + VCAM.V.hedo4 + VCAM.V.hedo5
+ VCAM.S.hedo1 + VCAM.S.hedo2 + VCAM.S.hedo3 + VCAM.S.hedo4 + VCAM.S.hedo5

achi =~ VCAM.V.achi1 + VCAM.V.achi2 + VCAM.V.achi3 + VCAM.V.achi4 + VCAM.V.achi5
+ VCAM.S.achi1 + VCAM.S.achi2 + VCAM.S.achi3 + VCAM.S.achi4 + VCAM.S.achi5

powd =~ VCAM.V.powd1 + VCAM.V.powd2 + VCAM.V.powd3 + VCAM.V.powd4 + VCAM.V.powd5
+ VCAM.S.powd1 + VCAM.S.powd2 + VCAM.S.powd3 + VCAM.S.powd4 + VCAM.S.powd5

powr =~ VCAM.V.powr1 + VCAM.V.powr2 + VCAM.V.powr3 + VCAM.V.powr4 + VCAM.V.powr5
+ VCAM.S.powr1 + VCAM.S.powr2 + VCAM.S.powr3 + VCAM.S.powr4 + VCAM.S.powr5

face =~ VCAM.V.face1 + VCAM.V.face2 + VCAM.V.face3 + VCAM.V.face4 + VCAM.V.face5
+ VCAM.S.face1 + VCAM.S.face2 + VCAM.S.face3 + VCAM.S.face4 + VCAM.S.face5

secp =~ VCAM.V.secp1 + VCAM.V.secp2 + VCAM.V.secp3 + VCAM.V.secp4 + VCAM.V.secp5
+ VCAM.S.secp1 + VCAM.S.secp2 + VCAM.S.secp3 + VCAM.S.secp4 + VCAM.S.secp5

secs =~ VCAM.V.secs1 + VCAM.V.secs2 + VCAM.V.secs3 + VCAM.V.secs4 + VCAM.V.secs5
+ VCAM.S.secs1 + VCAM.S.secs2 + VCAM.S.secs3 + VCAM.S.secs4 + VCAM.S.secs5

trad =~ VCAM.V.trad1 + VCAM.V.trad2 + VCAM.V.trad3 + VCAM.V.trad4 + VCAM.V.trad5
+ VCAM.S.trad1 + VCAM.S.trad2 + VCAM.S.trad3 + VCAM.S.trad4 + VCAM.S.trad5

conr =~ VCAM.V.conr1 + VCAM.V.conr2 + VCAM.V.conr3 + VCAM.V.conr4 + VCAM.V.conr5
+ VCAM.S.conr1 + VCAM.S.conr2 + VCAM.S.conr3 + VCAM.S.conr4 + VCAM.S.conr5

coni =~ VCAM.V.coni1 + VCAM.V.coni2 + VCAM.V.coni3 + VCAM.V.coni4 + VCAM.V.coni5
+ VCAM.S.coni1 + VCAM.S.coni2 + VCAM.S.coni3 + VCAM.S.coni4 + VCAM.S.coni5

humi =~ VCAM.V.humi1 + VCAM.V.humi2 + VCAM.V.humi3 + VCAM.V.humi4 + VCAM.V.humi5
+ VCAM.S.humi1 + VCAM.S.humi2 + VCAM.S.humi3 + VCAM.S.humi4 + VCAM.S.humi5

benc =~ VCAM.V.benc1 + VCAM.V.benc2 + VCAM.V.benc3 + VCAM.V.benc4 + VCAM.V.benc5
+ VCAM.S.benc1 + VCAM.S.benc2 + VCAM.S.benc3 + VCAM.S.benc4 + VCAM.S.benc5

bend =~ VCAM.V.bend1 + VCAM.V.bend2 + VCAM.V.bend3 + VCAM.V.bend4 + VCAM.V.bend5
+ VCAM.S.bend1 + VCAM.S.bend2 + VCAM.S.bend3 + VCAM.S.bend4 + VCAM.S.bend5

unic =~ VCAM.V.unic1 + VCAM.V.unic2 + VCAM.V.unic3 + VCAM.V.unic4 + VCAM.V.unic5
+ VCAM.S.unic1 + VCAM.S.unic2 + VCAM.S.unic3 + VCAM.S.unic4 + VCAM.S.unic5

unin =~ VCAM.V.unin1 + VCAM.V.unin2 + VCAM.V.unin3 + VCAM.V.unin4 + VCAM.V.unin5
+ VCAM.S.unin1 + VCAM.S.unin2 + VCAM.S.unin3 + VCAM.S.unin4 + VCAM.S.unin5

unit =~ VCAM.V.unit1 + VCAM.V.unit2 + VCAM.V.unit3 + VCAM.V.unit4 + VCAM.V.unit5
+ VCAM.S.unit1 + VCAM.S.unit2 + VCAM.S.unit3 + VCAM.S.unit4 + VCAM.S.unit5'

model1b <- cfa(m1b.19fs, data=A1miced, std.lv=TRUE)
summary(model1b, fit.measures=TRUE, standardized=TRUE)


sink(file='cfa.0cfs.output.txt')
summary(model1b, fit.measures=TRUE, standardized=TRUE)
sink()



#2a extra common factors

m2.3cfs <- '

commonf =~ 
  1*VCAM.V.sdt1 + 1*VCAM.V.sdt2 + 1*VCAM.V.sdt3 + 1*VCAM.V.sdt4 + 1*VCAM.V.sdt5
+ 1*VCAM.S.sdt1 + 1*VCAM.S.sdt2 + 1*VCAM.S.sdt3 + 1*VCAM.S.sdt4 + 1*VCAM.S.sdt5

+ 1*VCAM.V.sda1 + 1*VCAM.V.sda2 + 1*VCAM.V.sda3 + 1*VCAM.V.sda4 + 1*VCAM.V.sda5
+ 1*VCAM.S.sda1 + 1*VCAM.S.sda2 + 1*VCAM.S.sda3 + 1*VCAM.S.sda4 + 1*VCAM.S.sda5

+ 1*VCAM.V.stim1 + 1*VCAM.V.stim2 + 1*VCAM.V.stim3 + 1*VCAM.V.stim4 + 1*VCAM.V.stim5
+ 1*VCAM.S.stim1 + 1*VCAM.S.stim2 + 1*VCAM.S.stim3 + 1*VCAM.S.stim4 + 1*VCAM.S.stim5

+ 1*VCAM.V.hedo1 + 1*VCAM.V.hedo2 + 1*VCAM.V.hedo3 + 1*VCAM.V.hedo4 + 1*VCAM.V.hedo5
+ 1*VCAM.S.hedo1 + 1*VCAM.S.hedo2 + 1*VCAM.S.hedo3 + 1*VCAM.S.hedo4 + 1*VCAM.S.hedo5

+ 1*VCAM.V.achi1 + 1*VCAM.V.achi2 + 1*VCAM.V.achi3 + 1*VCAM.V.achi4 + 1*VCAM.V.achi5
+ 1*VCAM.S.achi1 + 1*VCAM.S.achi2 + 1*VCAM.S.achi3 + 1*VCAM.S.achi4 + 1*VCAM.S.achi5

+ 1*VCAM.V.powd1 + 1*VCAM.V.powd2 + 1*VCAM.V.powd3 + 1*VCAM.V.powd4 + 1*VCAM.V.powd5
+ 1*VCAM.S.powd1 + 1*VCAM.S.powd2 + 1*VCAM.S.powd3 + 1*VCAM.S.powd4 + 1*VCAM.S.powd5

+ 1*VCAM.V.powr1 + 1*VCAM.V.powr2 + 1*VCAM.V.powr3 + 1*VCAM.V.powr4 + 1*VCAM.V.powr5
+ 1*VCAM.S.powr1 + 1*VCAM.S.powr2 + 1*VCAM.S.powr3 + 1*VCAM.S.powr4 + 1*VCAM.S.powr5

+ 1*VCAM.V.face1 + 1*VCAM.V.face2 + 1*VCAM.V.face3 + 1*VCAM.V.face4 + 1*VCAM.V.face5
+ 1*VCAM.S.face1 + 1*VCAM.S.face2 + 1*VCAM.S.face3 + 1*VCAM.S.face4 + 1*VCAM.S.face5

+ 1*VCAM.V.secp1 + 1*VCAM.V.secp2 + 1*VCAM.V.secp3 + 1*VCAM.V.secp4 + 1*VCAM.V.secp5
+ 1*VCAM.S.secp1 + 1*VCAM.S.secp2 + 1*VCAM.S.secp3 + 1*VCAM.S.secp4 + 1*VCAM.S.secp5

+ 1*VCAM.V.secs1 + 1*VCAM.V.secs2 + 1*VCAM.V.secs3 + 1*VCAM.V.secs4 + 1*VCAM.V.secs5
+ 1*VCAM.S.secs1 + 1*VCAM.S.secs2 + 1*VCAM.S.secs3 + 1*VCAM.S.secs4 + 1*VCAM.S.secs5

+ 1*VCAM.V.trad1 + 1*VCAM.V.trad2 + 1*VCAM.V.trad3 + 1*VCAM.V.trad4 + 1*VCAM.V.trad5
+ 1*VCAM.S.trad1 + 1*VCAM.S.trad2 + 1*VCAM.S.trad3 + 1*VCAM.S.trad4 + 1*VCAM.S.trad5

+ 1*VCAM.V.conr1 + 1*VCAM.V.conr2 + 1*VCAM.V.conr3 + 1*VCAM.V.conr4 + 1*VCAM.V.conr5
+ 1*VCAM.S.conr1 + 1*VCAM.S.conr2 + 1*VCAM.S.conr3 + 1*VCAM.S.conr4 + 1*VCAM.S.conr5

+ 1*VCAM.V.coni1 + 1*VCAM.V.coni2 + 1*VCAM.V.coni3 + 1*VCAM.V.coni4 + 1*VCAM.V.coni5
+ 1*VCAM.S.coni1 + 1*VCAM.S.coni2 + 1*VCAM.S.coni3 + 1*VCAM.S.coni4 + 1*VCAM.S.coni5

+ 1*VCAM.V.humi1 + 1*VCAM.V.humi2 + 1*VCAM.V.humi3 + 1*VCAM.V.humi4 + 1*VCAM.V.humi5
+ 1*VCAM.S.humi1 + 1*VCAM.S.humi2 + 1*VCAM.S.humi3 + 1*VCAM.S.humi4 + 1*VCAM.S.humi5

+ 1*VCAM.V.benc1 + 1*VCAM.V.benc2 + 1*VCAM.V.benc3 + 1*VCAM.V.benc4 + 1*VCAM.V.benc5
+ 1*VCAM.S.benc1 + 1*VCAM.S.benc2 + 1*VCAM.S.benc3 + 1*VCAM.S.benc4 + 1*VCAM.S.benc5

+ 1*VCAM.V.bend1 + 1*VCAM.V.bend2 + 1*VCAM.V.bend3 + 1*VCAM.V.bend4 + 1*VCAM.V.bend5
+ 1*VCAM.S.bend1 + 1*VCAM.S.bend2 + 1*VCAM.S.bend3 + 1*VCAM.S.bend4 + 1*VCAM.S.bend5

+ 1*VCAM.V.unic1 + 1*VCAM.V.unic2 + 1*VCAM.V.unic3 + 1*VCAM.V.unic4 + 1*VCAM.V.unic5
+ 1*VCAM.S.unic1 + 1*VCAM.S.unic2 + 1*VCAM.S.unic3 + 1*VCAM.S.unic4 + 1*VCAM.S.unic5

+ 1*VCAM.V.unin1 + 1*VCAM.V.unin2 + 1*VCAM.V.unin3 + 1*VCAM.V.unin4 + 1*VCAM.V.unin5
+ 1*VCAM.S.unin1 + 1*VCAM.S.unin2 + 1*VCAM.S.unin3 + 1*VCAM.S.unin4 + 1*VCAM.S.unin5

+ 1*VCAM.V.unit1 + 1*VCAM.V.unit2 + 1*VCAM.V.unit3 + 1*VCAM.V.unit4 + 1*VCAM.V.unit5
+ 1*VCAM.S.unit1 + 1*VCAM.S.unit2 + 1*VCAM.S.unit3 + 1*VCAM.S.unit4 + 1*VCAM.S.unit5

violf =~ 
  1*VCAM.V.sdt1 + 1*VCAM.V.sdt2 + 1*VCAM.V.sdt3 + 1*VCAM.V.sdt4 + 1*VCAM.V.sdt5

+ 1*VCAM.V.sda1 + 1*VCAM.V.sda2 + 1*VCAM.V.sda3 + 1*VCAM.V.sda4 + 1*VCAM.V.sda5

+ 1*VCAM.V.stim1 + 1*VCAM.V.stim2 + 1*VCAM.V.stim3 + 1*VCAM.V.stim4 + 1*VCAM.V.stim5

+ 1*VCAM.V.hedo1 + 1*VCAM.V.hedo2 + 1*VCAM.V.hedo3 + 1*VCAM.V.hedo4 + 1*VCAM.V.hedo5

+ 1*VCAM.V.achi1 + 1*VCAM.V.achi2 + 1*VCAM.V.achi3 + 1*VCAM.V.achi4 + 1*VCAM.V.achi5

+ 1*VCAM.V.powd1 + 1*VCAM.V.powd2 + 1*VCAM.V.powd3 + 1*VCAM.V.powd4 + 1*VCAM.V.powd5

+ 1*VCAM.V.powr1 + 1*VCAM.V.powr2 + 1*VCAM.V.powr3 + 1*VCAM.V.powr4 + 1*VCAM.V.powr5

+ 1*VCAM.V.face1 + 1*VCAM.V.face2 + 1*VCAM.V.face3 + 1*VCAM.V.face4 + 1*VCAM.V.face5

+ 1*VCAM.V.secp1 + 1*VCAM.V.secp2 + 1*VCAM.V.secp3 + 1*VCAM.V.secp4 + 1*VCAM.V.secp5

+ 1*VCAM.V.secs1 + 1*VCAM.V.secs2 + 1*VCAM.V.secs3 + 1*VCAM.V.secs4 + 1*VCAM.V.secs5

+ 1*VCAM.V.trad1 + 1*VCAM.V.trad2 + 1*VCAM.V.trad3 + 1*VCAM.V.trad4 + 1*VCAM.V.trad5

+ 1*VCAM.V.conr1 + 1*VCAM.V.conr2 + 1*VCAM.V.conr3 + 1*VCAM.V.conr4 + 1*VCAM.V.conr5

+ 1*VCAM.V.coni1 + 1*VCAM.V.coni2 + 1*VCAM.V.coni3 + 1*VCAM.V.coni4 + 1*VCAM.V.coni5

+ 1*VCAM.V.humi1 + 1*VCAM.V.humi2 + 1*VCAM.V.humi3 + 1*VCAM.V.humi4 + 1*VCAM.V.humi5

+ 1*VCAM.V.benc1 + 1*VCAM.V.benc2 + 1*VCAM.V.benc3 + 1*VCAM.V.benc4 + 1*VCAM.V.benc5

+ 1*VCAM.V.bend1 + 1*VCAM.V.bend2 + 1*VCAM.V.bend3 + 1*VCAM.V.bend4 + 1*VCAM.V.bend5

+ 1*VCAM.V.unic1 + 1*VCAM.V.unic2 + 1*VCAM.V.unic3 + 1*VCAM.V.unic4 + 1*VCAM.V.unic5

+ 1*VCAM.V.unin1 + 1*VCAM.V.unin2 + 1*VCAM.V.unin3 + 1*VCAM.V.unin4 + 1*VCAM.V.unin5

+ 1*VCAM.V.unit1 + 1*VCAM.V.unit2 + 1*VCAM.V.unit3 + 1*VCAM.V.unit4 + 1*VCAM.V.unit5


satisf =~ 1*VCAM.S.sdt1 + 1*VCAM.S.sdt2 + 1*VCAM.S.sdt3 + 1*VCAM.S.sdt4 + 1*VCAM.S.sdt5

+ 1*VCAM.S.sda1 + 1*VCAM.S.sda2 + 1*VCAM.S.sda3 + 1*VCAM.S.sda4 + 1*VCAM.S.sda5

+ 1*VCAM.S.stim1 + 1*VCAM.S.stim2 + 1*VCAM.S.stim3 + 1*VCAM.S.stim4 + 1*VCAM.S.stim5

+ 1*VCAM.S.hedo1 + 1*VCAM.S.hedo2 + 1*VCAM.S.hedo3 + 1*VCAM.S.hedo4 + 1*VCAM.S.hedo5

+ 1*VCAM.S.achi1 + 1*VCAM.S.achi2 + 1*VCAM.S.achi3 + 1*VCAM.S.achi4 + 1*VCAM.S.achi5

+ 1*VCAM.S.powd1 + 1*VCAM.S.powd2 + 1*VCAM.S.powd3 + 1*VCAM.S.powd4 + 1*VCAM.S.powd5

+ 1*VCAM.S.powr1 + 1*VCAM.S.powr2 + 1*VCAM.S.powr3 + 1*VCAM.S.powr4 + 1*VCAM.S.powr5

+ 1*VCAM.S.face1 + 1*VCAM.S.face2 + 1*VCAM.S.face3 + 1*VCAM.S.face4 + 1*VCAM.S.face5

+ 1*VCAM.S.secp1 + 1*VCAM.S.secp2 + 1*VCAM.S.secp3 + 1*VCAM.S.secp4 + 1*VCAM.S.secp5

+ 1*VCAM.S.secs1 + 1*VCAM.S.secs2 + 1*VCAM.S.secs3 + 1*VCAM.S.secs4 + 1*VCAM.S.secs5

+ 1*VCAM.S.trad1 + 1*VCAM.S.trad2 + 1*VCAM.S.trad3 + 1*VCAM.S.trad4 + 1*VCAM.S.trad5

+ 1*VCAM.S.conr1 + 1*VCAM.S.conr2 + 1*VCAM.S.conr3 + 1*VCAM.S.conr4 + 1*VCAM.S.conr5

+ 1*VCAM.S.coni1 + 1*VCAM.S.coni2 + 1*VCAM.S.coni3 + 1*VCAM.S.coni4 + 1*VCAM.S.coni5

+ 1*VCAM.S.humi1 + 1*VCAM.S.humi2 + 1*VCAM.S.humi3 + 1*VCAM.S.humi4 + 1*VCAM.S.humi5

+ 1*VCAM.S.benc1 + 1*VCAM.S.benc2 + 1*VCAM.S.benc3 + 1*VCAM.S.benc4 + 1*VCAM.S.benc5

+ 1*VCAM.S.bend1 + 1*VCAM.S.bend2 + 1*VCAM.S.bend3 + 1*VCAM.S.bend4 + 1*VCAM.S.bend5

+ 1*VCAM.S.unic1 + 1*VCAM.S.unic2 + 1*VCAM.S.unic3 + 1*VCAM.S.unic4 + 1*VCAM.S.unic5

+ 1*VCAM.S.unin1 + 1*VCAM.S.unin2 + 1*VCAM.S.unin3 + 1*VCAM.S.unin4 + 1*VCAM.S.unin5

+ 1*VCAM.S.unit1 + 1*VCAM.S.unit2 + 1*VCAM.S.unit3 + 1*VCAM.S.unit4 + 1*VCAM.S.unit5

sdt =~ VCAM.V.sdt1 + VCAM.V.sdt2 + VCAM.V.sdt3 + VCAM.V.sdt4 + VCAM.V.sdt5
+ VCAM.S.sdt1 + VCAM.S.sdt2 + VCAM.S.sdt3 + VCAM.S.sdt4 + VCAM.S.sdt5

sda =~ VCAM.V.sda1 + VCAM.V.sda2 + VCAM.V.sda3 + VCAM.V.sda4 + VCAM.V.sda5
+ VCAM.S.sda1 + VCAM.S.sda2 + VCAM.S.sda3 + VCAM.S.sda4 + VCAM.S.sda5

stim =~ VCAM.V.stim1 + VCAM.V.stim2 + VCAM.V.stim3 + VCAM.V.stim4 + VCAM.V.stim5
+ VCAM.S.stim1 + VCAM.S.stim2 + VCAM.S.stim3 + VCAM.S.stim4 + VCAM.S.stim5

hedo =~ VCAM.V.hedo1 + VCAM.V.hedo2 + VCAM.V.hedo3 + VCAM.V.hedo4 + VCAM.V.hedo5
+ VCAM.S.hedo1 + VCAM.S.hedo2 + VCAM.S.hedo3 + VCAM.S.hedo4 + VCAM.S.hedo5

achi =~ VCAM.V.achi1 + VCAM.V.achi2 + VCAM.V.achi3 + VCAM.V.achi4 + VCAM.V.achi5
+ VCAM.S.achi1 + VCAM.S.achi2 + VCAM.S.achi3 + VCAM.S.achi4 + VCAM.S.achi5

powd =~ VCAM.V.powd1 + VCAM.V.powd2 + VCAM.V.powd3 + VCAM.V.powd4 + VCAM.V.powd5
+ VCAM.S.powd1 + VCAM.S.powd2 + VCAM.S.powd3 + VCAM.S.powd4 + VCAM.S.powd5

powr =~ VCAM.V.powr1 + VCAM.V.powr2 + VCAM.V.powr3 + VCAM.V.powr4 + VCAM.V.powr5
+ VCAM.S.powr1 + VCAM.S.powr2 + VCAM.S.powr3 + VCAM.S.powr4 + VCAM.S.powr5

face =~ VCAM.V.face1 + VCAM.V.face2 + VCAM.V.face3 + VCAM.V.face4 + VCAM.V.face5
+ VCAM.S.face1 + VCAM.S.face2 + VCAM.S.face3 + VCAM.S.face4 + VCAM.S.face5

secp =~ VCAM.V.secp1 + VCAM.V.secp2 + VCAM.V.secp3 + VCAM.V.secp4 + VCAM.V.secp5
+ VCAM.S.secp1 + VCAM.S.secp2 + VCAM.S.secp3 + VCAM.S.secp4 + VCAM.S.secp5

secs =~ VCAM.V.secs1 + VCAM.V.secs2 + VCAM.V.secs3 + VCAM.V.secs4 + VCAM.V.secs5
+ VCAM.S.secs1 + VCAM.S.secs2 + VCAM.S.secs3 + VCAM.S.secs4 + VCAM.S.secs5

trad =~ VCAM.V.trad1 + VCAM.V.trad2 + VCAM.V.trad3 + VCAM.V.trad4 + VCAM.V.trad5
+ VCAM.S.trad1 + VCAM.S.trad2 + VCAM.S.trad3 + VCAM.S.trad4 + VCAM.S.trad5

conr =~ VCAM.V.conr1 + VCAM.V.conr2 + VCAM.V.conr3 + VCAM.V.conr4 + VCAM.V.conr5
+ VCAM.S.conr1 + VCAM.S.conr2 + VCAM.S.conr3 + VCAM.S.conr4 + VCAM.S.conr5

coni =~ VCAM.V.coni1 + VCAM.V.coni2 + VCAM.V.coni3 + VCAM.V.coni4 + VCAM.V.coni5
+ VCAM.S.coni1 + VCAM.S.coni2 + VCAM.S.coni3 + VCAM.S.coni4 + VCAM.S.coni5

humi =~ VCAM.V.humi1 + VCAM.V.humi2 + VCAM.V.humi3 + VCAM.V.humi4 + VCAM.V.humi5
+ VCAM.S.humi1 + VCAM.S.humi2 + VCAM.S.humi3 + VCAM.S.humi4 + VCAM.S.humi5

benc =~ VCAM.V.benc1 + VCAM.V.benc2 + VCAM.V.benc3 + VCAM.V.benc4 + VCAM.V.benc5
+ VCAM.S.benc1 + VCAM.S.benc2 + VCAM.S.benc3 + VCAM.S.benc4 + VCAM.S.benc5

bend =~ VCAM.V.bend1 + VCAM.V.bend2 + VCAM.V.bend3 + VCAM.V.bend4 + VCAM.V.bend5
+ VCAM.S.bend1 + VCAM.S.bend2 + VCAM.S.bend3 + VCAM.S.bend4 + VCAM.S.bend5

unic =~ VCAM.V.unic1 + VCAM.V.unic2 + VCAM.V.unic3 + VCAM.V.unic4 + VCAM.V.unic5
+ VCAM.S.unic1 + VCAM.S.unic2 + VCAM.S.unic3 + VCAM.S.unic4 + VCAM.S.unic5

unin =~ VCAM.V.unin1 + VCAM.V.unin2 + VCAM.V.unin3 + VCAM.V.unin4 + VCAM.V.unin5
+ VCAM.S.unin1 + VCAM.S.unin2 + VCAM.S.unin3 + VCAM.S.unin4 + VCAM.S.unin5

unit =~ VCAM.V.unit1 + VCAM.V.unit2 + VCAM.V.unit3 + VCAM.V.unit4 + VCAM.V.unit5
+ VCAM.S.unit1 + VCAM.S.unit2 + VCAM.S.unit3 + VCAM.S.unit4 + VCAM.S.unit5'

cfa.3cfs <- cfa(m2.3cfs, data=A1miced, std.lv=TRUE)
summary(cfa.3cfs, fit.measures=TRUE, standardized=TRUE)

summary(cfa.3cfs, fit.measures=TRUE)

print(cfa.3cfs, fit.measures=TRUE)

rstudioapi::writeRStudioPreference("console_max_lines", 300)

?writeRStudioPreference

write.csv(cfa.3cfs, "cfa.3cfs")

?inspect

fits<-inspect(cfs.3cfs, what = "fitMeasures")
fits[c(5:7,24,44,34)]

cfa.3cfs@Fit@test[["standard"]]

cfa.3cfs@Fit

## This saves output as text file in order to read more than 1k lines
sink(file='cfa.3cfs.output.txt')
summary(cfa.3cfs, fit.measures=TRUE, standardized=TRUE)
sink()


#2b extra common factors (just +/-)

m2b.2cfs <- '

violf =~ 
  1*VCAM.V.sdt1 + 1*VCAM.V.sdt2 + 1*VCAM.V.sdt3 + 1*VCAM.V.sdt4 + 1*VCAM.V.sdt5

+ 1*VCAM.V.sda1 + 1*VCAM.V.sda2 + 1*VCAM.V.sda3 + 1*VCAM.V.sda4 + 1*VCAM.V.sda5

+ 1*VCAM.V.stim1 + 1*VCAM.V.stim2 + 1*VCAM.V.stim3 + 1*VCAM.V.stim4 + 1*VCAM.V.stim5

+ 1*VCAM.V.hedo1 + 1*VCAM.V.hedo2 + 1*VCAM.V.hedo3 + 1*VCAM.V.hedo4 + 1*VCAM.V.hedo5

+ 1*VCAM.V.achi1 + 1*VCAM.V.achi2 + 1*VCAM.V.achi3 + 1*VCAM.V.achi4 + 1*VCAM.V.achi5

+ 1*VCAM.V.powd1 + 1*VCAM.V.powd2 + 1*VCAM.V.powd3 + 1*VCAM.V.powd4 + 1*VCAM.V.powd5

+ 1*VCAM.V.powr1 + 1*VCAM.V.powr2 + 1*VCAM.V.powr3 + 1*VCAM.V.powr4 + 1*VCAM.V.powr5

+ 1*VCAM.V.face1 + 1*VCAM.V.face2 + 1*VCAM.V.face3 + 1*VCAM.V.face4 + 1*VCAM.V.face5

+ 1*VCAM.V.secp1 + 1*VCAM.V.secp2 + 1*VCAM.V.secp3 + 1*VCAM.V.secp4 + 1*VCAM.V.secp5

+ 1*VCAM.V.secs1 + 1*VCAM.V.secs2 + 1*VCAM.V.secs3 + 1*VCAM.V.secs4 + 1*VCAM.V.secs5

+ 1*VCAM.V.trad1 + 1*VCAM.V.trad2 + 1*VCAM.V.trad3 + 1*VCAM.V.trad4 + 1*VCAM.V.trad5

+ 1*VCAM.V.conr1 + 1*VCAM.V.conr2 + 1*VCAM.V.conr3 + 1*VCAM.V.conr4 + 1*VCAM.V.conr5

+ 1*VCAM.V.coni1 + 1*VCAM.V.coni2 + 1*VCAM.V.coni3 + 1*VCAM.V.coni4 + 1*VCAM.V.coni5

+ 1*VCAM.V.humi1 + 1*VCAM.V.humi2 + 1*VCAM.V.humi3 + 1*VCAM.V.humi4 + 1*VCAM.V.humi5

+ 1*VCAM.V.benc1 + 1*VCAM.V.benc2 + 1*VCAM.V.benc3 + 1*VCAM.V.benc4 + 1*VCAM.V.benc5

+ 1*VCAM.V.bend1 + 1*VCAM.V.bend2 + 1*VCAM.V.bend3 + 1*VCAM.V.bend4 + 1*VCAM.V.bend5

+ 1*VCAM.V.unic1 + 1*VCAM.V.unic2 + 1*VCAM.V.unic3 + 1*VCAM.V.unic4 + 1*VCAM.V.unic5

+ 1*VCAM.V.unin1 + 1*VCAM.V.unin2 + 1*VCAM.V.unin3 + 1*VCAM.V.unin4 + 1*VCAM.V.unin5

+ 1*VCAM.V.unit1 + 1*VCAM.V.unit2 + 1*VCAM.V.unit3 + 1*VCAM.V.unit4 + 1*VCAM.V.unit5


satisf =~ 1*VCAM.S.sdt1 + 1*VCAM.S.sdt2 + 1*VCAM.S.sdt3 + 1*VCAM.S.sdt4 + 1*VCAM.S.sdt5

+ 1*VCAM.S.sda1 + 1*VCAM.S.sda2 + 1*VCAM.S.sda3 + 1*VCAM.S.sda4 + 1*VCAM.S.sda5

+ 1*VCAM.S.stim1 + 1*VCAM.S.stim2 + 1*VCAM.S.stim3 + 1*VCAM.S.stim4 + 1*VCAM.S.stim5

+ 1*VCAM.S.hedo1 + 1*VCAM.S.hedo2 + 1*VCAM.S.hedo3 + 1*VCAM.S.hedo4 + 1*VCAM.S.hedo5

+ 1*VCAM.S.achi1 + 1*VCAM.S.achi2 + 1*VCAM.S.achi3 + 1*VCAM.S.achi4 + 1*VCAM.S.achi5

+ 1*VCAM.S.powd1 + 1*VCAM.S.powd2 + 1*VCAM.S.powd3 + 1*VCAM.S.powd4 + 1*VCAM.S.powd5

+ 1*VCAM.S.powr1 + 1*VCAM.S.powr2 + 1*VCAM.S.powr3 + 1*VCAM.S.powr4 + 1*VCAM.S.powr5

+ 1*VCAM.S.face1 + 1*VCAM.S.face2 + 1*VCAM.S.face3 + 1*VCAM.S.face4 + 1*VCAM.S.face5

+ 1*VCAM.S.secp1 + 1*VCAM.S.secp2 + 1*VCAM.S.secp3 + 1*VCAM.S.secp4 + 1*VCAM.S.secp5

+ 1*VCAM.S.secs1 + 1*VCAM.S.secs2 + 1*VCAM.S.secs3 + 1*VCAM.S.secs4 + 1*VCAM.S.secs5

+ 1*VCAM.S.trad1 + 1*VCAM.S.trad2 + 1*VCAM.S.trad3 + 1*VCAM.S.trad4 + 1*VCAM.S.trad5

+ 1*VCAM.S.conr1 + 1*VCAM.S.conr2 + 1*VCAM.S.conr3 + 1*VCAM.S.conr4 + 1*VCAM.S.conr5

+ 1*VCAM.S.coni1 + 1*VCAM.S.coni2 + 1*VCAM.S.coni3 + 1*VCAM.S.coni4 + 1*VCAM.S.coni5

+ 1*VCAM.S.humi1 + 1*VCAM.S.humi2 + 1*VCAM.S.humi3 + 1*VCAM.S.humi4 + 1*VCAM.S.humi5

+ 1*VCAM.S.benc1 + 1*VCAM.S.benc2 + 1*VCAM.S.benc3 + 1*VCAM.S.benc4 + 1*VCAM.S.benc5

+ 1*VCAM.S.bend1 + 1*VCAM.S.bend2 + 1*VCAM.S.bend3 + 1*VCAM.S.bend4 + 1*VCAM.S.bend5

+ 1*VCAM.S.unic1 + 1*VCAM.S.unic2 + 1*VCAM.S.unic3 + 1*VCAM.S.unic4 + 1*VCAM.S.unic5

+ 1*VCAM.S.unin1 + 1*VCAM.S.unin2 + 1*VCAM.S.unin3 + 1*VCAM.S.unin4 + 1*VCAM.S.unin5

+ 1*VCAM.S.unit1 + 1*VCAM.S.unit2 + 1*VCAM.S.unit3 + 1*VCAM.S.unit4 + 1*VCAM.S.unit5

sdt =~ VCAM.V.sdt1 + VCAM.V.sdt2 + VCAM.V.sdt3 + VCAM.V.sdt4 + VCAM.V.sdt5
+ VCAM.S.sdt1 + VCAM.S.sdt2 + VCAM.S.sdt3 + VCAM.S.sdt4 + VCAM.S.sdt5

sda =~ VCAM.V.sda1 + VCAM.V.sda2 + VCAM.V.sda3 + VCAM.V.sda4 + VCAM.V.sda5
+ VCAM.S.sda1 + VCAM.S.sda2 + VCAM.S.sda3 + VCAM.S.sda4 + VCAM.S.sda5

stim =~ VCAM.V.stim1 + VCAM.V.stim2 + VCAM.V.stim3 + VCAM.V.stim4 + VCAM.V.stim5
+ VCAM.S.stim1 + VCAM.S.stim2 + VCAM.S.stim3 + VCAM.S.stim4 + VCAM.S.stim5

hedo =~ VCAM.V.hedo1 + VCAM.V.hedo2 + VCAM.V.hedo3 + VCAM.V.hedo4 + VCAM.V.hedo5
+ VCAM.S.hedo1 + VCAM.S.hedo2 + VCAM.S.hedo3 + VCAM.S.hedo4 + VCAM.S.hedo5

achi =~ VCAM.V.achi1 + VCAM.V.achi2 + VCAM.V.achi3 + VCAM.V.achi4 + VCAM.V.achi5
+ VCAM.S.achi1 + VCAM.S.achi2 + VCAM.S.achi3 + VCAM.S.achi4 + VCAM.S.achi5

powd =~ VCAM.V.powd1 + VCAM.V.powd2 + VCAM.V.powd3 + VCAM.V.powd4 + VCAM.V.powd5
+ VCAM.S.powd1 + VCAM.S.powd2 + VCAM.S.powd3 + VCAM.S.powd4 + VCAM.S.powd5

powr =~ VCAM.V.powr1 + VCAM.V.powr2 + VCAM.V.powr3 + VCAM.V.powr4 + VCAM.V.powr5
+ VCAM.S.powr1 + VCAM.S.powr2 + VCAM.S.powr3 + VCAM.S.powr4 + VCAM.S.powr5

face =~ VCAM.V.face1 + VCAM.V.face2 + VCAM.V.face3 + VCAM.V.face4 + VCAM.V.face5
+ VCAM.S.face1 + VCAM.S.face2 + VCAM.S.face3 + VCAM.S.face4 + VCAM.S.face5

secp =~ VCAM.V.secp1 + VCAM.V.secp2 + VCAM.V.secp3 + VCAM.V.secp4 + VCAM.V.secp5
+ VCAM.S.secp1 + VCAM.S.secp2 + VCAM.S.secp3 + VCAM.S.secp4 + VCAM.S.secp5

secs =~ VCAM.V.secs1 + VCAM.V.secs2 + VCAM.V.secs3 + VCAM.V.secs4 + VCAM.V.secs5
+ VCAM.S.secs1 + VCAM.S.secs2 + VCAM.S.secs3 + VCAM.S.secs4 + VCAM.S.secs5

trad =~ VCAM.V.trad1 + VCAM.V.trad2 + VCAM.V.trad3 + VCAM.V.trad4 + VCAM.V.trad5
+ VCAM.S.trad1 + VCAM.S.trad2 + VCAM.S.trad3 + VCAM.S.trad4 + VCAM.S.trad5

conr =~ VCAM.V.conr1 + VCAM.V.conr2 + VCAM.V.conr3 + VCAM.V.conr4 + VCAM.V.conr5
+ VCAM.S.conr1 + VCAM.S.conr2 + VCAM.S.conr3 + VCAM.S.conr4 + VCAM.S.conr5

coni =~ VCAM.V.coni1 + VCAM.V.coni2 + VCAM.V.coni3 + VCAM.V.coni4 + VCAM.V.coni5
+ VCAM.S.coni1 + VCAM.S.coni2 + VCAM.S.coni3 + VCAM.S.coni4 + VCAM.S.coni5

humi =~ VCAM.V.humi1 + VCAM.V.humi2 + VCAM.V.humi3 + VCAM.V.humi4 + VCAM.V.humi5
+ VCAM.S.humi1 + VCAM.S.humi2 + VCAM.S.humi3 + VCAM.S.humi4 + VCAM.S.humi5

benc =~ VCAM.V.benc1 + VCAM.V.benc2 + VCAM.V.benc3 + VCAM.V.benc4 + VCAM.V.benc5
+ VCAM.S.benc1 + VCAM.S.benc2 + VCAM.S.benc3 + VCAM.S.benc4 + VCAM.S.benc5

bend =~ VCAM.V.bend1 + VCAM.V.bend2 + VCAM.V.bend3 + VCAM.V.bend4 + VCAM.V.bend5
+ VCAM.S.bend1 + VCAM.S.bend2 + VCAM.S.bend3 + VCAM.S.bend4 + VCAM.S.bend5

unic =~ VCAM.V.unic1 + VCAM.V.unic2 + VCAM.V.unic3 + VCAM.V.unic4 + VCAM.V.unic5
+ VCAM.S.unic1 + VCAM.S.unic2 + VCAM.S.unic3 + VCAM.S.unic4 + VCAM.S.unic5

unin =~ VCAM.V.unin1 + VCAM.V.unin2 + VCAM.V.unin3 + VCAM.V.unin4 + VCAM.V.unin5
+ VCAM.S.unin1 + VCAM.S.unin2 + VCAM.S.unin3 + VCAM.S.unin4 + VCAM.S.unin5

unit =~ VCAM.V.unit1 + VCAM.V.unit2 + VCAM.V.unit3 + VCAM.V.unit4 + VCAM.V.unit5
+ VCAM.S.unit1 + VCAM.S.unit2 + VCAM.S.unit3 + VCAM.S.unit4 + VCAM.S.unit5'

cfa.2cfs <- cfa(m2b.2cfs, data=A1miced, std.lv=TRUE)

sink(file='cfa.2cfs.output.txt')
summary(cfa.2cfs, fit.measures=TRUE, standardized=TRUE)
sink()

##### Models 3

#3a 3cfs, 10 

m3.10bvs <- '

commonf =~ 
  1*VCAM.V.sdt1 + 1*VCAM.V.sdt2 + 1*VCAM.V.sdt3 + 1*VCAM.V.sdt4 + 1*VCAM.V.sdt5
+ 1*VCAM.S.sdt1 + 1*VCAM.S.sdt2 + 1*VCAM.S.sdt3 + 1*VCAM.S.sdt4 + 1*VCAM.S.sdt5

+ 1*VCAM.V.sda1 + 1*VCAM.V.sda2 + 1*VCAM.V.sda3 + 1*VCAM.V.sda4 + 1*VCAM.V.sda5
+ 1*VCAM.S.sda1 + 1*VCAM.S.sda2 + 1*VCAM.S.sda3 + 1*VCAM.S.sda4 + 1*VCAM.S.sda5

+ 1*VCAM.V.stim1 + 1*VCAM.V.stim2 + 1*VCAM.V.stim3 + 1*VCAM.V.stim4 + 1*VCAM.V.stim5
+ 1*VCAM.S.stim1 + 1*VCAM.S.stim2 + 1*VCAM.S.stim3 + 1*VCAM.S.stim4 + 1*VCAM.S.stim5

+ 1*VCAM.V.hedo1 + 1*VCAM.V.hedo2 + 1*VCAM.V.hedo3 + 1*VCAM.V.hedo4 + 1*VCAM.V.hedo5
+ 1*VCAM.S.hedo1 + 1*VCAM.S.hedo2 + 1*VCAM.S.hedo3 + 1*VCAM.S.hedo4 + 1*VCAM.S.hedo5

+ 1*VCAM.V.achi1 + 1*VCAM.V.achi2 + 1*VCAM.V.achi3 + 1*VCAM.V.achi4 + 1*VCAM.V.achi5
+ 1*VCAM.S.achi1 + 1*VCAM.S.achi2 + 1*VCAM.S.achi3 + 1*VCAM.S.achi4 + 1*VCAM.S.achi5

+ 1*VCAM.V.powd1 + 1*VCAM.V.powd2 + 1*VCAM.V.powd3 + 1*VCAM.V.powd4 + 1*VCAM.V.powd5
+ 1*VCAM.S.powd1 + 1*VCAM.S.powd2 + 1*VCAM.S.powd3 + 1*VCAM.S.powd4 + 1*VCAM.S.powd5

+ 1*VCAM.V.powr1 + 1*VCAM.V.powr2 + 1*VCAM.V.powr3 + 1*VCAM.V.powr4 + 1*VCAM.V.powr5
+ 1*VCAM.S.powr1 + 1*VCAM.S.powr2 + 1*VCAM.S.powr3 + 1*VCAM.S.powr4 + 1*VCAM.S.powr5

+ 1*VCAM.V.face1 + 1*VCAM.V.face2 + 1*VCAM.V.face3 + 1*VCAM.V.face4 + 1*VCAM.V.face5
+ 1*VCAM.S.face1 + 1*VCAM.S.face2 + 1*VCAM.S.face3 + 1*VCAM.S.face4 + 1*VCAM.S.face5

+ 1*VCAM.V.secp1 + 1*VCAM.V.secp2 + 1*VCAM.V.secp3 + 1*VCAM.V.secp4 + 1*VCAM.V.secp5
+ 1*VCAM.S.secp1 + 1*VCAM.S.secp2 + 1*VCAM.S.secp3 + 1*VCAM.S.secp4 + 1*VCAM.S.secp5

+ 1*VCAM.V.secs1 + 1*VCAM.V.secs2 + 1*VCAM.V.secs3 + 1*VCAM.V.secs4 + 1*VCAM.V.secs5
+ 1*VCAM.S.secs1 + 1*VCAM.S.secs2 + 1*VCAM.S.secs3 + 1*VCAM.S.secs4 + 1*VCAM.S.secs5

+ 1*VCAM.V.trad1 + 1*VCAM.V.trad2 + 1*VCAM.V.trad3 + 1*VCAM.V.trad4 + 1*VCAM.V.trad5
+ 1*VCAM.S.trad1 + 1*VCAM.S.trad2 + 1*VCAM.S.trad3 + 1*VCAM.S.trad4 + 1*VCAM.S.trad5

+ 1*VCAM.V.conr1 + 1*VCAM.V.conr2 + 1*VCAM.V.conr3 + 1*VCAM.V.conr4 + 1*VCAM.V.conr5
+ 1*VCAM.S.conr1 + 1*VCAM.S.conr2 + 1*VCAM.S.conr3 + 1*VCAM.S.conr4 + 1*VCAM.S.conr5

+ 1*VCAM.V.coni1 + 1*VCAM.V.coni2 + 1*VCAM.V.coni3 + 1*VCAM.V.coni4 + 1*VCAM.V.coni5
+ 1*VCAM.S.coni1 + 1*VCAM.S.coni2 + 1*VCAM.S.coni3 + 1*VCAM.S.coni4 + 1*VCAM.S.coni5

+ 1*VCAM.V.humi1 + 1*VCAM.V.humi2 + 1*VCAM.V.humi3 + 1*VCAM.V.humi4 + 1*VCAM.V.humi5
+ 1*VCAM.S.humi1 + 1*VCAM.S.humi2 + 1*VCAM.S.humi3 + 1*VCAM.S.humi4 + 1*VCAM.S.humi5

+ 1*VCAM.V.benc1 + 1*VCAM.V.benc2 + 1*VCAM.V.benc3 + 1*VCAM.V.benc4 + 1*VCAM.V.benc5
+ 1*VCAM.S.benc1 + 1*VCAM.S.benc2 + 1*VCAM.S.benc3 + 1*VCAM.S.benc4 + 1*VCAM.S.benc5

+ 1*VCAM.V.bend1 + 1*VCAM.V.bend2 + 1*VCAM.V.bend3 + 1*VCAM.V.bend4 + 1*VCAM.V.bend5
+ 1*VCAM.S.bend1 + 1*VCAM.S.bend2 + 1*VCAM.S.bend3 + 1*VCAM.S.bend4 + 1*VCAM.S.bend5

+ 1*VCAM.V.unic1 + 1*VCAM.V.unic2 + 1*VCAM.V.unic3 + 1*VCAM.V.unic4 + 1*VCAM.V.unic5
+ 1*VCAM.S.unic1 + 1*VCAM.S.unic2 + 1*VCAM.S.unic3 + 1*VCAM.S.unic4 + 1*VCAM.S.unic5

+ 1*VCAM.V.unin1 + 1*VCAM.V.unin2 + 1*VCAM.V.unin3 + 1*VCAM.V.unin4 + 1*VCAM.V.unin5
+ 1*VCAM.S.unin1 + 1*VCAM.S.unin2 + 1*VCAM.S.unin3 + 1*VCAM.S.unin4 + 1*VCAM.S.unin5

+ 1*VCAM.V.unit1 + 1*VCAM.V.unit2 + 1*VCAM.V.unit3 + 1*VCAM.V.unit4 + 1*VCAM.V.unit5
+ 1*VCAM.S.unit1 + 1*VCAM.S.unit2 + 1*VCAM.S.unit3 + 1*VCAM.S.unit4 + 1*VCAM.S.unit5

violf =~ 
  1*VCAM.V.sdt1 + 1*VCAM.V.sdt2 + 1*VCAM.V.sdt3 + 1*VCAM.V.sdt4 + 1*VCAM.V.sdt5

+ 1*VCAM.V.sda1 + 1*VCAM.V.sda2 + 1*VCAM.V.sda3 + 1*VCAM.V.sda4 + 1*VCAM.V.sda5

+ 1*VCAM.V.stim1 + 1*VCAM.V.stim2 + 1*VCAM.V.stim3 + 1*VCAM.V.stim4 + 1*VCAM.V.stim5

+ 1*VCAM.V.hedo1 + 1*VCAM.V.hedo2 + 1*VCAM.V.hedo3 + 1*VCAM.V.hedo4 + 1*VCAM.V.hedo5

+ 1*VCAM.V.achi1 + 1*VCAM.V.achi2 + 1*VCAM.V.achi3 + 1*VCAM.V.achi4 + 1*VCAM.V.achi5

+ 1*VCAM.V.powd1 + 1*VCAM.V.powd2 + 1*VCAM.V.powd3 + 1*VCAM.V.powd4 + 1*VCAM.V.powd5

+ 1*VCAM.V.powr1 + 1*VCAM.V.powr2 + 1*VCAM.V.powr3 + 1*VCAM.V.powr4 + 1*VCAM.V.powr5

+ 1*VCAM.V.face1 + 1*VCAM.V.face2 + 1*VCAM.V.face3 + 1*VCAM.V.face4 + 1*VCAM.V.face5

+ 1*VCAM.V.secp1 + 1*VCAM.V.secp2 + 1*VCAM.V.secp3 + 1*VCAM.V.secp4 + 1*VCAM.V.secp5

+ 1*VCAM.V.secs1 + 1*VCAM.V.secs2 + 1*VCAM.V.secs3 + 1*VCAM.V.secs4 + 1*VCAM.V.secs5

+ 1*VCAM.V.trad1 + 1*VCAM.V.trad2 + 1*VCAM.V.trad3 + 1*VCAM.V.trad4 + 1*VCAM.V.trad5

+ 1*VCAM.V.conr1 + 1*VCAM.V.conr2 + 1*VCAM.V.conr3 + 1*VCAM.V.conr4 + 1*VCAM.V.conr5

+ 1*VCAM.V.coni1 + 1*VCAM.V.coni2 + 1*VCAM.V.coni3 + 1*VCAM.V.coni4 + 1*VCAM.V.coni5

+ 1*VCAM.V.humi1 + 1*VCAM.V.humi2 + 1*VCAM.V.humi3 + 1*VCAM.V.humi4 + 1*VCAM.V.humi5

+ 1*VCAM.V.benc1 + 1*VCAM.V.benc2 + 1*VCAM.V.benc3 + 1*VCAM.V.benc4 + 1*VCAM.V.benc5

+ 1*VCAM.V.bend1 + 1*VCAM.V.bend2 + 1*VCAM.V.bend3 + 1*VCAM.V.bend4 + 1*VCAM.V.bend5

+ 1*VCAM.V.unic1 + 1*VCAM.V.unic2 + 1*VCAM.V.unic3 + 1*VCAM.V.unic4 + 1*VCAM.V.unic5

+ 1*VCAM.V.unin1 + 1*VCAM.V.unin2 + 1*VCAM.V.unin3 + 1*VCAM.V.unin4 + 1*VCAM.V.unin5

+ 1*VCAM.V.unit1 + 1*VCAM.V.unit2 + 1*VCAM.V.unit3 + 1*VCAM.V.unit4 + 1*VCAM.V.unit5


satisf =~ 1*VCAM.S.sdt1 + 1*VCAM.S.sdt2 + 1*VCAM.S.sdt3 + 1*VCAM.S.sdt4 + 1*VCAM.S.sdt5

+ 1*VCAM.S.sda1 + 1*VCAM.S.sda2 + 1*VCAM.S.sda3 + 1*VCAM.S.sda4 + 1*VCAM.S.sda5

+ 1*VCAM.S.stim1 + 1*VCAM.S.stim2 + 1*VCAM.S.stim3 + 1*VCAM.S.stim4 + 1*VCAM.S.stim5

+ 1*VCAM.S.hedo1 + 1*VCAM.S.hedo2 + 1*VCAM.S.hedo3 + 1*VCAM.S.hedo4 + 1*VCAM.S.hedo5

+ 1*VCAM.S.achi1 + 1*VCAM.S.achi2 + 1*VCAM.S.achi3 + 1*VCAM.S.achi4 + 1*VCAM.S.achi5

+ 1*VCAM.S.powd1 + 1*VCAM.S.powd2 + 1*VCAM.S.powd3 + 1*VCAM.S.powd4 + 1*VCAM.S.powd5

+ 1*VCAM.S.powr1 + 1*VCAM.S.powr2 + 1*VCAM.S.powr3 + 1*VCAM.S.powr4 + 1*VCAM.S.powr5

+ 1*VCAM.S.face1 + 1*VCAM.S.face2 + 1*VCAM.S.face3 + 1*VCAM.S.face4 + 1*VCAM.S.face5

+ 1*VCAM.S.secp1 + 1*VCAM.S.secp2 + 1*VCAM.S.secp3 + 1*VCAM.S.secp4 + 1*VCAM.S.secp5

+ 1*VCAM.S.secs1 + 1*VCAM.S.secs2 + 1*VCAM.S.secs3 + 1*VCAM.S.secs4 + 1*VCAM.S.secs5

+ 1*VCAM.S.trad1 + 1*VCAM.S.trad2 + 1*VCAM.S.trad3 + 1*VCAM.S.trad4 + 1*VCAM.S.trad5

+ 1*VCAM.S.conr1 + 1*VCAM.S.conr2 + 1*VCAM.S.conr3 + 1*VCAM.S.conr4 + 1*VCAM.S.conr5

+ 1*VCAM.S.coni1 + 1*VCAM.S.coni2 + 1*VCAM.S.coni3 + 1*VCAM.S.coni4 + 1*VCAM.S.coni5

+ 1*VCAM.S.humi1 + 1*VCAM.S.humi2 + 1*VCAM.S.humi3 + 1*VCAM.S.humi4 + 1*VCAM.S.humi5

+ 1*VCAM.S.benc1 + 1*VCAM.S.benc2 + 1*VCAM.S.benc3 + 1*VCAM.S.benc4 + 1*VCAM.S.benc5

+ 1*VCAM.S.bend1 + 1*VCAM.S.bend2 + 1*VCAM.S.bend3 + 1*VCAM.S.bend4 + 1*VCAM.S.bend5

+ 1*VCAM.S.unic1 + 1*VCAM.S.unic2 + 1*VCAM.S.unic3 + 1*VCAM.S.unic4 + 1*VCAM.S.unic5

+ 1*VCAM.S.unin1 + 1*VCAM.S.unin2 + 1*VCAM.S.unin3 + 1*VCAM.S.unin4 + 1*VCAM.S.unin5

+ 1*VCAM.S.unit1 + 1*VCAM.S.unit2 + 1*VCAM.S.unit3 + 1*VCAM.S.unit4 + 1*VCAM.S.unit5

sdt =~ VCAM.V.sdt1 + VCAM.V.sdt2 + VCAM.V.sdt3 + VCAM.V.sdt4 + VCAM.V.sdt5
+ VCAM.S.sdt1 + VCAM.S.sdt2 + VCAM.S.sdt3 + VCAM.S.sdt4 + VCAM.S.sdt5

sda =~ VCAM.V.sda1 + VCAM.V.sda2 + VCAM.V.sda3 + VCAM.V.sda4 + VCAM.V.sda5
+ VCAM.S.sda1 + VCAM.S.sda2 + VCAM.S.sda3 + VCAM.S.sda4 + VCAM.S.sda5

sd =~ sdt + sda

stim =~ VCAM.V.stim1 + VCAM.V.stim2 + VCAM.V.stim3 + VCAM.V.stim4 + VCAM.V.stim5
+ VCAM.S.stim1 + VCAM.S.stim2 + VCAM.S.stim3 + VCAM.S.stim4 + VCAM.S.stim5

hedo =~ VCAM.V.hedo1 + VCAM.V.hedo2 + VCAM.V.hedo3 + VCAM.V.hedo4 + VCAM.V.hedo5
+ VCAM.S.hedo1 + VCAM.S.hedo2 + VCAM.S.hedo3 + VCAM.S.hedo4 + VCAM.S.hedo5

achi =~ VCAM.V.achi1 + VCAM.V.achi2 + VCAM.V.achi3 + VCAM.V.achi4 + VCAM.V.achi5
+ VCAM.S.achi1 + VCAM.S.achi2 + VCAM.S.achi3 + VCAM.S.achi4 + VCAM.S.achi5

powd =~ VCAM.V.powd1 + VCAM.V.powd2 + VCAM.V.powd3 + VCAM.V.powd4 + VCAM.V.powd5
+ VCAM.S.powd1 + VCAM.S.powd2 + VCAM.S.powd3 + VCAM.S.powd4 + VCAM.S.powd5

powr =~ VCAM.V.powr1 + VCAM.V.powr2 + VCAM.V.powr3 + VCAM.V.powr4 + VCAM.V.powr5
+ VCAM.S.powr1 + VCAM.S.powr2 + VCAM.S.powr3 + VCAM.S.powr4 + VCAM.S.powr5

pow =~ powd + powr

face =~ VCAM.V.face1 + VCAM.V.face2 + VCAM.V.face3 + VCAM.V.face4 + VCAM.V.face5
+ VCAM.S.face1 + VCAM.S.face2 + VCAM.S.face3 + VCAM.S.face4 + VCAM.S.face5

secp =~ VCAM.V.secp1 + VCAM.V.secp2 + VCAM.V.secp3 + VCAM.V.secp4 + VCAM.V.secp5
+ VCAM.S.secp1 + VCAM.S.secp2 + VCAM.S.secp3 + VCAM.S.secp4 + VCAM.S.secp5

secs =~ VCAM.V.secs1 + VCAM.V.secs2 + VCAM.V.secs3 + VCAM.V.secs4 + VCAM.V.secs5
+ VCAM.S.secs1 + VCAM.S.secs2 + VCAM.S.secs3 + VCAM.S.secs4 + VCAM.S.secs5

sec =~ secp + secs

trad =~ VCAM.V.trad1 + VCAM.V.trad2 + VCAM.V.trad3 + VCAM.V.trad4 + VCAM.V.trad5
+ VCAM.S.trad1 + VCAM.S.trad2 + VCAM.S.trad3 + VCAM.S.trad4 + VCAM.S.trad5

conr =~ VCAM.V.conr1 + VCAM.V.conr2 + VCAM.V.conr3 + VCAM.V.conr4 + VCAM.V.conr5
+ VCAM.S.conr1 + VCAM.S.conr2 + VCAM.S.conr3 + VCAM.S.conr4 + VCAM.S.conr5

coni =~ VCAM.V.coni1 + VCAM.V.coni2 + VCAM.V.coni3 + VCAM.V.coni4 + VCAM.V.coni5
+ VCAM.S.coni1 + VCAM.S.coni2 + VCAM.S.coni3 + VCAM.S.coni4 + VCAM.S.coni5

con =~ conr + coni

humi =~ VCAM.V.humi1 + VCAM.V.humi2 + VCAM.V.humi3 + VCAM.V.humi4 + VCAM.V.humi5
+ VCAM.S.humi1 + VCAM.S.humi2 + VCAM.S.humi3 + VCAM.S.humi4 + VCAM.S.humi5

benc =~ VCAM.V.benc1 + VCAM.V.benc2 + VCAM.V.benc3 + VCAM.V.benc4 + VCAM.V.benc5
+ VCAM.S.benc1 + VCAM.S.benc2 + VCAM.S.benc3 + VCAM.S.benc4 + VCAM.S.benc5

bend =~ VCAM.V.bend1 + VCAM.V.bend2 + VCAM.V.bend3 + VCAM.V.bend4 + VCAM.V.bend5
+ VCAM.S.bend1 + VCAM.S.bend2 + VCAM.S.bend3 + VCAM.S.bend4 + VCAM.S.bend5

ben =~ benc + bend

unic =~ VCAM.V.unic1 + VCAM.V.unic2 + VCAM.V.unic3 + VCAM.V.unic4 + VCAM.V.unic5
+ VCAM.S.unic1 + VCAM.S.unic2 + VCAM.S.unic3 + VCAM.S.unic4 + VCAM.S.unic5

unin =~ VCAM.V.unin1 + VCAM.V.unin2 + VCAM.V.unin3 + VCAM.V.unin4 + VCAM.V.unin5
+ VCAM.S.unin1 + VCAM.S.unin2 + VCAM.S.unin3 + VCAM.S.unin4 + VCAM.S.unin5

unit =~ VCAM.V.unit1 + VCAM.V.unit2 + VCAM.V.unit3 + VCAM.V.unit4 + VCAM.V.unit5
+ VCAM.S.unit1 + VCAM.S.unit2 + VCAM.S.unit3 + VCAM.S.unit4 + VCAM.S.unit5

uni =~ unic + unin + unit'

cfa.10bvs <- cfa(m3.10bvs, data=A1miced, std.lv=TRUE)
summary(cfa.10bvs, fit.measures=TRUE, standardized=TRUE)

## This saves output as text file in order to read more than 1k lines
sink(file='cfa.10bvs.output.txt')
summary(cfa.10bvs, fit.measures=TRUE, standardized=TRUE)
sink()

################

######

###

######

################




#### EFA ####

#Updated October 2022

VCAM <- A1miced[, -c(1:59)]

parallel <- fa.parallel(VCAM, fm="ml", fa="fa")

parallel

VCAM.V <- VCAM[, c(1:95)]

VCAM.S <- VCAM[, c(96:190)]

parallel.V <- fa.parallel(VCAM.V, fm="ml", fa="fa")

parallel.S <- fa.parallel(VCAM.S, fm="ml", fa="fa")

parallel.V
parallel.S

#stopped here 10/12/2022

twofactorV <- fa(VCAM.V, nfactors=2, rotate = "oblimin", fm="ml")

summary(twofactorV, print=fitmeasures())



sink(file='efa.violations.txt')
summary(twofactorV, fit.measures=TRUE, standardized=TRUE)
sink()


twofactorS <- fa(VCAM.S, nfactors=2, rotate = "oblimin", fm="ml")

summary(twofactorS, print=fitmeasures())


sink(file='efa.satisfactions.txt')
summary(twofactorS, fit.measures=TRUE, standardized=TRUE)
sink()


#Get CFI
1 - ((twofactorV$STATISTIC - twofactorV$dof)/(twofactorV$null.chisq - twofactorV$null.dof))


1 - ((twofactorS$STATISTIC - twofactorS$dof)/(twofactorS$null.chisq - twofactorS$null.dof))


### means and SDs of each item

attach(A1miced)

sd(VCAM.V.sdt1)



## Attempt at creating two-factor circle with value items


circleV <- fa(VCAM.V, nfactors=2, rotate = "varimax", fm="ml")

circleVloadings <- loadings(circleV)

summary(circleV, fit.measures=TRUE, standardized=TRUE)
1 - ((circleV$STATISTIC - circleV$dof)/(circleV$null.chisq - circleV$null.dof))
(circleV)

?s

sink(file='efa.circleVloadings3.txt')
print(circleVloadings, cutoff = 0.0000001)
sink()

circleS <- fa(VCAM.S, nfactors=2, rotate = "varimax", fm="ml")

summary(circleS)
1 - ((circleS$STATISTIC - circleS$dof)/(circleS$null.chisq - circleS$null.dof))


circleSloadings <- loadings(circleS)

sink(file='efa.circleSloadings.txt')
print(circleSloadings, cutoff = 0.0000001)
sink()



PVQR <- A1.5miced[, c(2:58)]

circlePVQR <- fa(PVQR, nfactors=2, rotate = "varimax", fm="ml")

circlePVQRloadings <- loadings(circlePVQR)

summary(circlePVQR)
1 - ((circlePVQR$STATISTIC - circlePVQR$dof)/(circlePVQR$null.chisq - circlePVQR$null.dof))



sink(file='efa.circlePVQRloadings.txt')
print(circlePVQRloadings, cutoff = 0.0000001)
sink()

A1.5efa <- A1.5miced[, c(-1)]

parallel3combined <- fa.parallel(A1.5efa, fm="ml", fa="fa")

parallel3combined


circle3combined <- fa(A1.5efa, nfactors=2, rotate="varimax", fm="ml")

circle3combinedloadings <- loadings(circle3combined)


sink(file='efa.circle3combinedloadings.txt')
print(circle3combinedloadings, cutoff = 0.0000001)
sink()



circle2combined <- fa(VCAM, nfactors=2, rotate="varimax", fm="ml")

circle2combinedloadings <- loadings(circle2combined)


sink(file='efa.circle2combinedloadings.txt')
print(circle2combinedloadings, cutoff = 0.0000001)
sink()

#Average inter-item correlation

library(performance)

# 19 VCAM Scales sum scores (10 items each)

attach(A1miced)

VCAM.sdt <- VCAM.V.sdt1 + VCAM.V.sdt2 + VCAM.V.sdt3 + VCAM.V.sdt4 + VCAM.V.sdt5 +
  VCAM.S.sdt1 + VCAM.S.sdt2 + VCAM.S.sdt3 + VCAM.S.sdt4 + VCAM.S.sdt5

VCAM.sda <- VCAM.V.sda1 + VCAM.V.sda2 + VCAM.V.sda3 + VCAM.V.sda4 + VCAM.V.sda5 +
  VCAM.S.sda1 + VCAM.S.sda2 + VCAM.S.sda3 + VCAM.S.sda4 + VCAM.S.sda5

VCAM.stim <- VCAM.V.stim1 + VCAM.V.stim2 + VCAM.V.stim3 + VCAM.V.stim4 + VCAM.V.stim5 +
  VCAM.S.stim1 + VCAM.S.stim2 + VCAM.S.stim3 + VCAM.S.stim4 + VCAM.S.stim5

VCAM.hedo <- VCAM.V.hedo1 + VCAM.V.hedo2 + VCAM.V.hedo3 + VCAM.V.hedo4 + VCAM.V.hedo5 +
  VCAM.S.hedo1 + VCAM.S.hedo2 + VCAM.S.hedo3 + VCAM.S.hedo4 + VCAM.S.hedo5

VCAM.achi <- VCAM.V.achi1 + VCAM.V.achi2 + VCAM.V.achi3 + VCAM.V.achi4 + VCAM.V.achi5 +
  VCAM.S.achi1 + VCAM.S.achi2 + VCAM.S.achi3 + VCAM.S.achi4 + VCAM.S.achi5

VCAM.powd <- VCAM.V.powd1 + VCAM.V.powd2 + VCAM.V.powd3 + VCAM.V.powd4 + VCAM.V.powd5 +
  VCAM.S.powd1 + VCAM.S.powd2 + VCAM.S.powd3 + VCAM.S.powd4 + VCAM.S.powd5

VCAM.powr <- VCAM.V.powr1 + VCAM.V.powr2 + VCAM.V.powr3 + VCAM.V.powr4 + VCAM.V.powr5 +
  VCAM.S.powr1 + VCAM.S.powr2 + VCAM.S.powr3 + VCAM.S.powr4 + VCAM.S.powr5

VCAM.face <- VCAM.V.face1 + VCAM.V.face2 + VCAM.V.face3 + VCAM.V.face4 + VCAM.V.face5 +
  VCAM.S.face1 + VCAM.S.face2 + VCAM.S.face3 + VCAM.S.face4 + VCAM.S.face5

VCAM.secp <- VCAM.V.secp1 + VCAM.V.secp2 + VCAM.V.secp3 + VCAM.V.secp4 + VCAM.V.secp5 +
  VCAM.S.secp1 + VCAM.S.secp2 + VCAM.S.secp3 + VCAM.S.secp4 + VCAM.S.secp5

VCAM.secs <- VCAM.V.secs1 + VCAM.V.secs2 + VCAM.V.secs3 + VCAM.V.secs4 + VCAM.V.secs5 +
  VCAM.S.secs1 + VCAM.S.secs2 + VCAM.S.secs3 + VCAM.S.secs4 + VCAM.S.secs5

VCAM.trad <- VCAM.V.trad1 + VCAM.V.trad2 + VCAM.V.trad3 + VCAM.V.trad4 + VCAM.V.trad5 +
  VCAM.S.trad1 + VCAM.S.trad2 + VCAM.S.trad3 + VCAM.S.trad4 + VCAM.S.trad5

VCAM.conr <- VCAM.V.conr1 + VCAM.V.conr2 + VCAM.V.conr3 + VCAM.V.conr4 + VCAM.V.conr5 +
  VCAM.S.conr1 + VCAM.S.conr2 + VCAM.S.conr3 + VCAM.S.conr4 + VCAM.S.conr5

VCAM.coni <- VCAM.V.coni1 + VCAM.V.coni2 + VCAM.V.coni3 + VCAM.V.coni4 + VCAM.V.coni5 +
  VCAM.S.coni1 + VCAM.S.coni2 + VCAM.S.coni3 + VCAM.S.coni4 + VCAM.S.coni5

VCAM.humi <- VCAM.V.humi1 + VCAM.V.humi2 + VCAM.V.humi3 + VCAM.V.humi4 + VCAM.V.humi5 +
  VCAM.S.humi1 + VCAM.S.humi2 + VCAM.S.humi3 + VCAM.S.humi4 + VCAM.S.humi5

VCAM.benc <- VCAM.V.benc1 + VCAM.V.benc2 + VCAM.V.benc3 + VCAM.V.benc4 + VCAM.V.benc5 +
  VCAM.S.benc1 + VCAM.S.benc2 + VCAM.S.benc3 + VCAM.S.benc4 + VCAM.S.benc5

VCAM.bend <- VCAM.V.bend1 + VCAM.V.bend2 + VCAM.V.bend3 + VCAM.V.bend4 + VCAM.V.bend5 +
  VCAM.S.bend1 + VCAM.S.bend2 + VCAM.S.bend3 + VCAM.S.bend4 + VCAM.S.bend5

VCAM.unic <- VCAM.V.unic1 + VCAM.V.unic2 + VCAM.V.unic3 + VCAM.V.unic4 + VCAM.V.unic5 +
  VCAM.S.unic1 + VCAM.S.unic2 + VCAM.S.unic3 + VCAM.S.unic4 + VCAM.S.unic5

VCAM.unin <- VCAM.V.unin1 + VCAM.V.unin2 + VCAM.V.unin3 + VCAM.V.unin4 + VCAM.V.unin5 +
  VCAM.S.unin1 + VCAM.S.unin2 + VCAM.S.unin3 + VCAM.S.unin4 + VCAM.S.unin5

VCAM.unit <- VCAM.V.unit1 + VCAM.V.unit2 + VCAM.V.unit3 + VCAM.V.unit4 + VCAM.V.unit5 +
  VCAM.S.unit1 + VCAM.S.unit2 + VCAM.S.unit3 + VCAM.S.unit4 + VCAM.S.unit5



#VCAM item sets for each scale


df.VCAM.sdt <- data.frame(VCAM.V.sdt1, VCAM.V.sdt2, VCAM.V.sdt3, VCAM.V.sdt4, VCAM.V.sdt5 +
                            VCAM.S.sdt1, VCAM.S.sdt2, VCAM.S.sdt3, VCAM.S.sdt4, VCAM.S.sdt5)

df.VCAM.sda <- data.frame(VCAM.V.sda1, VCAM.V.sda2, VCAM.V.sda3, VCAM.V.sda4, VCAM.V.sda5 +
                            VCAM.S.sda1, VCAM.S.sda2, VCAM.S.sda3, VCAM.S.sda4, VCAM.S.sda5)

df.VCAM.stim <- data.frame(VCAM.V.stim1, VCAM.V.stim2, VCAM.V.stim3, VCAM.V.stim4, VCAM.V.stim5 +
                             VCAM.S.stim1, VCAM.S.stim2, VCAM.S.stim3, VCAM.S.stim4, VCAM.S.stim5)

df.VCAM.hedo <- data.frame(VCAM.V.hedo1, VCAM.V.hedo2, VCAM.V.hedo3, VCAM.V.hedo4, VCAM.V.hedo5 +
                             VCAM.S.hedo1, VCAM.S.hedo2, VCAM.S.hedo3, VCAM.S.hedo4, VCAM.S.hedo5)

df.VCAM.achi <- data.frame(VCAM.V.achi1, VCAM.V.achi2, VCAM.V.achi3, VCAM.V.achi4, VCAM.V.achi5 +
                             VCAM.S.achi1, VCAM.S.achi2, VCAM.S.achi3, VCAM.S.achi4, VCAM.S.achi5)

df.VCAM.powd <- data.frame(VCAM.V.powd1, VCAM.V.powd2, VCAM.V.powd3, VCAM.V.powd4, VCAM.V.powd5 +
                             VCAM.S.powd1, VCAM.S.powd2, VCAM.S.powd3, VCAM.S.powd4, VCAM.S.powd5)

df.VCAM.powr <- data.frame(VCAM.V.powr1, VCAM.V.powr2, VCAM.V.powr3, VCAM.V.powr4, VCAM.V.powr5 +
                             VCAM.S.powr1, VCAM.S.powr2, VCAM.S.powr3, VCAM.S.powr4, VCAM.S.powr5)

df.VCAM.face <- data.frame(VCAM.V.face1, VCAM.V.face2, VCAM.V.face3, VCAM.V.face4, VCAM.V.face5 +
                             VCAM.S.face1, VCAM.S.face2, VCAM.S.face3, VCAM.S.face4, VCAM.S.face5)

df.VCAM.secp <- data.frame(VCAM.V.secp1, VCAM.V.secp2, VCAM.V.secp3, VCAM.V.secp4, VCAM.V.secp5 +
                             VCAM.S.secp1, VCAM.S.secp2, VCAM.S.secp3, VCAM.S.secp4, VCAM.S.secp5)

df.VCAM.secs <- data.frame(VCAM.V.secs1, VCAM.V.secs2, VCAM.V.secs3, VCAM.V.secs4, VCAM.V.secs5 +
                             VCAM.S.secs1, VCAM.S.secs2, VCAM.S.secs3, VCAM.S.secs4, VCAM.S.secs5)

df.VCAM.trad <- data.frame(VCAM.V.trad1, VCAM.V.trad2, VCAM.V.trad3, VCAM.V.trad4, VCAM.V.trad5 +
                             VCAM.S.trad1, VCAM.S.trad2, VCAM.S.trad3, VCAM.S.trad4, VCAM.S.trad5)

df.VCAM.conr <- data.frame(VCAM.V.conr1, VCAM.V.conr2, VCAM.V.conr3, VCAM.V.conr4, VCAM.V.conr5 +
                             VCAM.S.conr1, VCAM.S.conr2, VCAM.S.conr3, VCAM.S.conr4, VCAM.S.conr5)

df.VCAM.coni <- data.frame(VCAM.V.coni1, VCAM.V.coni2, VCAM.V.coni3, VCAM.V.coni4, VCAM.V.coni5 +
                             VCAM.S.coni1, VCAM.S.coni2, VCAM.S.coni3, VCAM.S.coni4, VCAM.S.coni5)

df.VCAM.humi <- data.frame(VCAM.V.humi1, VCAM.V.humi2, VCAM.V.humi3, VCAM.V.humi4, VCAM.V.humi5 +
                             VCAM.S.humi1, VCAM.S.humi2, VCAM.S.humi3, VCAM.S.humi4, VCAM.S.humi5)

df.VCAM.benc <- data.frame(VCAM.V.benc1, VCAM.V.benc2, VCAM.V.benc3, VCAM.V.benc4, VCAM.V.benc5 +
                             VCAM.S.benc1, VCAM.S.benc2, VCAM.S.benc3, VCAM.S.benc4, VCAM.S.benc5)

df.VCAM.bend <- data.frame(VCAM.V.bend1, VCAM.V.bend2, VCAM.V.bend3, VCAM.V.bend4, VCAM.V.bend5 +
                             VCAM.S.bend1, VCAM.S.bend2, VCAM.S.bend3, VCAM.S.bend4, VCAM.S.bend5)

df.VCAM.unic <- data.frame(VCAM.V.unic1, VCAM.V.unic2, VCAM.V.unic3, VCAM.V.unic4, VCAM.V.unic5 +
                             VCAM.S.unic1, VCAM.S.unic2, VCAM.S.unic3, VCAM.S.unic4, VCAM.S.unic5)

df.VCAM.unin <- data.frame(VCAM.V.unin1, VCAM.V.unin2, VCAM.V.unin3, VCAM.V.unin4, VCAM.V.unin5 +
                             VCAM.S.unin1, VCAM.S.unin2, VCAM.S.unin3, VCAM.S.unin4, VCAM.S.unin5)

df.VCAM.unit <- data.frame(VCAM.V.unit1, VCAM.V.unit2, VCAM.V.unit3, VCAM.V.unit4, VCAM.V.unit5 +
                             VCAM.S.unit1, VCAM.S.unit2, VCAM.S.unit3, VCAM.S.unit4, VCAM.S.unit5)

# AIC of each scale

item_intercor(df.VCAM.achi)
item_intercor(df.VCAM.benc)
item_intercor(df.VCAM.bend)
item_intercor(df.VCAM.coni)
item_intercor(df.VCAM.conr)
item_intercor(df.VCAM.face)
item_intercor(df.VCAM.hedo)
item_intercor(df.VCAM.humi)
item_intercor(df.VCAM.powd)
item_intercor(df.VCAM.powr)
item_intercor(df.VCAM.sda)
item_intercor(df.VCAM.sdt)
item_intercor(df.VCAM.secp)
item_intercor(df.VCAM.secs)
item_intercor(df.VCAM.stim)
item_intercor(df.VCAM.trad)
item_intercor(df.VCAM.unic)
item_intercor(df.VCAM.unin)
item_intercor(df.VCAM.unit)


sink(file='VCAMAICs.txt')
item_intercor(df.VCAM.achi)
item_intercor(df.VCAM.benc)
item_intercor(df.VCAM.bend)
item_intercor(df.VCAM.coni)
item_intercor(df.VCAM.conr)
item_intercor(df.VCAM.face)
item_intercor(df.VCAM.hedo)
item_intercor(df.VCAM.humi)
item_intercor(df.VCAM.powd)
item_intercor(df.VCAM.powr)
item_intercor(df.VCAM.sda)
item_intercor(df.VCAM.sdt)
item_intercor(df.VCAM.secp)
item_intercor(df.VCAM.secs)
item_intercor(df.VCAM.stim)
item_intercor(df.VCAM.trad)
item_intercor(df.VCAM.unic)
item_intercor(df.VCAM.unin)
item_intercor(df.VCAM.unit)
sink()


# 10/12/2022 add: taking away -2s

VCAMnonegs <- VCAM

VCAMnonegs[VCAMnonegs == -2] <- 0

attach(VCAMnonegs)

nonegs.df.VCAM.sdt <- data.frame(VCAM.V.sdt1, VCAM.V.sdt2, VCAM.V.sdt3, VCAM.V.sdt4, VCAM.V.sdt5, 
                            VCAM.S.sdt1, VCAM.S.sdt2, VCAM.S.sdt3, VCAM.S.sdt4, VCAM.S.sdt5)

nonegs.df.VCAM.sda <- data.frame(VCAM.V.sda1, VCAM.V.sda2, VCAM.V.sda3, VCAM.V.sda4, VCAM.V.sda5, 
                            VCAM.S.sda1, VCAM.S.sda2, VCAM.S.sda3, VCAM.S.sda4, VCAM.S.sda5)

nonegs.df.VCAM.stim <- data.frame(VCAM.V.stim1, VCAM.V.stim2, VCAM.V.stim3, VCAM.V.stim4, VCAM.V.stim5, 
                             VCAM.S.stim1, VCAM.S.stim2, VCAM.S.stim3, VCAM.S.stim4, VCAM.S.stim5)

nonegs.df.VCAM.hedo <- data.frame(VCAM.V.hedo1, VCAM.V.hedo2, VCAM.V.hedo3, VCAM.V.hedo4, VCAM.V.hedo5, 
                             VCAM.S.hedo1, VCAM.S.hedo2, VCAM.S.hedo3, VCAM.S.hedo4, VCAM.S.hedo5)

nonegs.df.VCAM.achi <- data.frame(VCAM.V.achi1, VCAM.V.achi2, VCAM.V.achi3, VCAM.V.achi4, VCAM.V.achi5, 
                             VCAM.S.achi1, VCAM.S.achi2, VCAM.S.achi3, VCAM.S.achi4, VCAM.S.achi5)

nonegs.df.VCAM.powd <- data.frame(VCAM.V.powd1, VCAM.V.powd2, VCAM.V.powd3, VCAM.V.powd4, VCAM.V.powd5, 
                             VCAM.S.powd1, VCAM.S.powd2, VCAM.S.powd3, VCAM.S.powd4, VCAM.S.powd5)

nonegs.df.VCAM.powr <- data.frame(VCAM.V.powr1, VCAM.V.powr2, VCAM.V.powr3, VCAM.V.powr4, VCAM.V.powr5, 
                             VCAM.S.powr1, VCAM.S.powr2, VCAM.S.powr3, VCAM.S.powr4, VCAM.S.powr5)

nonegs.df.VCAM.face <- data.frame(VCAM.V.face1, VCAM.V.face2, VCAM.V.face3, VCAM.V.face4, VCAM.V.face5, 
                             VCAM.S.face1, VCAM.S.face2, VCAM.S.face3, VCAM.S.face4, VCAM.S.face5)

nonegs.df.VCAM.secp <- data.frame(VCAM.V.secp1, VCAM.V.secp2, VCAM.V.secp3, VCAM.V.secp4, VCAM.V.secp5, 
                             VCAM.S.secp1, VCAM.S.secp2, VCAM.S.secp3, VCAM.S.secp4, VCAM.S.secp5)

nonegs.df.VCAM.secs <- data.frame(VCAM.V.secs1, VCAM.V.secs2, VCAM.V.secs3, VCAM.V.secs4, VCAM.V.secs5, 
                             VCAM.S.secs1, VCAM.S.secs2, VCAM.S.secs3, VCAM.S.secs4, VCAM.S.secs5)

nonegs.df.VCAM.trad <- data.frame(VCAM.V.trad1, VCAM.V.trad2, VCAM.V.trad3, VCAM.V.trad4, VCAM.V.trad5, 
                             VCAM.S.trad1, VCAM.S.trad2, VCAM.S.trad3, VCAM.S.trad4, VCAM.S.trad5)

nonegs.df.VCAM.conr <- data.frame(VCAM.V.conr1, VCAM.V.conr2, VCAM.V.conr3, VCAM.V.conr4, VCAM.V.conr5, 
                             VCAM.S.conr1, VCAM.S.conr2, VCAM.S.conr3, VCAM.S.conr4, VCAM.S.conr5)

nonegs.df.VCAM.coni <- data.frame(VCAM.V.coni1, VCAM.V.coni2, VCAM.V.coni3, VCAM.V.coni4, VCAM.V.coni5, 
                             VCAM.S.coni1, VCAM.S.coni2, VCAM.S.coni3, VCAM.S.coni4, VCAM.S.coni5)

nonegs.df.VCAM.humi <- data.frame(VCAM.V.humi1, VCAM.V.humi2, VCAM.V.humi3, VCAM.V.humi4, VCAM.V.humi5, 
                             VCAM.S.humi1, VCAM.S.humi2, VCAM.S.humi3, VCAM.S.humi4, VCAM.S.humi5)

nonegs.df.VCAM.benc <- data.frame(VCAM.V.benc1, VCAM.V.benc2, VCAM.V.benc3, VCAM.V.benc4, VCAM.V.benc5, 
                             VCAM.S.benc1, VCAM.S.benc2, VCAM.S.benc3, VCAM.S.benc4, VCAM.S.benc5)

nonegs.df.VCAM.bend <- data.frame(VCAM.V.bend1, VCAM.V.bend2, VCAM.V.bend3, VCAM.V.bend4, VCAM.V.bend5, 
                             VCAM.S.bend1, VCAM.S.bend2, VCAM.S.bend3, VCAM.S.bend4, VCAM.S.bend5)

nonegs.df.VCAM.unic <- data.frame(VCAM.V.unic1, VCAM.V.unic2, VCAM.V.unic3, VCAM.V.unic4, VCAM.V.unic5, 
                             VCAM.S.unic1, VCAM.S.unic2, VCAM.S.unic3, VCAM.S.unic4, VCAM.S.unic5)

nonegs.df.VCAM.unin <- data.frame(VCAM.V.unin1, VCAM.V.unin2, VCAM.V.unin3, VCAM.V.unin4, VCAM.V.unin5, 
                             VCAM.S.unin1, VCAM.S.unin2, VCAM.S.unin3, VCAM.S.unin4, VCAM.S.unin5)

nonegs.df.VCAM.unit <- data.frame(VCAM.V.unit1, VCAM.V.unit2, VCAM.V.unit3, VCAM.V.unit4, VCAM.V.unit5, 
                             VCAM.S.unit1, VCAM.S.unit2, VCAM.S.unit3, VCAM.S.unit4, VCAM.S.unit5)



item_intercor(nonegs.df.VCAM.achi)
item_intercor(nonegs.df.VCAM.benc)
item_intercor(nonegs.df.VCAM.bend)
item_intercor(nonegs.df.VCAM.coni)
item_intercor(nonegs.df.VCAM.conr)
item_intercor(nonegs.df.VCAM.face)
item_intercor(nonegs.df.VCAM.hedo)
item_intercor(nonegs.df.VCAM.humi)
item_intercor(nonegs.df.VCAM.powd)
item_intercor(nonegs.df.VCAM.powr)
item_intercor(nonegs.df.VCAM.sda)
item_intercor(nonegs.df.VCAM.sdt)
item_intercor(nonegs.df.VCAM.secp)
item_intercor(nonegs.df.VCAM.secs)
item_intercor(nonegs.df.VCAM.stim)
item_intercor(nonegs.df.VCAM.trad)
item_intercor(nonegs.df.VCAM.unic)
item_intercor(nonegs.df.VCAM.unin)
item_intercor(nonegs.df.VCAM.unit)






#Things broke here 10/12/2022. Check this

#reliabilities

# detach ggplot
?alpha
detach(ggplot2)
library(psych)
?alpha
detach(scales)

summary(alpha(nonegs.df.VCAM.achi))
summary(alpha(nonegs.df.VCAM.benc))
summary(alpha(nonegs.df.VCAM.bend))
summary(alpha(nonegs.df.VCAM.coni))
summary(alpha(nonegs.df.VCAM.conr))
summary(alpha(nonegs.df.VCAM.face))
summary(alpha(nonegs.df.VCAM.hedo))
summary(alpha(nonegs.df.VCAM.humi))
summary(alpha(nonegs.df.VCAM.powd))
summary(alpha(nonegs.df.VCAM.powr))
summary(alpha(nonegs.df.VCAM.sda))
summary(alpha(nonegs.df.VCAM.sdt))
summary(alpha(nonegs.df.VCAM.secp))
summary(alpha(nonegs.df.VCAM.secs))
summary(alpha(nonegs.df.VCAM.stim))
summary(alpha(nonegs.df.VCAM.trad))
summary(alpha(nonegs.df.VCAM.unic))
summary(alpha(nonegs.df.VCAM.unin))
summary(alpha(nonegs.df.VCAM.unit))



# Scale with just violations

V.nonegs.df.VCAM.sdt <- data.frame(VCAM.V.sdt1, VCAM.V.sdt2, VCAM.V.sdt3, VCAM.V.sdt4, VCAM.V.sdt5)

V.nonegs.df.VCAM.sda <- data.frame(VCAM.V.sda1, VCAM.V.sda2, VCAM.V.sda3, VCAM.V.sda4, VCAM.V.sda5)

V.nonegs.df.VCAM.stim <- data.frame(VCAM.V.stim1, VCAM.V.stim2, VCAM.V.stim3, VCAM.V.stim4, VCAM.V.stim5)

V.nonegs.df.VCAM.hedo <- data.frame(VCAM.V.hedo1, VCAM.V.hedo2, VCAM.V.hedo3, VCAM.V.hedo4, VCAM.V.hedo5)

V.nonegs.df.VCAM.achi <- data.frame(VCAM.V.achi1, VCAM.V.achi2, VCAM.V.achi3, VCAM.V.achi4, VCAM.V.achi5)

V.nonegs.df.VCAM.powd <- data.frame(VCAM.V.powd1, VCAM.V.powd2, VCAM.V.powd3, VCAM.V.powd4, VCAM.V.powd5)

V.nonegs.df.VCAM.powr <- data.frame(VCAM.V.powr1, VCAM.V.powr2, VCAM.V.powr3, VCAM.V.powr4, VCAM.V.powr5)

V.nonegs.df.VCAM.face <- data.frame(VCAM.V.face1, VCAM.V.face2, VCAM.V.face3, VCAM.V.face4, VCAM.V.face5)

V.nonegs.df.VCAM.secp <- data.frame(VCAM.V.secp1, VCAM.V.secp2, VCAM.V.secp3, VCAM.V.secp4, VCAM.V.secp5)

V.nonegs.df.VCAM.secs <- data.frame(VCAM.V.secs1, VCAM.V.secs2, VCAM.V.secs3, VCAM.V.secs4, VCAM.V.secs5)

V.nonegs.df.VCAM.trad <- data.frame(VCAM.V.trad1, VCAM.V.trad2, VCAM.V.trad3, VCAM.V.trad4, VCAM.V.trad5)

V.nonegs.df.VCAM.conr <- data.frame(VCAM.V.conr1, VCAM.V.conr2, VCAM.V.conr3, VCAM.V.conr4, VCAM.V.conr5)

V.nonegs.df.VCAM.coni <- data.frame(VCAM.V.coni1, VCAM.V.coni2, VCAM.V.coni3, VCAM.V.coni4, VCAM.V.coni5)

V.nonegs.df.VCAM.humi <- data.frame(VCAM.V.humi1, VCAM.V.humi2, VCAM.V.humi3, VCAM.V.humi4, VCAM.V.humi5)

V.nonegs.df.VCAM.benc <- data.frame(VCAM.V.benc1, VCAM.V.benc2, VCAM.V.benc3, VCAM.V.benc4, VCAM.V.benc5)

V.nonegs.df.VCAM.bend <- data.frame(VCAM.V.bend1, VCAM.V.bend2, VCAM.V.bend3, VCAM.V.bend4, VCAM.V.bend5)

V.nonegs.df.VCAM.unic <- data.frame(VCAM.V.unic1, VCAM.V.unic2, VCAM.V.unic3, VCAM.V.unic4, VCAM.V.unic5)

V.nonegs.df.VCAM.unin <- data.frame(VCAM.V.unin1, VCAM.V.unin2, VCAM.V.unin3, VCAM.V.unin4, VCAM.V.unin5)

V.nonegs.df.VCAM.unit <- data.frame(VCAM.V.unit1, VCAM.V.unit2, VCAM.V.unit3, VCAM.V.unit4, VCAM.V.unit5)

# Scale with just satisfactions


S.nonegs.df.VCAM.sdt <- data.frame(VCAM.S.sdt1, VCAM.S.sdt2, VCAM.S.sdt3, VCAM.S.sdt4, VCAM.S.sdt5)

S.nonegs.df.VCAM.sda <- data.frame(VCAM.S.sda1, VCAM.S.sda2, VCAM.S.sda3, VCAM.S.sda4, VCAM.S.sda5)

S.nonegs.df.VCAM.stim <- data.frame(VCAM.S.stim1, VCAM.S.stim2, VCAM.S.stim3, VCAM.S.stim4, VCAM.S.stim5)

S.nonegs.df.VCAM.hedo <- data.frame(VCAM.S.hedo1, VCAM.S.hedo2, VCAM.S.hedo3, VCAM.S.hedo4, VCAM.S.hedo5)

S.nonegs.df.VCAM.achi <- data.frame(VCAM.S.achi1, VCAM.S.achi2, VCAM.S.achi3, VCAM.S.achi4, VCAM.S.achi5)

S.nonegs.df.VCAM.powd <- data.frame(VCAM.S.powd1, VCAM.S.powd2, VCAM.S.powd3, VCAM.S.powd4, VCAM.S.powd5)

S.nonegs.df.VCAM.powr <- data.frame(VCAM.S.powr1, VCAM.S.powr2, VCAM.S.powr3, VCAM.S.powr4, VCAM.S.powr5)

S.nonegs.df.VCAM.face <- data.frame(VCAM.S.face1, VCAM.S.face2, VCAM.S.face3, VCAM.S.face4, VCAM.S.face5)

S.nonegs.df.VCAM.secp <- data.frame(VCAM.S.secp1, VCAM.S.secp2, VCAM.S.secp3, VCAM.S.secp4, VCAM.S.secp5)

S.nonegs.df.VCAM.secs <- data.frame(VCAM.S.secs1, VCAM.S.secs2, VCAM.S.secs3, VCAM.S.secs4, VCAM.S.secs5)

S.nonegs.df.VCAM.trad <- data.frame(VCAM.S.trad1, VCAM.S.trad2, VCAM.S.trad3, VCAM.S.trad4, VCAM.S.trad5)

S.nonegs.df.VCAM.conr <- data.frame(VCAM.S.conr1, VCAM.S.conr2, VCAM.S.conr3, VCAM.S.conr4, VCAM.S.conr5)

S.nonegs.df.VCAM.coni <- data.frame(VCAM.S.coni1, VCAM.S.coni2, VCAM.S.coni3, VCAM.S.coni4, VCAM.S.coni5)

S.nonegs.df.VCAM.humi <- data.frame(VCAM.S.humi1, VCAM.S.humi2, VCAM.S.humi3, VCAM.S.humi4, VCAM.S.humi5)

S.nonegs.df.VCAM.benc <- data.frame(VCAM.S.benc1, VCAM.S.benc2, VCAM.S.benc3, VCAM.S.benc4, VCAM.S.benc5)

S.nonegs.df.VCAM.bend <- data.frame(VCAM.S.bend1, VCAM.S.bend2, VCAM.S.bend3, VCAM.S.bend4, VCAM.S.bend5)

S.nonegs.df.VCAM.unic <- data.frame(VCAM.S.unic1, VCAM.S.unic2, VCAM.S.unic3, VCAM.S.unic4, VCAM.S.unic5)

S.nonegs.df.VCAM.unin <- data.frame(VCAM.S.unin1, VCAM.S.unin2, VCAM.S.unin3, VCAM.S.unin4, VCAM.S.unin5)

S.nonegs.df.VCAM.unit <- data.frame(VCAM.S.unit1, VCAM.S.unit2, VCAM.S.unit3, VCAM.S.unit4, VCAM.S.unit5)


## Inter-cors for smaller scales

library(performance)

item_intercor(V.nonegs.df.VCAM.achi)
item_intercor(V.nonegs.df.VCAM.benc)
item_intercor(V.nonegs.df.VCAM.bend)
item_intercor(V.nonegs.df.VCAM.coni)
item_intercor(V.nonegs.df.VCAM.conr)
item_intercor(V.nonegs.df.VCAM.face)
item_intercor(V.nonegs.df.VCAM.hedo)
item_intercor(V.nonegs.df.VCAM.humi)
item_intercor(V.nonegs.df.VCAM.powd)
item_intercor(V.nonegs.df.VCAM.powr)
item_intercor(V.nonegs.df.VCAM.sda)
item_intercor(V.nonegs.df.VCAM.sdt)
item_intercor(V.nonegs.df.VCAM.secp)
item_intercor(V.nonegs.df.VCAM.secs)
item_intercor(V.nonegs.df.VCAM.stim)
item_intercor(V.nonegs.df.VCAM.trad)
item_intercor(V.nonegs.df.VCAM.unic)
item_intercor(V.nonegs.df.VCAM.unin)
item_intercor(V.nonegs.df.VCAM.unit)

item_intercor(S.nonegs.df.VCAM.achi)
item_intercor(S.nonegs.df.VCAM.benc)
item_intercor(S.nonegs.df.VCAM.bend)
item_intercor(S.nonegs.df.VCAM.coni)
item_intercor(S.nonegs.df.VCAM.conr)
item_intercor(S.nonegs.df.VCAM.face)
item_intercor(S.nonegs.df.VCAM.hedo)
item_intercor(S.nonegs.df.VCAM.humi)
item_intercor(S.nonegs.df.VCAM.powd)
item_intercor(S.nonegs.df.VCAM.powr)
item_intercor(S.nonegs.df.VCAM.sda)
item_intercor(S.nonegs.df.VCAM.sdt)
item_intercor(S.nonegs.df.VCAM.secp)
item_intercor(S.nonegs.df.VCAM.secs)
item_intercor(S.nonegs.df.VCAM.stim)
item_intercor(S.nonegs.df.VCAM.trad)
item_intercor(S.nonegs.df.VCAM.unic)
item_intercor(S.nonegs.df.VCAM.unin)
item_intercor(S.nonegs.df.VCAM.unit)


## Reliabilities for smaller scales

summary(alpha(V.nonegs.df.VCAM.achi))
summary(alpha(V.nonegs.df.VCAM.benc))
summary(alpha(V.nonegs.df.VCAM.bend))
summary(alpha(V.nonegs.df.VCAM.coni))
summary(alpha(V.nonegs.df.VCAM.conr))
summary(alpha(V.nonegs.df.VCAM.face))
summary(alpha(V.nonegs.df.VCAM.hedo))
summary(alpha(V.nonegs.df.VCAM.humi))
summary(alpha(V.nonegs.df.VCAM.powd))
summary(alpha(V.nonegs.df.VCAM.powr))
summary(alpha(V.nonegs.df.VCAM.sda))
summary(alpha(V.nonegs.df.VCAM.sdt))
summary(alpha(V.nonegs.df.VCAM.secp))
summary(alpha(V.nonegs.df.VCAM.secs))
summary(alpha(V.nonegs.df.VCAM.stim))
summary(alpha(V.nonegs.df.VCAM.trad))
summary(alpha(V.nonegs.df.VCAM.unic))
summary(alpha(V.nonegs.df.VCAM.unin))
summary(alpha(V.nonegs.df.VCAM.unit))

summary(alpha(S.nonegs.df.VCAM.achi))
summary(alpha(S.nonegs.df.VCAM.benc))
summary(alpha(S.nonegs.df.VCAM.bend))
summary(alpha(S.nonegs.df.VCAM.coni))
summary(alpha(S.nonegs.df.VCAM.conr))
summary(alpha(S.nonegs.df.VCAM.face))
summary(alpha(S.nonegs.df.VCAM.hedo))
summary(alpha(S.nonegs.df.VCAM.humi))
summary(alpha(S.nonegs.df.VCAM.powd))
summary(alpha(S.nonegs.df.VCAM.powr))
summary(alpha(S.nonegs.df.VCAM.sda))
summary(alpha(S.nonegs.df.VCAM.sdt))
summary(alpha(S.nonegs.df.VCAM.secp))
summary(alpha(S.nonegs.df.VCAM.secs))
summary(alpha(S.nonegs.df.VCAM.stim))
summary(alpha(S.nonegs.df.VCAM.trad))
summary(alpha(S.nonegs.df.VCAM.unic))
summary(alpha(S.nonegs.df.VCAM.unin))
summary(alpha(S.nonegs.df.VCAM.unit))


### end 10/12/22. Continue here with correlations among scales, see if there are items that should be dropped

### Also perform reliability analysis at higher levels, and try forming scales based on EFA factor loadings rather than Schwartz scales

# Creating quadrant-level scales

# Violations

#IMPORTANT: Using version with no negatives :D

attach(VCAMnonegs)

VCAM.V.SelfTrans <- 
  VCAM.V.unin1 + VCAM.V.unin2 + VCAM.V.unin3 + VCAM.V.unin4 + VCAM.V.unin5 +
  VCAM.V.unic1 + VCAM.V.unic2 + VCAM.V.unic3 + VCAM.V.unic4 + VCAM.V.unic5 +
  VCAM.V.unit1 + VCAM.V.unit2 + VCAM.V.unit3 + VCAM.V.unit4 + VCAM.V.unit5 +
  VCAM.V.benc1 + VCAM.V.benc2 + VCAM.V.benc3 + VCAM.V.benc4 + VCAM.V.benc5 +
  VCAM.V.bend1 + VCAM.V.bend2 + VCAM.V.bend3 + VCAM.V.bend4 + VCAM.V.bend5

VCAM.V.SelfEnh <- 
  VCAM.V.achi1 + VCAM.V.achi2 + VCAM.V.achi3 + VCAM.V.achi4 + VCAM.V.achi5 +
  VCAM.V.powd1 + VCAM.V.powd2 + VCAM.V.powd3 + VCAM.V.powd4 + VCAM.V.powd5 +
  VCAM.V.powr1 + VCAM.V.powr2 + VCAM.V.powr3 + VCAM.V.powr4 + VCAM.V.powr5

VCAM.V.OpenTCh <- 
  VCAM.V.sdt1 + VCAM.V.sdt2 + VCAM.V.sdt3 + VCAM.V.sdt4 + VCAM.V.sdt5 +
  VCAM.V.sda1 + VCAM.V.sda2 + VCAM.V.sda3 + VCAM.V.sda4 + VCAM.V.sda5 +
  VCAM.V.stim1 + VCAM.V.stim2 + VCAM.V.stim3 + VCAM.V.stim4 + VCAM.V.stim5 +
  VCAM.V.hedo1 + VCAM.V.hedo2 + VCAM.V.hedo3 + VCAM.V.hedo4 + VCAM.V.hedo5

VCAM.V.Conserv <- 
  VCAM.V.secp1 + VCAM.V.secp2 + VCAM.V.secp3 + VCAM.V.secp4 + VCAM.V.secp5 +
  VCAM.V.secs1 + VCAM.V.secs2 + VCAM.V.secs3 + VCAM.V.secs4 + VCAM.V.secs5 +
  VCAM.V.trad1 + VCAM.V.trad2 + VCAM.V.trad3 + VCAM.V.trad4 + VCAM.V.trad5 +
  VCAM.V.conr1 + VCAM.V.conr2 + VCAM.V.conr3 + VCAM.V.conr4 + VCAM.V.conr5 +
  VCAM.V.coni1 + VCAM.V.coni2 + VCAM.V.coni3 + VCAM.V.coni4 + VCAM.V.coni5

#Satisfactions

VCAM.S.SelfTrans <- 
  VCAM.S.unin1 + VCAM.S.unin2 + VCAM.S.unin3 + VCAM.S.unin4 + VCAM.S.unin5 +
  VCAM.S.unic1 + VCAM.S.unic2 + VCAM.S.unic3 + VCAM.S.unic4 + VCAM.S.unic5 +
  VCAM.S.unit1 + VCAM.S.unit2 + VCAM.S.unit3 + VCAM.S.unit4 + VCAM.S.unit5 +
  VCAM.S.benc1 + VCAM.S.benc2 + VCAM.S.benc3 + VCAM.S.benc4 + VCAM.S.benc5 +
  VCAM.S.bend1 + VCAM.S.bend2 + VCAM.S.bend3 + VCAM.S.bend4 + VCAM.S.bend5

VCAM.S.SelfEnh <- 
  VCAM.S.achi1 + VCAM.S.achi2 + VCAM.S.achi3 + VCAM.S.achi4 + VCAM.S.achi5 +
  VCAM.S.powd1 + VCAM.S.powd2 + VCAM.S.powd3 + VCAM.S.powd4 + VCAM.S.powd5 +
  VCAM.S.powr1 + VCAM.S.powr2 + VCAM.S.powr3 + VCAM.S.powr4 + VCAM.S.powr5

VCAM.S.OpenTCh <- 
  VCAM.S.sdt1 + VCAM.S.sdt2 + VCAM.S.sdt3 + VCAM.S.sdt4 + VCAM.S.sdt5 +
  VCAM.S.sda1 + VCAM.S.sda2 + VCAM.S.sda3 + VCAM.S.sda4 + VCAM.S.sda5 +
  VCAM.S.stim1 + VCAM.S.stim2 + VCAM.S.stim3 + VCAM.S.stim4 + VCAM.S.stim5 +
  VCAM.S.hedo1 + VCAM.S.hedo2 + VCAM.S.hedo3 + VCAM.S.hedo4 + VCAM.S.hedo5

VCAM.S.Conserv <- 
  VCAM.S.secp1 + VCAM.S.secp2 + VCAM.S.secp3 + VCAM.S.secp4 + VCAM.S.secp5 +
  VCAM.S.secs1 + VCAM.S.secs2 + VCAM.S.secs3 + VCAM.S.secs4 + VCAM.S.secs5 +
  VCAM.S.trad1 + VCAM.S.trad2 + VCAM.S.trad3 + VCAM.S.trad4 + VCAM.S.trad5 +
  VCAM.S.conr1 + VCAM.S.conr2 + VCAM.S.conr3 + VCAM.S.conr4 + VCAM.S.conr5 +
  VCAM.S.coni1 + VCAM.S.coni2 + VCAM.S.coni3 + VCAM.S.coni4 + VCAM.S.coni5


#making datasets for quadrants

V.nonegs.df.VCAM.SelfTrans <- data.frame(VCAM.V.unin1, VCAM.V.unin2, VCAM.V.unin3, VCAM.V.unin4, VCAM.V.unin5,
                                         VCAM.V.unic1, VCAM.V.unic2, VCAM.V.unic3, VCAM.V.unic4, VCAM.V.unic5,
                                         VCAM.V.unit1, VCAM.V.unit2, VCAM.V.unit3, VCAM.V.unit4, VCAM.V.unit5,
                                         VCAM.V.benc1, VCAM.V.benc2, VCAM.V.benc3, VCAM.V.benc4, VCAM.V.benc5,
                                         VCAM.V.bend1, VCAM.V.bend2, VCAM.V.bend3, VCAM.V.bend4, VCAM.V.bend5)

V.nonegs.df.VCAM.SelfEnh <- data.frame(VCAM.V.achi1, VCAM.V.achi2, VCAM.V.achi3, VCAM.V.achi4, VCAM.V.achi5,
                                       VCAM.V.powd1, VCAM.V.powd2, VCAM.V.powd3, VCAM.V.powd4, VCAM.V.powd5,
                                       VCAM.V.powr1, VCAM.V.powr2, VCAM.V.powr3, VCAM.V.powr4, VCAM.V.powr5)

V.nonegs.df.VCAM.OpenTCh <- data.frame(VCAM.V.sdt1, VCAM.V.sdt2, VCAM.V.sdt3, VCAM.V.sdt4, VCAM.V.sdt5,
                                       VCAM.V.sda1, VCAM.V.sda2, VCAM.V.sda3, VCAM.V.sda4, VCAM.V.sda5,
                                       VCAM.V.stim1, VCAM.V.stim2, VCAM.V.stim3, VCAM.V.stim4, VCAM.V.stim5,
                                       VCAM.V.hedo1, VCAM.V.hedo2, VCAM.V.hedo3, VCAM.V.hedo4, VCAM.V.hedo5)

V.nonegs.df.VCAM.Conserv <- data.frame(VCAM.V.secp1, VCAM.V.secp2, VCAM.V.secp3, VCAM.V.secp4, VCAM.V.secp5,
                                       VCAM.V.secs1, VCAM.V.secs2, VCAM.V.secs3, VCAM.V.secs4, VCAM.V.secs5,
                                       VCAM.V.trad1, VCAM.V.trad2, VCAM.V.trad3, VCAM.V.trad4, VCAM.V.trad5,
                                       VCAM.V.conr1, VCAM.V.conr2, VCAM.V.conr3, VCAM.V.conr4, VCAM.V.conr5,
                                       VCAM.V.coni1, VCAM.V.coni2, VCAM.V.coni3, VCAM.V.coni4, VCAM.V.coni5)


S.nonegs.df.VCAM.SelfTrans <- data.frame(VCAM.S.unin1, VCAM.S.unin2, VCAM.S.unin3, VCAM.S.unin4, VCAM.S.unin5,
                                         VCAM.S.unic1, VCAM.S.unic2, VCAM.S.unic3, VCAM.S.unic4, VCAM.S.unic5,
                                         VCAM.S.unit1, VCAM.S.unit2, VCAM.S.unit3, VCAM.S.unit4, VCAM.S.unit5,
                                         VCAM.S.benc1, VCAM.S.benc2, VCAM.S.benc3, VCAM.S.benc4, VCAM.S.benc5,
                                         VCAM.S.bend1, VCAM.S.bend2, VCAM.S.bend3, VCAM.S.bend4, VCAM.S.bend5)

S.nonegs.df.VCAM.SelfEnh <- data.frame(VCAM.S.achi1, VCAM.S.achi2, VCAM.S.achi3, VCAM.S.achi4, VCAM.S.achi5,
                                       VCAM.S.powd1, VCAM.S.powd2, VCAM.S.powd3, VCAM.S.powd4, VCAM.S.powd5,
                                       VCAM.S.powr1, VCAM.S.powr2, VCAM.S.powr3, VCAM.S.powr4, VCAM.S.powr5)

S.nonegs.df.VCAM.OpenTCh <- data.frame(VCAM.S.sdt1, VCAM.S.sdt2, VCAM.S.sdt3, VCAM.S.sdt4, VCAM.S.sdt5,
                                       VCAM.S.sda1, VCAM.S.sda2, VCAM.S.sda3, VCAM.S.sda4, VCAM.S.sda5,
                                       VCAM.S.stim1, VCAM.S.stim2, VCAM.S.stim3, VCAM.S.stim4, VCAM.S.stim5,
                                       VCAM.S.hedo1, VCAM.S.hedo2, VCAM.S.hedo3, VCAM.S.hedo4, VCAM.S.hedo5)

S.nonegs.df.VCAM.Conserv <- data.frame(VCAM.S.secp1, VCAM.S.secp2, VCAM.S.secp3, VCAM.S.secp4, VCAM.S.secp5,
                                        VCAM.S.secs1, VCAM.S.secs2, VCAM.S.secs3, VCAM.S.secs4, VCAM.S.secs5,
                                        VCAM.S.trad1, VCAM.S.trad2, VCAM.S.trad3, VCAM.S.trad4, VCAM.S.trad5,
                                        VCAM.S.conr1, VCAM.S.conr2, VCAM.S.conr3, VCAM.S.conr4, VCAM.S.conr5,
                                        VCAM.S.coni1, VCAM.S.coni2, VCAM.S.coni3, VCAM.S.coni4, VCAM.S.coni5)


# Bigger datasets

nonegs.df.VCAM.SelfTrans <- data.frame(VCAM.V.unin1, VCAM.V.unin2, VCAM.V.unin3, VCAM.V.unin4, VCAM.V.unin5,
                                       VCAM.V.unic1, VCAM.V.unic2, VCAM.V.unic3, VCAM.V.unic4, VCAM.V.unic5,
                                       VCAM.V.unit1, VCAM.V.unit2, VCAM.V.unit3, VCAM.V.unit4, VCAM.V.unit5,
                                       VCAM.V.benc1, VCAM.V.benc2, VCAM.V.benc3, VCAM.V.benc4, VCAM.V.benc5,
                                       VCAM.V.bend1, VCAM.V.bend2, VCAM.V.bend3, VCAM.V.bend4, VCAM.V.bend5,
                                       VCAM.S.unin1, VCAM.S.unin2, VCAM.S.unin3, VCAM.S.unin4, VCAM.S.unin5,
                                       VCAM.S.unic1, VCAM.S.unic2, VCAM.S.unic3, VCAM.S.unic4, VCAM.S.unic5,
                                       VCAM.S.unit1, VCAM.S.unit2, VCAM.S.unit3, VCAM.S.unit4, VCAM.S.unit5,
                                       VCAM.S.benc1, VCAM.S.benc2, VCAM.S.benc3, VCAM.S.benc4, VCAM.S.benc5,
                                       VCAM.S.bend1, VCAM.S.bend2, VCAM.S.bend3, VCAM.S.bend4, VCAM.S.bend5)

nonegs.df.VCAM.SelfEnh <- data.frame(VCAM.V.achi1, VCAM.V.achi2, VCAM.V.achi3, VCAM.V.achi4, VCAM.V.achi5,
                                     VCAM.V.powd1, VCAM.V.powd2, VCAM.V.powd3, VCAM.V.powd4, VCAM.V.powd5,
                                     VCAM.V.powr1, VCAM.V.powr2, VCAM.V.powr3, VCAM.V.powr4, VCAM.V.powr5,
                                     VCAM.S.achi1, VCAM.S.achi2, VCAM.S.achi3, VCAM.S.achi4, VCAM.S.achi5,
                                     VCAM.S.powd1, VCAM.S.powd2, VCAM.S.powd3, VCAM.S.powd4, VCAM.S.powd5,
                                     VCAM.S.powr1, VCAM.S.powr2, VCAM.S.powr3, VCAM.S.powr4, VCAM.S.powr5)

nonegs.df.VCAM.OpenTCh <- data.frame(VCAM.V.sdt1, VCAM.V.sdt2, VCAM.V.sdt3, VCAM.V.sdt4, VCAM.V.sdt5,
                                     VCAM.V.sda1, VCAM.V.sda2, VCAM.V.sda3, VCAM.V.sda4, VCAM.V.sda5,
                                     VCAM.V.stim1, VCAM.V.stim2, VCAM.V.stim3, VCAM.V.stim4, VCAM.V.stim5,
                                     VCAM.V.hedo1, VCAM.V.hedo2, VCAM.V.hedo3, VCAM.V.hedo4, VCAM.V.hedo5,
                                     VCAM.S.sdt1, VCAM.S.sdt2, VCAM.S.sdt3, VCAM.S.sdt4, VCAM.S.sdt5,
                                     VCAM.S.sda1, VCAM.S.sda2, VCAM.S.sda3, VCAM.S.sda4, VCAM.S.sda5,
                                     VCAM.S.stim1, VCAM.S.stim2, VCAM.S.stim3, VCAM.S.stim4, VCAM.S.stim5,
                                     VCAM.S.hedo1, VCAM.S.hedo2, VCAM.S.hedo3, VCAM.S.hedo4, VCAM.S.hedo5)

nonegs.df.VCAM.Conserv <- data.frame(VCAM.V.secp1, VCAM.V.secp2, VCAM.V.secp3, VCAM.V.secp4, VCAM.V.secp5,
                                     VCAM.V.secs1, VCAM.V.secs2, VCAM.V.secs3, VCAM.V.secs4, VCAM.V.secs5,
                                     VCAM.V.trad1, VCAM.V.trad2, VCAM.V.trad3, VCAM.V.trad4, VCAM.V.trad5,
                                     VCAM.V.conr1, VCAM.V.conr2, VCAM.V.conr3, VCAM.V.conr4, VCAM.V.conr5,
                                     VCAM.V.coni1, VCAM.V.coni2, VCAM.V.coni3, VCAM.V.coni4, VCAM.V.coni5,
                                     VCAM.S.secp1, VCAM.S.secp2, VCAM.S.secp3, VCAM.S.secp4, VCAM.S.secp5,
                                     VCAM.S.secs1, VCAM.S.secs2, VCAM.S.secs3, VCAM.S.secs4, VCAM.S.secs5,
                                     VCAM.S.trad1, VCAM.S.trad2, VCAM.S.trad3, VCAM.S.trad4, VCAM.S.trad5,
                                     VCAM.S.conr1, VCAM.S.conr2, VCAM.S.conr3, VCAM.S.conr4, VCAM.S.conr5,
                                     VCAM.S.coni1, VCAM.S.coni2, VCAM.S.coni3, VCAM.S.coni4, VCAM.S.coni5)


# AIC

item_intercor(V.nonegs.df.VCAM.SelfTrans)
item_intercor(V.nonegs.df.VCAM.SelfEnh)
item_intercor(V.nonegs.df.VCAM.OpenTCh)
item_intercor(V.nonegs.df.VCAM.Conserv)

item_intercor(S.nonegs.df.VCAM.SelfTrans)
item_intercor(S.nonegs.df.VCAM.SelfEnh)
item_intercor(S.nonegs.df.VCAM.OpenTCh)
item_intercor(S.nonegs.df.VCAM.Conserv)

item_intercor(nonegs.df.VCAM.SelfTrans)
item_intercor(nonegs.df.VCAM.SelfEnh)
item_intercor(nonegs.df.VCAM.OpenTCh)
item_intercor(nonegs.df.VCAM.Conserv)

# Reliabilities

summary(alpha(V.nonegs.df.VCAM.SelfTrans))
summary(alpha(V.nonegs.df.VCAM.SelfEnh))
summary(alpha(V.nonegs.df.VCAM.OpenTCh))
summary(alpha(V.nonegs.df.VCAM.Conserv))

summary(alpha(S.nonegs.df.VCAM.SelfTrans))
summary(alpha(S.nonegs.df.VCAM.SelfEnh))
summary(alpha(S.nonegs.df.VCAM.OpenTCh))
summary(alpha(S.nonegs.df.VCAM.Conserv))

summary(alpha(nonegs.df.VCAM.SelfTrans))
summary(alpha(nonegs.df.VCAM.SelfEnh))
summary(alpha(nonegs.df.VCAM.OpenTCh))
summary(alpha(nonegs.df.VCAM.Conserv))


## Correlations among each scale

round(cor(V.nonegs.df.VCAM.achi), digits = 2)
round(cor(V.nonegs.df.VCAM.benc), digits = 2)
round(cor(V.nonegs.df.VCAM.bend), digits = 2)
round(cor(V.nonegs.df.VCAM.coni), digits = 2)
round(cor(V.nonegs.df.VCAM.conr), digits = 2)
round(cor(V.nonegs.df.VCAM.face), digits = 2)
round(cor(V.nonegs.df.VCAM.hedo), digits = 2)
round(cor(V.nonegs.df.VCAM.humi), digits = 2)
round(cor(V.nonegs.df.VCAM.powd), digits = 2)
round(cor(V.nonegs.df.VCAM.powr), digits = 2)
round(cor(V.nonegs.df.VCAM.sda), digits = 2)
round(cor(V.nonegs.df.VCAM.sdt), digits = 2)
round(cor(V.nonegs.df.VCAM.secp), digits = 2)
round(cor(V.nonegs.df.VCAM.secs), digits = 2)
round(cor(V.nonegs.df.VCAM.stim), digits = 2)
round(cor(V.nonegs.df.VCAM.trad), digits = 2)
round(cor(V.nonegs.df.VCAM.unic), digits = 2)
round(cor(V.nonegs.df.VCAM.unin), digits = 2)
round(cor(V.nonegs.df.VCAM.unit), digits = 2)
round(cor(S.nonegs.df.VCAM.achi), digits = 2)
round(cor(S.nonegs.df.VCAM.benc), digits = 2)
round(cor(S.nonegs.df.VCAM.bend), digits = 2)
round(cor(S.nonegs.df.VCAM.coni), digits = 2)
round(cor(S.nonegs.df.VCAM.conr), digits = 2)
round(cor(S.nonegs.df.VCAM.face), digits = 2)
round(cor(S.nonegs.df.VCAM.hedo), digits = 2)
round(cor(S.nonegs.df.VCAM.humi), digits = 2)
round(cor(S.nonegs.df.VCAM.powd), digits = 2)
round(cor(S.nonegs.df.VCAM.powr), digits = 2)
round(cor(S.nonegs.df.VCAM.sda), digits = 2)
round(cor(S.nonegs.df.VCAM.sdt), digits = 2)
round(cor(S.nonegs.df.VCAM.secp), digits = 2)
round(cor(S.nonegs.df.VCAM.secs), digits = 2)
round(cor(S.nonegs.df.VCAM.stim), digits = 2)
round(cor(S.nonegs.df.VCAM.trad), digits = 2)
round(cor(S.nonegs.df.VCAM.unic), digits = 2)
round(cor(S.nonegs.df.VCAM.unin), digits = 2)
round(cor(S.nonegs.df.VCAM.unit), digits = 2)
round(cor(nonegs.df.VCAM.achi), digits = 2)
round(cor(nonegs.df.VCAM.benc), digits = 2)
round(cor(nonegs.df.VCAM.bend), digits = 2)
round(cor(nonegs.df.VCAM.coni), digits = 2)
round(cor(nonegs.df.VCAM.conr), digits = 2)
round(cor(nonegs.df.VCAM.face), digits = 2)
round(cor(nonegs.df.VCAM.hedo), digits = 2)
round(cor(nonegs.df.VCAM.humi), digits = 2)
round(cor(nonegs.df.VCAM.powd), digits = 2)
round(cor(nonegs.df.VCAM.powr), digits = 2)
round(cor(nonegs.df.VCAM.sda), digits = 2)
round(cor(nonegs.df.VCAM.sdt), digits = 2)
round(cor(nonegs.df.VCAM.secp), digits = 2)
round(cor(nonegs.df.VCAM.secs), digits = 2)
round(cor(nonegs.df.VCAM.stim), digits = 2)
round(cor(nonegs.df.VCAM.trad), digits = 2)
round(cor(nonegs.df.VCAM.unic), digits = 2)
round(cor(nonegs.df.VCAM.unin), digits = 2)
round(cor(nonegs.df.VCAM.unit), digits = 2)
round(cor(V.nonegs.df.VCAM.SelfTrans), digits = 2)
round(cor(V.nonegs.df.VCAM.SelfEnh), digits = 2)
round(cor(V.nonegs.df.VCAM.OpenTCh), digits = 2)
round(cor(V.nonegs.df.VCAM.Conserv), digits = 2)
round(cor(S.nonegs.df.VCAM.SelfTrans), digits = 2)
round(cor(S.nonegs.df.VCAM.SelfEnh), digits = 2)
round(cor(S.nonegs.df.VCAM.OpenTCh), digits = 2)
round(cor(S.nonegs.df.VCAM.Conserv), digits = 2)
round(cor(nonegs.df.VCAM.SelfTrans), digits = 2)
round(cor(nonegs.df.VCAM.SelfEnh), digits = 2)
round(cor(nonegs.df.VCAM.OpenTCh), digits = 2)
round(cor(nonegs.df.VCAM.Conserv), digits = 2)





library(Hmisc)

cormat.V.nonegs.df.VCAM.achi <- rcorr(as.matrix(V.nonegs.df.VCAM.achi))

write.csv(cormat[["r"]], "cormat.V.nonegs.df.VCAM.achi.csv")

sink(file='VCAM.PVQR.cormatrix.csv')
rcorr(as.matrix(df.VCAM.PVQR))
sink()

# Gives significance

rcorr(as.matrix(V.nonegs.df.VCAM.benc))

#Good code to know!
write.csv(cormat[["r"]], "cormatvcampvqr.csv")
write.csv(cormat[["P"]], "pvalscormat.csv")















## Correlations with PVQ-R


#create PVQR sum scores
A1.5miced <- read.csv("A1.5miced.csv")


attach(A1.5miced)

PVQR.SelfTrans <- 
  PVQR.unin1 + PVQR.unin2 + PVQR.unin3 +
  PVQR.unic1 + PVQR.unic2 + PVQR.unic3 +
  PVQR.unit1 + PVQR.unit2 + PVQR.unit3 +
  PVQR.benc1 + PVQR.benc2 + PVQR.benc3 +
  PVQR.bend1 + PVQR.bend2 + PVQR.bend3

PVQR.SelfEnh <- 
  PVQR.achi1 + PVQR.achi2 + PVQR.achi3 +
  PVQR.powd1 + PVQR.powd2 + PVQR.powd3 +
  PVQR.powr1 + PVQR.powr2 + PVQR.powr3

PVQR.OpenTCh <- 
  PVQR.sdt1 + PVQR.sdt2 + PVQR.sdt3 +
  PVQR.sda1 + PVQR.sda2 + PVQR.sda3 +
  PVQR.stim1 + PVQR.stim2 + PVQR.stim3 +
  PVQR.hedo1 + PVQR.hedo2 + PVQR.hedo3

PVQR.Conserv <- 
  PVQR.secp1 + PVQR.secp2 + PVQR.secp3 +
  PVQR.secs1 + PVQR.secs2 + PVQR.secs3 +
  PVQR.trad1 + PVQR.trad2 + PVQR.trad3 +
  PVQR.conr1 + PVQR.conr2 + PVQR.conr3 +
  PVQR.coni1 + PVQR.coni2 + PVQR.coni3


PVQR.sum.Unin <- PVQR.unin1 + PVQR.unin2 + PVQR.unin3
PVQR.sum.Unic <- PVQR.unic1 + PVQR.unic2 + PVQR.unic3
PVQR.sum.Unit <- PVQR.unit1 + PVQR.unit2 + PVQR.unit3
PVQR.sum.Benc <- PVQR.benc1 + PVQR.benc2 + PVQR.benc3
PVQR.sum.Bend <- PVQR.bend1 + PVQR.bend2 + PVQR.bend3

PVQR.sum.Achi <- PVQR.achi1 + PVQR.achi2 + PVQR.achi3
PVQR.sum.Powd <- PVQR.powd1 + PVQR.powd2 + PVQR.powd3
PVQR.sum.Powr <- PVQR.powr1 + PVQR.powr2 + PVQR.powr3

PVQR.sum.Sdt <-  PVQR.sdt1 + PVQR.sdt2 + PVQR.sdt3
PVQR.sum.Sda <-  PVQR.sda1 + PVQR.sda2 + PVQR.sda3
PVQR.sum.Stim <-  PVQR.stim1 + PVQR.stim2 + PVQR.stim3
PVQR.sum.Hedo <-  PVQR.hedo1 + PVQR.hedo2 + PVQR.hedo3

PVQR.sum.Secp <- PVQR.secp1 + PVQR.secp2 + PVQR.secp3
PVQR.sum.Secs <- PVQR.secs1 + PVQR.secs2 + PVQR.secs3
PVQR.sum.Trad <- PVQR.trad1 + PVQR.trad2 + PVQR.trad3
PVQR.sum.Conr <- PVQR.conr1 + PVQR.conr2 + PVQR.conr3
PVQR.sum.Coni <- PVQR.coni1 + PVQR.coni2 + PVQR.coni3

# other values

PVQR.sum.Face <-  PVQR.face1 + PVQR.face2 + PVQR.face3
PVQR.sum.Humi <-  PVQR.humi1 + PVQR.humi2 + PVQR.humi3



cor.test(VCAM.achi, PVQR.sum.Achi)
cor.test(VCAM.benc, PVQR.sum.Benc)
cor.test(VCAM.bend, PVQR.sum.Bend)
cor.test(VCAM.coni, PVQR.sum.Coni)
cor.test(VCAM.conr, PVQR.sum.Conr)
cor.test(VCAM.face, PVQR.sum.Face)
cor.test(VCAM.hedo, PVQR.sum.Hedo)
cor.test(VCAM.humi, PVQR.sum.Humi)
cor.test(VCAM.powd, PVQR.sum.Powd)
cor.test(VCAM.powr, PVQR.sum.Powr)
cor.test(VCAM.sda, PVQR.sum.Sda)
cor.test(VCAM.sdt, PVQR.sum.Sdt)
cor.test(VCAM.secp, PVQR.sum.Secp)
cor.test(VCAM.secs, PVQR.sum.Secs)
cor.test(VCAM.stim, PVQR.sum.Stim)
cor.test(VCAM.trad, PVQR.sum.Trad)
cor.test(VCAM.unic, PVQR.sum.Unic)
cor.test(VCAM.unin, PVQR.sum.Unin)
cor.test(VCAM.unit, PVQR.sum.Unit)


## 

df.A1.5efa <- data.frame(PVQR.sum.Achi, 
                         PVQR.sum.Benc,
                         PVQR.sum.Bend,
                         PVQR.sum.Coni,
                         PVQR.sum.Conr,
                         PVQR.sum.Face,
                         PVQR.sum.Hedo,
                         PVQR.sum.Humi,
                         PVQR.sum.Powd,
                         PVQR.sum.Powr,
                         PVQR.sum.Sda,
                         PVQR.sum.Sdt,
                         PVQR.sum.Secp,
                         PVQR.sum.Secs,
                         PVQR.sum.Stim,
                         PVQR.sum.Trad,
                         PVQR.sum.Unic,
                         PVQR.sum.Unit,
                         PVQR.sum.Unin,
                         VCAM.achi,
                         VCAM.bend,
                         VCAM.benc,
                         VCAM.coni,
                         VCAM.conr,
                         VCAM.face,
                         VCAM.hedo,
                         VCAM.humi,
                         VCAM.powd,
                         VCAM.powr,
                         VCAM.sda,
                         VCAM.sdt,
                         VCAM.secp,
                         VCAM.secs,
                         VCAM.stim,
                         VCAM.trad,
                         VCAM.unic,
                         VCAM.unin,
                         VCAM.unit)



circlevaluescombined <- fa(df.A1.5efa, nfactors=2, rotate = "varimax", fm="ml")

parallelcombined <- fa.parallel(df.A1.5efa, fm="pa", fa="fa")

circlevaluescombined.pa.loadings <- circlevaluescombined.pa$loadings

sink(file='efa.circlevaluescombined.txt')
loadings(circlevaluescombined)
sink()


load <- circlevaluescombined.pa$loadings

plot(load)





### Comparative EFA Violations Satisfactions PVQR

loaddiff <- read.csv("loadingdifferences.csv")

hist(loaddiff$..differences, main = "Difference in Factor Loadings from PVQ-R (Violations and Satisfactions)", col="white", border="black", xlab = "Average loading of VCAM Scale - Average Loading of PVQ-R Scale", breaks = 5)

Violloaddiff <- loaddiff[c(1:19, 39:57) ,]

Satisloaddiff <- loaddiff[c(20:38, 58:76) ,]

hist(Violloaddiff, main = "Difference in Factor Loadings between Violation scales and PVQ-R", col="white", border="black", xlab = "Average loading of Violation Scale - Average Loading of PVQ-R Scale", breaks = 5)

hist(Satisloaddiff, main = "Difference in Factor Loadings between Satisfaction scales and PVQ-R", col="white", border="black", xlab = "Average loading of Satisfaction Scale - Average Loading of PVQ-R Scale", breaks = 5)






# Alpha reliabilities of PVQ-R 


# 19 PVQR Scales sum scores (10 items each)

attach(A1.5miced)

PVQR.sdt <- PVQR.sdt1 + PVQR.sdt2 + PVQR.sdt3

PVQR.sda <- PVQR.sda1 + PVQR.sda2 + PVQR.sda3

PVQR.stim <- PVQR.stim1 + PVQR.stim2 + PVQR.stim3 

PVQR.hedo <- PVQR.hedo1 + PVQR.hedo2 + PVQR.hedo3 

PVQR.achi <- PVQR.achi1 + PVQR.achi2 + PVQR.achi3

PVQR.powd <- PVQR.powd1 + PVQR.powd2 + PVQR.powd3

PVQR.powr <- PVQR.powr1 + PVQR.powr2 + PVQR.powr3

PVQR.face <- PVQR.face1 + PVQR.face2 + PVQR.face3

PVQR.secp <- PVQR.secp1 + PVQR.secp2 + PVQR.secp3

PVQR.secs <- PVQR.secs1 + PVQR.secs2 + PVQR.secs3

PVQR.trad <- PVQR.trad1 + PVQR.trad2 + PVQR.trad3

PVQR.conr <- PVQR.conr1 + PVQR.conr2 + PVQR.conr3

PVQR.coni <- PVQR.coni1 + PVQR.coni2 + PVQR.coni3

PVQR.humi <- PVQR.humi1 + PVQR.humi2 + PVQR.humi3

PVQR.benc <- PVQR.benc1 + PVQR.benc2 + PVQR.benc3

PVQR.bend <- PVQR.bend1 + PVQR.bend2 + PVQR.bend3

PVQR.unic <- PVQR.unic1 + PVQR.unic2 + PVQR.unic3

PVQR.unin <- PVQR.unin1 + PVQR.unin2 + PVQR.unin3

PVQR.unit <- PVQR.unit1 + PVQR.unit2 + PVQR.unit3


#PVQR item sets for each scale


df.PVQR.sdt <- data.frame(PVQR.sdt1, PVQR.sdt2, PVQR.sdt3)

df.PVQR.sda <- data.frame(PVQR.sda1, PVQR.sda2, PVQR.sda3)

df.PVQR.stim <- data.frame(PVQR.stim1, PVQR.stim2, PVQR.stim3)

df.PVQR.hedo <- data.frame(PVQR.hedo1, PVQR.hedo2, PVQR.hedo3)

df.PVQR.achi <- data.frame(PVQR.achi1, PVQR.achi2, PVQR.achi3)

df.PVQR.powd <- data.frame(PVQR.powd1, PVQR.powd2, PVQR.powd3)

df.PVQR.powr <- data.frame(PVQR.powr1, PVQR.powr2, PVQR.powr3)

df.PVQR.face <- data.frame(PVQR.face1, PVQR.face2, PVQR.face3)

df.PVQR.secp <- data.frame(PVQR.secp1, PVQR.secp2, PVQR.secp3)

df.PVQR.secs <- data.frame(PVQR.secs1, PVQR.secs2, PVQR.secs3)

df.PVQR.trad <- data.frame(PVQR.trad1, PVQR.trad2, PVQR.trad3)

df.PVQR.conr <- data.frame(PVQR.conr1, PVQR.conr2, PVQR.conr3)

df.PVQR.coni <- data.frame(PVQR.coni1, PVQR.coni2, PVQR.coni3)

df.PVQR.humi <- data.frame(PVQR.humi1, PVQR.humi2, PVQR.humi3)

df.PVQR.benc <- data.frame(PVQR.benc1, PVQR.benc2, PVQR.benc3)

df.PVQR.bend <- data.frame(PVQR.bend1, PVQR.bend2, PVQR.bend3)

df.PVQR.unic <- data.frame(PVQR.unic1, PVQR.unic2, PVQR.unic3)

df.PVQR.unin <- data.frame(PVQR.unin1, PVQR.unin2, PVQR.unin3)

df.PVQR.unit <- data.frame(PVQR.unit1, PVQR.unit2, PVQR.unit3)

# AIC of each scale

item_intercor(df.PVQR.achi)
item_intercor(df.PVQR.benc)
item_intercor(df.PVQR.bend)
item_intercor(df.PVQR.coni)
item_intercor(df.PVQR.conr)
item_intercor(df.PVQR.face)
item_intercor(df.PVQR.hedo)
item_intercor(df.PVQR.humi)
item_intercor(df.PVQR.powd)
item_intercor(df.PVQR.powr)
item_intercor(df.PVQR.sda)
item_intercor(df.PVQR.sdt)
item_intercor(df.PVQR.secp)
item_intercor(df.PVQR.secs)
item_intercor(df.PVQR.stim)
item_intercor(df.PVQR.trad)
item_intercor(df.PVQR.unic)
item_intercor(df.PVQR.unin)
item_intercor(df.PVQR.unit)


sink(file='PVQRAICs.txt')
item_intercor(df.PVQR.achi)
item_intercor(df.PVQR.benc)
item_intercor(df.PVQR.bend)
item_intercor(df.PVQR.coni)
item_intercor(df.PVQR.conr)
item_intercor(df.PVQR.face)
item_intercor(df.PVQR.hedo)
item_intercor(df.PVQR.humi)
item_intercor(df.PVQR.powd)
item_intercor(df.PVQR.powr)
item_intercor(df.PVQR.sda)
item_intercor(df.PVQR.sdt)
item_intercor(df.PVQR.secp)
item_intercor(df.PVQR.secs)
item_intercor(df.PVQR.stim)
item_intercor(df.PVQR.trad)
item_intercor(df.PVQR.unic)
item_intercor(df.PVQR.unin)
item_intercor(df.PVQR.unit)
sink()

#reliabilities

summary(alpha(df.PVQR.achi))
summary(alpha(df.PVQR.benc))
summary(alpha(df.PVQR.bend))
summary(alpha(df.PVQR.coni))
summary(alpha(df.PVQR.conr))
summary(alpha(df.PVQR.face))
summary(alpha(df.PVQR.hedo))
summary(alpha(df.PVQR.humi))
summary(alpha(df.PVQR.powd))
summary(alpha(df.PVQR.powr))
summary(alpha(df.PVQR.sda))
summary(alpha(df.PVQR.sdt))
summary(alpha(df.PVQR.secp))
summary(alpha(df.PVQR.secs))
summary(alpha(df.PVQR.stim))
summary(alpha(df.PVQR.trad))
summary(alpha(df.PVQR.unic))
summary(alpha(df.PVQR.unin))
summary(alpha(df.PVQR.unit))




mean(
  item_intercor(df.PVQR.achi),
  item_intercor(df.PVQR.benc),
  item_intercor(df.PVQR.bend),
  item_intercor(df.PVQR.coni),
  item_intercor(df.PVQR.conr),
  item_intercor(df.PVQR.face),
  item_intercor(df.PVQR.hedo),
  item_intercor(df.PVQR.humi),
  item_intercor(df.PVQR.powd),
  item_intercor(df.PVQR.powr),
  item_intercor(df.PVQR.sda),
  item_intercor(df.PVQR.sdt),
  item_intercor(df.PVQR.secp),
  item_intercor(df.PVQR.secs),
  item_intercor(df.PVQR.stim),
  item_intercor(df.PVQR.trad),
  item_intercor(df.PVQR.unic),
  item_intercor(df.PVQR.unin),
  item_intercor(df.PVQR.unit))


## dataset for correlation matrix



df.VCAM.PVQR <- data.frame(PVQR.sum.Achi, 
                          PVQR.sum.Benc,
                          PVQR.sum.Bend,
                          PVQR.sum.Coni,
                          PVQR.sum.Conr,
                          PVQR.sum.Face,
                          PVQR.sum.Hedo,
                          PVQR.sum.Humi,
                          PVQR.sum.Powd,
                          PVQR.sum.Powr,
                          PVQR.sum.Sda,
                          PVQR.sum.Sdt,
                          PVQR.sum.Secp,
                          PVQR.sum.Secs,
                          PVQR.sum.Stim,
                          PVQR.sum.Trad,
                          PVQR.sum.Unic,
                          PVQR.sum.Unin,
                          PVQR.sum.Unit,
                          VCAM.achi, 
                          VCAM.benc,
                          VCAM.bend,
                          VCAM.coni,
                          VCAM.conr,
                          VCAM.face,
                          VCAM.hedo,
                          VCAM.humi,
                          VCAM.powd,
                          VCAM.powr,
                          VCAM.sda,
                          VCAM.sdt,
                          VCAM.secp,
                          VCAM.secs,
                          VCAM.stim,
                          VCAM.trad,
                          VCAM.unic,
                          VCAM.unin,
                          VCAM.unit)

library(Hmisc)

cormat <- rcorr(as.matrix(df.VCAM.PVQR))

sink(file='VCAM.PVQR.cormatrix.csv')
rcorr(as.matrix(df.VCAM.PVQR))
sink()

# Gives significance

rcorr(as.matrix(V.nonegs.df.VCAM.benc))

#Good code to know!
write.csv(cormat[["r"]], "cormatvcampvqr.csv")
write.csv(cormat[["P"]], "pvalscormat.csv")


