#####
library(psych)
library(lavaan)
library(semPlot)
library(dplyr)
library(lm.beta)
library(GPArotation)
options(max.print=1000000)



#### set wd ####
setwd("C:/Users/joela/OneDrive/Values Project/1500 Combined Sample")

#Load data
A3A4 <- read.csv("A3A4type2.csv")

table(A3A4$X.1)

#Step 1 Combine Variables into Scales

## PVQR

# Higher order quadrants

attach(A3A4)

PVQR.SelfTrans <- 
  PVQR.unin1 + PVQR.unin2 + PVQR.unin3 +
  PVQR.unic1 + PVQR.unic2 + PVQR.unic3 +
  PVQR.unit1 + PVQR.unit2 + PVQR.unit3 +
  PVQR.benc1 + PVQR.benc2 + PVQR.benc3 +
  PVQR.bend1 + PVQR.bend2 + PVQR.bend3

PVQR.SelfEnh <- 
  PVQR.achi1 + PVQR.achi2 + PVQR.achi3 +
  PVQR.powd1 + PVQR.powd2 + PVQR.powd3 +
  PVQR.powr1 + PVQR.powr2 + PVQR.powr3

PVQR.OpenTCh <- 
  PVQR.sdt1 + PVQR.sdt2 + PVQR.sdt3 +
  PVQR.sda1 + PVQR.sda2 + PVQR.sda3 +
  PVQR.stim1 + PVQR.stim2 + PVQR.stim3 +
  PVQR.hedo1 + PVQR.hedo2 + PVQR.hedo3

PVQR.Conserv <- 
  PVQR.secp1 + PVQR.secp2 + PVQR.secp3 +
  PVQR.secs1 + PVQR.secs2 + PVQR.secs3 +
  PVQR.trad1 + PVQR.trad2 + PVQR.trad3 +
  PVQR.conr1 + PVQR.conr2 + PVQR.conr3 +
  PVQR.coni1 + PVQR.coni2 + PVQR.coni3


## VCAMF (# of violations per value quadrant ^)

# Violations

VCAMF.V.SelfTrans <- 
  VCAMF.V.unin1 + VCAMF.V.unin2 + VCAMF.V.unin3 + VCAMF.V.unin4 + VCAMF.V.unin5 +
  VCAMF.V.unic1 + VCAMF.V.unic2 + VCAMF.V.unic3 + VCAMF.V.unic4 + VCAMF.V.unic5 +
  VCAMF.V.unit1 + VCAMF.V.unit2 + VCAMF.V.unit3 + VCAMF.V.unit4 + VCAMF.V.unit5 +
  VCAMF.V.benc1 + VCAMF.V.benc2 + VCAMF.V.benc3 + VCAMF.V.benc4 + VCAMF.V.benc5 +
  VCAMF.V.bend1 + VCAMF.V.bend2 + VCAMF.V.bend3 + VCAMF.V.bend4 + VCAMF.V.bend5

VCAMF.V.SelfEnh <- 
  VCAMF.V.achi1 + VCAMF.V.achi2 + VCAMF.V.achi3 + VCAMF.V.achi4 + VCAMF.V.achi5 +
  VCAMF.V.powd1 + VCAMF.V.powd2 + VCAMF.V.powd3 + VCAMF.V.powd4 + VCAMF.V.powd5 +
  VCAMF.V.powr1 + VCAMF.V.powr2 + VCAMF.V.powr3 + VCAMF.V.powr4 + VCAMF.V.powr5

VCAMF.V.OpenTCh <- 
  VCAMF.V.sdt1 + VCAMF.V.sdt2 + VCAMF.V.sdt3 + VCAMF.V.sdt4 + VCAMF.V.sdt5 +
  VCAMF.V.sda1 + VCAMF.V.sda2 + VCAMF.V.sda3 + VCAMF.V.sda4 + VCAMF.V.sda5 +
  VCAMF.V.stim1 + VCAMF.V.stim2 + VCAMF.V.stim3 + VCAMF.V.stim4 + VCAMF.V.stim5 +
  VCAMF.V.hedo1 + VCAMF.V.hedo2 + VCAMF.V.hedo3 + VCAMF.V.hedo4 + VCAMF.V.hedo5

VCAMF.V.Conserv <- 
  VCAMF.V.secp1 + VCAMF.V.secp2 + VCAMF.V.secp3 + VCAMF.V.secp4 + VCAMF.V.secp5 +
  VCAMF.V.secs1 + VCAMF.V.secs2 + VCAMF.V.secs3 + VCAMF.V.secs4 + VCAMF.V.secs5 +
  VCAMF.V.trad1 + VCAMF.V.trad2 + VCAMF.V.trad3 + VCAMF.V.trad4 + VCAMF.V.trad5 +
  VCAMF.V.conr1 + VCAMF.V.conr2 + VCAMF.V.conr3 + VCAMF.V.conr4 + VCAMF.V.conr5 +
  VCAMF.V.coni1 + VCAMF.V.coni2 + VCAMF.V.coni3 + VCAMF.V.coni4 + VCAMF.V.coni5

#Satisfactions

VCAMF.S.SelfTrans <- 
  VCAMF.S.unin1 + VCAMF.S.unin2 + VCAMF.S.unin3 + VCAMF.S.unin4 + VCAMF.S.unin5 +
  VCAMF.S.unic1 + VCAMF.S.unic2 + VCAMF.S.unic3 + VCAMF.S.unic4 + VCAMF.S.unic5 +
  VCAMF.S.unit1 + VCAMF.S.unit2 + VCAMF.S.unit3 + VCAMF.S.unit4 + VCAMF.S.unit5 +
  VCAMF.S.benc1 + VCAMF.S.benc2 + VCAMF.S.benc3 + VCAMF.S.benc4 + VCAMF.S.benc5 +
  VCAMF.S.bend1 + VCAMF.S.bend2 + VCAMF.S.bend3 + VCAMF.S.bend4 + VCAMF.S.bend5

VCAMF.S.SelfEnh <- 
  VCAMF.S.achi1 + VCAMF.S.achi2 + VCAMF.S.achi3 + VCAMF.S.achi4 + VCAMF.S.achi5 +
  VCAMF.S.powd1 + VCAMF.S.powd2 + VCAMF.S.powd3 + VCAMF.S.powd4 + VCAMF.S.powd5 +
  VCAMF.S.powr1 + VCAMF.S.powr2 + VCAMF.S.powr3 + VCAMF.S.powr4 + VCAMF.S.powr5

VCAMF.S.OpenTCh <- 
  VCAMF.S.sdt1 + VCAMF.S.sdt2 + VCAMF.S.sdt3 + VCAMF.S.sdt4 + VCAMF.S.sdt5 +
  VCAMF.S.sda1 + VCAMF.S.sda2 + VCAMF.S.sda3 + VCAMF.S.sda4 + VCAMF.S.sda5 +
  VCAMF.S.stim1 + VCAMF.S.stim2 + VCAMF.S.stim3 + VCAMF.S.stim4 + VCAMF.S.stim5 +
  VCAMF.S.hedo1 + VCAMF.S.hedo2 + VCAMF.S.hedo3 + VCAMF.S.hedo4 + VCAMF.S.hedo5

VCAMF.S.Conserv <- 
  VCAMF.S.secp1 + VCAMF.S.secp2 + VCAMF.S.secp3 + VCAMF.S.secp4 + VCAMF.S.secp5 +
  VCAMF.S.secs1 + VCAMF.S.secs2 + VCAMF.S.secs3 + VCAMF.S.secs4 + VCAMF.S.secs5 +
  VCAMF.S.trad1 + VCAMF.S.trad2 + VCAMF.S.trad3 + VCAMF.S.trad4 + VCAMF.S.trad5 +
  VCAMF.S.conr1 + VCAMF.S.conr2 + VCAMF.S.conr3 + VCAMF.S.conr4 + VCAMF.S.conr5 +
  VCAMF.S.coni1 + VCAMF.S.coni2 + VCAMF.S.coni3 + VCAMF.S.coni4 + VCAMF.S.coni5

## DAS Scales

DAS.consen <- 
  DAS.consen1 + DAS.consen2 + DAS.consen3 +
  DAS.consen4 + DAS.consen5 + DAS.consen6 +
  DAS.consen7 + DAS.consen8 + DAS.consen9 +
  DAS.consen10 + DAS.consen11 + DAS.consen12 +
  DAS.consen13

DAS.satis <- 
  DAS.satis1 + DAS.satis2 + DAS.satis3 +
  DAS.satis4 + DAS.satis5 + DAS.satis6 +
  DAS.satis7 + DAS.satis8 + DAS.satis9 +
  DAS.satis10

DAS.cohes <- 
  DAS.cohes1 + DAS.cohes2 + DAS.cohes3 +
  DAS.cohes4 + DAS.cohes5

DAS.affex <- 
  DAS.affex1 + DAS.affex2 + DAS.affex3 +
  DAS.affex4

DAS.adj <-
  DAS.consen1 + DAS.consen2 + DAS.consen3 +
  DAS.consen4 + DAS.consen5 + DAS.consen6 +
  DAS.consen7 + DAS.consen8 + DAS.consen9 +
  DAS.consen10 + DAS.consen11 + DAS.consen12 +
  DAS.consen13 +
  DAS.satis1 + DAS.satis2 + DAS.satis3 +
  DAS.satis4 + DAS.satis5 + DAS.satis6 +
  DAS.satis7 + DAS.satis8 + DAS.satis9 +
  DAS.satis10 +
  DAS.cohes1 + DAS.cohes2 + DAS.cohes3 +
  DAS.cohes4 + DAS.cohes5 +
  DAS.affex1 + DAS.affex2 + DAS.affex3 +
  DAS.affex4

## CCI scales

# positive communication

CCI.partner.collab <- 
  CCI.partner.collab1 + CCI.partner.collab2 +
  CCI.partner.collab4 + CCI.partner.collab4 +
  CCI.partner.collab5 + CCI.partner.collab6 +
  CCI.partner.collab7

CCI.self.collab <- 
  CCI.self.collab1 + CCI.self.collab2 +
  CCI.self.collab4 + CCI.self.collab4 +
  CCI.self.collab5 + CCI.self.collab6 +
  CCI.self.collab7

CCI.poscom <-
  CCI.partner.collab1 + CCI.partner.collab2 +
  CCI.partner.collab4 + CCI.partner.collab4 +
  CCI.partner.collab5 + CCI.partner.collab6 +
  CCI.partner.collab7 +
  CCI.self.collab1 + CCI.self.collab2 +
  CCI.self.collab4 + CCI.self.collab4 +
  CCI.self.collab5 + CCI.self.collab6 +
  CCI.self.collab7

# negative communication

CCI.partner.advers <- 
  CCI.partner.advers1 + CCI.partner.advers2 +
  CCI.partner.advers4 + CCI.partner.advers4 +
  CCI.partner.advers5 + CCI.partner.advers6 +
  CCI.partner.advers7

CCI.self.advers <- 
  CCI.self.advers1 + CCI.self.advers2 +
  CCI.self.advers4 + CCI.self.advers4 +
  CCI.self.advers5 + CCI.self.advers6 +
  CCI.self.advers7

CCI.negcom <-
  CCI.partner.advers1 + CCI.partner.advers2 +
  CCI.partner.advers4 + CCI.partner.advers4 +
  CCI.partner.advers5 + CCI.partner.advers6 +
  CCI.partner.advers7 +
  CCI.self.advers1 + CCI.self.advers2 +
  CCI.self.advers4 + CCI.self.advers4 +
  CCI.self.advers5 + CCI.self.advers6 +
  CCI.self.advers7


## CAC scales

## Absolute values used because 
#  desired change could be more 
#  or less of a behavior

#communication

CAC.com <- 
  abs(CAC.com1) + abs(CAC.com2) + abs(CAC.com3) +
  abs(CAC.com4) + abs(CAC.com5)

# Expectations

CAC.exp <- 
  abs(CAC.exp1) + abs(CAC.exp2)

# Affection

CAC.affec <- 
  abs(CAC.affec1) + abs(CAC.affec2) + abs(CAC.affec3) +
  abs(CAC.affec4)

# Loving Feelings

CAC.lovfeel <- 
  abs(CAC.lovfeel1) + abs(CAC.lovfeel2)

# Sex

CAC.sex <- 
  abs(CAC.sex1) + abs(CAC.sex2) + abs(CAC.sex3)

# Power Struggles

CAC.powstrug <- 
  abs(CAC.powstrug1) + abs(CAC.powstrug2)

# Problem Solving

CAC.probsolv <- 
  abs(CAC.probsolv1) + abs(CAC.probsolv2) + abs(CAC.probsolv3) +
  abs(CAC.probsolv4)

# Finances

CAC.fin <- 
  abs(CAC.fin1) + abs(CAC.fin2) + abs(CAC.fin3) +
  abs(CAC.fin4)

# Values

CAC.val <- 
  abs(CAC.val1) + abs(CAC.val2) + abs(CAC.val3)

# Roles

CAC.roles <- 
  abs(CAC.roles1) + abs(CAC.roles2)

# Children

CAC.child <- 
  abs(CAC.child1) + abs(CAC.child2) + abs(CAC.child3)

# Serious Individual Problems

CAC.indprob <- 
  abs(CAC.indprob1) + abs(CAC.indprob2) + abs(CAC.indprob3) +
  abs(CAC.indprob4) + abs(CAC.indprob5)

# Affairs

CAC.affair <- 
  abs(CAC.affair1) + abs(CAC.affair2)

# Household Management

CAC.housmgmt <- 
  abs(CAC.housmgmt1) + abs(CAC.housmgmt2) + abs(CAC.housmgmt3) +
  abs(CAC.housmgmt4)

# In-Laws / Relatives

CAC.inlaw <- 
  abs(CAC.inlaw1) + abs(CAC.inlaw2) + abs(CAC.inlaw3) +
  abs(CAC.inlaw4)

# Conventionality

CAC.conv <- 
  abs(CAC.conv1) + abs(CAC.conv2)

# Jealousy

CAC.jeal <- 
  abs(CAC.jeal1) + abs(CAC.jeal2)

# Employment

CAC.emp <- 
  abs(CAC.emp1) + abs(CAC.emp2) + abs(CAC.emp3) +
  abs(CAC.emp4)

# Leisure Time

CAC.leisure <- 
  abs(CAC.leisure1) + abs(CAC.leisure2) + abs(CAC.leisure3)

# Alcoholism

CAC.alc <- 
  abs(CAC.alc1) + abs(CAC.alc2)

# Prior-marriage

CAC.priormar <- 
  abs(CAC.priormar1) + abs(CAC.priormar2) + abs(CAC.priormar3)

# Psychosomatic Illnesses

CAC.psysom <- 
  abs(CAC.psysom1) + abs(CAC.psysom2)

# Friends

CAC.frnd <- 
  abs(CAC.frnd1) + abs(CAC.frnd2) + abs(CAC.frnd3)

# Addiction

CAC.addic <- 
  abs(CAC.addic1) + abs(CAC.addic2)

# Personal Habits/Appearance

CAC.appear <- 
  abs(CAC.appear1) + abs(CAC.appear2)

# Physical Abuse

CAC.physabu <- 
  abs(CAC.physabu1) + abs(CAC.physabu2)

# Religion

CAC.relig <- 
  abs(CAC.relig1) + abs(CAC.relig2)

# Health/Physical Handicaps

CAC.health <- 
  abs(CAC.health1) + abs(CAC.health2)

# Incest

CAC.incest <- 
  abs(CAC.incest1) + abs(CAC.incest2)


### Total Desired Change

CAC.deschan <- 
  abs(CAC.com1) + abs(CAC.com2) + abs(CAC.com3) +
  abs(CAC.com4) + abs(CAC.com5) +
  abs(CAC.exp1) + abs(CAC.exp2) +
  abs(CAC.affec1) + abs(CAC.affec2) + abs(CAC.affec3) +
  abs(CAC.affec4) +
  abs(CAC.lovfeel1) + abs(CAC.lovfeel2) +
  abs(CAC.sex1) + abs(CAC.sex2) + abs(CAC.sex3) +
  abs(CAC.powstrug1) + abs(CAC.powstrug2) +
  abs(CAC.probsolv1) + abs(CAC.probsolv2) + abs(CAC.probsolv3) +
  abs(CAC.probsolv4) +
  abs(CAC.fin1) + abs(CAC.fin2) + abs(CAC.fin3) +
  abs(CAC.fin4) +
  abs(CAC.val1) + abs(CAC.val2) + abs(CAC.val3) +
  abs(CAC.roles1) + abs(CAC.roles2) +
  abs(CAC.child1) + abs(CAC.child2) + abs(CAC.child3) +
  abs(CAC.indprob1) + abs(CAC.indprob2) + abs(CAC.indprob3) +
  abs(CAC.indprob4) + abs(CAC.indprob5) +
  abs(CAC.affair1) + abs(CAC.affair2) +
  abs(CAC.housmgmt1) + abs(CAC.housmgmt2) + abs(CAC.housmgmt3) +
  abs(CAC.housmgmt4) +
  abs(CAC.inlaw1) + abs(CAC.inlaw2) + abs(CAC.inlaw3) +
  abs(CAC.inlaw4) +
  abs(CAC.conv1) + abs(CAC.conv2) +
  abs(CAC.jeal1) + abs(CAC.jeal2) +
  abs(CAC.emp1) + abs(CAC.emp2) + abs(CAC.emp3) +
  abs(CAC.emp4) +
  abs(CAC.leisure1) + abs(CAC.leisure2) + abs(CAC.leisure3) +
  abs(CAC.alc1) + abs(CAC.alc2) +
  abs(CAC.priormar1) + abs(CAC.priormar2) + abs(CAC.priormar3) +
  abs(CAC.psysom1) + abs(CAC.psysom2) +
  abs(CAC.frnd1) + abs(CAC.frnd2) + abs(CAC.frnd3) +
  abs(CAC.addic1) + abs(CAC.addic2) +
  abs(CAC.appear1) + abs(CAC.appear2) +
  abs(CAC.physabu1) + abs(CAC.physabu2) +
  abs(CAC.relig1) + abs(CAC.relig2) +
  abs(CAC.health1) + abs(CAC.health2) +
  abs(CAC.incest1) + abs(CAC.incest2)




## RAM Scales

RAM.locus <- 
  RAM.locus.chore + RAM.locus.criticizes +
  RAM.locus.decisnoask + RAM.locus.distant +
  RAM.locus.intolerant + RAM.locus.lesstime +
  RAM.locus.nopayatt + RAM.locus.nosupport

RAM.stable <- 
  RAM.stable.chore + RAM.stable.criticizes +
  RAM.stable.decisnoask + RAM.stable.distant +
  RAM.stable.intolerant + RAM.stable.lesstime +
  RAM.stable.nopayatt + RAM.stable.nosupport

RAM.global <- 
  RAM.global.chore + RAM.global.criticizes +
  RAM.global.decisnoask + RAM.global.distant +
  RAM.global.intolerant + RAM.global.lesstime +
  RAM.global.nopayatt + RAM.global.nosupport

RAM.purpose <- 
  RAM.purpose.chore + RAM.purpose.criticizes +
  RAM.purpose.decisnoask + RAM.purpose.distant +
  RAM.purpose.intolerant + RAM.purpose.lesstime +
  RAM.purpose.nopayatt + RAM.purpose.nosupport

RAM.selfish <- 
  RAM.selfish.chore + RAM.selfish.criticizes +
  RAM.selfish.decisnoask + RAM.selfish.distant +
  RAM.selfish.intolerant + RAM.selfish.lesstime +
  RAM.selfish.nopayatt + RAM.selfish.nosupport

RAM.blame <- 
  RAM.blame.chore + RAM.blame.criticizes +
  RAM.blame.decisnoask + RAM.blame.distant +
  RAM.blame.intolerant + RAM.blame.lesstime +
  RAM.blame.nopayatt + RAM.blame.nosupport

## Total Negative Attributions

RAM.negatts <- 
  RAM.locus.chore + RAM.locus.criticizes +
  RAM.locus.decisnoask + RAM.locus.distant +
  RAM.locus.intolerant + RAM.locus.lesstime +
  RAM.locus.nopayatt + RAM.locus.nosupport +
  RAM.stable.chore + RAM.stable.criticizes +
  RAM.stable.decisnoask + RAM.stable.distant +
  RAM.stable.intolerant + RAM.stable.lesstime +
  RAM.stable.nopayatt + RAM.stable.nosupport +
  RAM.global.chore + RAM.global.criticizes +
  RAM.global.decisnoask + RAM.global.distant +
  RAM.global.intolerant + RAM.global.lesstime +
  RAM.global.nopayatt + RAM.global.nosupport +
  RAM.purpose.chore + RAM.purpose.criticizes +
  RAM.purpose.decisnoask + RAM.purpose.distant +
  RAM.purpose.intolerant + RAM.purpose.lesstime +
  RAM.purpose.nopayatt + RAM.purpose.nosupport +
  RAM.selfish.chore + RAM.selfish.criticizes +
  RAM.selfish.decisnoask + RAM.selfish.distant +
  RAM.selfish.intolerant + RAM.selfish.lesstime +
  RAM.selfish.nopayatt + RAM.selfish.nosupport +
  RAM.blame.chore + RAM.blame.criticizes +
  RAM.blame.decisnoask + RAM.blame.distant +
  RAM.blame.intolerant + RAM.blame.lesstime +
  RAM.blame.nopayatt + RAM.blame.nosupport 


##### Highest value quadrant

## Need to change to factor in % of maximum or else ones with fewer items get screwed

PVQR.VQuads <- data.frame(PVQR.Conserv, PVQR.OpenTCh, PVQR.SelfEnh, PVQR.SelfTrans)

PVQR.TopVal <- colnames(PVQR.VQuads)[max.col(PVQR.VQuads, ties.method = "random")]

table(PVQR.TopVal)

?max.col

## basic math
# Conserv has 15 var max 75
# OpenTCh has 12 var max 60
# selftrans has 15 vars * 5(max) = 75
# SelfEnh has 9 vars * 5(max) = 45

table(PVQR.Conserv)
table(PVQR.SelfTrans)
table(PVQR.OpenTCh)
table(PVQR.SelfEnh)

## Make pomp scores

pomp.Conserv <- PVQR.Conserv/75
pomp.OpenTCh <- PVQR.OpenTCh/60
pomp.SelfTrans <- PVQR.SelfTrans/75
pomp.SelfEnh <- PVQR.SelfEnh/45

pompVCAMF.V.Conserv <- VCAMF.V.Conserv/100
pompVCAMF.V.OpenTCh <- VCAMF.V.OpenTCh/80
pompVCAMF.V.SelfTrans <- VCAMF.V.SelfTrans/100
pompVCAMF.V.SelfEnh <- VCAMF.V.SelfEnh/60

pompVCAMF.S.Conserv <- VCAMF.S.Conserv/100
pompVCAMF.S.OpenTCh <- VCAMF.S.OpenTCh/80
pompVCAMF.S.SelfTrans <- VCAMF.S.SelfTrans/100
pompVCAMF.S.SelfEnh <- VCAMF.S.SelfEnh/60

# pomp score quadrant dataset and top val

min.col <- function(m, ...) max.col(-m, ...)


PVQR.VQuads <- data.frame(pomp.Conserv, pomp.OpenTCh, pomp.SelfEnh, pomp.SelfTrans)

PVQR.TopVal <- colnames(PVQR.VQuads)[max.col(PVQR.VQuads, ties.method = "random")]

PVQR.BottomVal <- colnames(PVQR.VQuads)[min.col(PVQR.VQuads, ties.method = "random")]

table(PVQR.TopVal)

table(PVQR.BottomVal)



?max.col


## If else chain - if PVQR.TopVal == Conserve, new variable = VCAMF.v or .S Convserv

TopVal.SatisFreq=
  ifelse(PVQR.TopVal=="pomp.Conserv", pompVCAMF.S.Conserv,
         ifelse(PVQR.TopVal=="pomp.OpenTCh", pompVCAMF.S.OpenTCh,
                ifelse(PVQR.TopVal=="pomp.SelfEnh", pompVCAMF.S.SelfEnh,  
                       ifelse(PVQR.TopVal=="pomp.SelfTrans", pompVCAMF.S.SelfTrans, 0))))

TopVal.ViolFreq=
  ifelse(PVQR.TopVal=="pomp.Conserv", pompVCAMF.V.Conserv,
         ifelse(PVQR.TopVal=="pomp.OpenTCh", pompVCAMF.V.OpenTCh,
                ifelse(PVQR.TopVal=="pomp.SelfEnh", pompVCAMF.V.SelfEnh,  
                       ifelse(PVQR.TopVal=="pomp.SelfTrans", pompVCAMF.V.SelfTrans, 0))))

TopVal.Check <- data.frame(TopVal.SatisFreq, pomp.Conserv, pompVCAMF.S.Conserv, pomp.OpenTCh, pompVCAMF.S.OpenTCh, pomp.SelfEnh, pompVCAMF.S.SelfEnh, pomp.SelfTrans, pompVCAMF.S.SelfTrans) 

write.csv(TopVal.Check, "TopVal.Check.csv")


#bottom values


BottomVal.SatisFreq=
  ifelse(PVQR.BottomVal=="pomp.Conserv", pompVCAMF.S.Conserv,
         ifelse(PVQR.BottomVal=="pomp.OpenTCh", pompVCAMF.S.OpenTCh,
                ifelse(PVQR.BottomVal=="pomp.SelfEnh", pompVCAMF.S.SelfEnh,  
                       ifelse(PVQR.BottomVal=="pomp.SelfTrans", pompVCAMF.S.SelfTrans, 0))))

BottomVal.ViolFreq=
  ifelse(PVQR.BottomVal=="pomp.Conserv", pompVCAMF.V.Conserv,
         ifelse(PVQR.BottomVal=="pomp.OpenTCh", pompVCAMF.V.OpenTCh,
                ifelse(PVQR.BottomVal=="pomp.SelfEnh", pompVCAMF.V.SelfEnh,  
                       ifelse(PVQR.BottomVal=="pomp.SelfTrans", pompVCAMF.V.SelfTrans, 0))))

BottomVal.Check <- data.frame(BottomVal.SatisFreq, pomp.Conserv, pompVCAMF.S.Conserv, pomp.OpenTCh, pompVCAMF.S.OpenTCh, pomp.SelfEnh, pompVCAMF.S.SelfEnh, pomp.SelfTrans, pompVCAMF.S.SelfTrans) 

write.csv(BottomVal.Check, "BottomVal.Check.csv")

#checked and working well!


## A3 model 2

A3.TopValViols.Adjustment <- (lm(DAS.adj~TopVal.ViolFreq))
summary(lm.beta(A3.TopValViols.Adjustment))

A3.TopValSatis.Adjustment <- (lm(DAS.adj~TopVal.SatisFreq))
summary(lm.beta(A3.TopValSatis.Adjustment))


## A3 model 2 bottom values

A3.BottomValViols.Adjustment <- (lm(DAS.adj~BottomVal.ViolFreq))
summary(lm.beta(A3.BottomValViols.Adjustment))

A3.BottomValSatis.Adjustment <- (lm(DAS.adj~BottomVal.SatisFreq))
summary(lm.beta(A3.BottomValSatis.Adjustment))


## A4 model


A4.RiskyTest <- (lm(DAS.adj~TopVal.ViolFreq+TopVal.SatisFreq+CAC.deschan+RAM.negatts+CCI.negcom+CCI.poscom))
summary(lm.beta(A4.RiskyTest))


## A4 two-step hierarchical

A4.step1 <- (lm(DAS.adj~CAC.deschan+RAM.negatts+CCI.negcom+CCI.poscom))
summary(lm.beta(A4.step1))

A4.step2 <- lm(DAS.adj~TopVal.ViolFreq+TopVal.SatisFreq+CAC.deschan+RAM.negatts+CCI.negcom+CCI.poscom)
summary(A4.step2)

anova(A4.step1, A4.step2)



# Tomorrow finish this and make tables :D
## A3 model 1 (interaction between each PVQR val and each VCAMF scale)
### do regression for each of the 19 to start

# make variable generalizing effect? Not sure how to wrap my mind around that atm

# make specific PVQR, VCAMF.V, and VCAMF.S refined value variables

PVQR.sum.Unin <- PVQR.unin1 + PVQR.unin2 + PVQR.unin3
PVQR.sum.Unic <- PVQR.unic1 + PVQR.unic2 + PVQR.unic3
PVQR.sum.Unit <- PVQR.unit1 + PVQR.unit2 + PVQR.unit3
PVQR.sum.Benc <- PVQR.benc1 + PVQR.benc2 + PVQR.benc3
PVQR.sum.Bend <- PVQR.bend1 + PVQR.bend2 + PVQR.bend3

PVQR.sum.Achi <- PVQR.achi1 + PVQR.achi2 + PVQR.achi3
PVQR.sum.Powd <- PVQR.powd1 + PVQR.powd2 + PVQR.powd3
PVQR.sum.Powr <- PVQR.powr1 + PVQR.powr2 + PVQR.powr3

PVQR.sum.Sdt <-  PVQR.sdt1 + PVQR.sdt2 + PVQR.sdt3
PVQR.sum.Sda <-  PVQR.sda1 + PVQR.sda2 + PVQR.sda3
PVQR.sum.Stim <-  PVQR.stim1 + PVQR.stim2 + PVQR.stim3
PVQR.sum.Hedo <-  PVQR.hedo1 + PVQR.hedo2 + PVQR.hedo3

PVQR.sum.Secp <- PVQR.secp1 + PVQR.secp2 + PVQR.secp3
PVQR.sum.Secs <- PVQR.secs1 + PVQR.secs2 + PVQR.secs3
PVQR.sum.Trad <- PVQR.trad1 + PVQR.trad2 + PVQR.trad3
PVQR.sum.Conr <- PVQR.conr1 + PVQR.conr2 + PVQR.conr3
PVQR.sum.Coni <- PVQR.coni1 + PVQR.coni2 + PVQR.coni3

# other values

PVQR.sum.Face <-  PVQR.face1 + PVQR.face2 + PVQR.face3
PVQR.sum.Humi <-  PVQR.humi1 + PVQR.humi2 + PVQR.humi3


## VCAMF (# of violations per value quadrant ^)

# Violations

VCAMF.V.sum.Unin <- VCAMF.V.unin1 + VCAMF.V.unin2 + VCAMF.V.unin3 + VCAMF.V.unin4 + VCAMF.V.unin5
VCAMF.V.sum.Unic <- VCAMF.V.unic1 + VCAMF.V.unic2 + VCAMF.V.unic3 + VCAMF.V.unic4 + VCAMF.V.unic5
VCAMF.V.sum.Unit <- VCAMF.V.unit1 + VCAMF.V.unit2 + VCAMF.V.unit3 + VCAMF.V.unit4 + VCAMF.V.unit5
VCAMF.V.sum.Benc <- VCAMF.V.benc1 + VCAMF.V.benc2 + VCAMF.V.benc3 + VCAMF.V.benc4 + VCAMF.V.benc5
VCAMF.V.sum.Bend <- VCAMF.V.bend1 + VCAMF.V.bend2 + VCAMF.V.bend3 + VCAMF.V.bend4 + VCAMF.V.bend5

VCAMF.V.sum.Achi <- VCAMF.V.achi1 + VCAMF.V.achi2 + VCAMF.V.achi3 + VCAMF.V.achi4 + VCAMF.V.achi5
VCAMF.V.sum.Powd <- VCAMF.V.powd1 + VCAMF.V.powd2 + VCAMF.V.powd3 + VCAMF.V.powd4 + VCAMF.V.powd5
VCAMF.V.sum.Powr <- VCAMF.V.powr1 + VCAMF.V.powr2 + VCAMF.V.powr3 + VCAMF.V.powr4 + VCAMF.V.powr5

VCAMF.V.sum.Sdt <- VCAMF.V.sdt1 + VCAMF.V.sdt2 + VCAMF.V.sdt3 + VCAMF.V.sdt4 + VCAMF.V.sdt5
VCAMF.V.sum.Sda <- VCAMF.V.sda1 + VCAMF.V.sda2 + VCAMF.V.sda3 + VCAMF.V.sda4 + VCAMF.V.sda5
VCAMF.V.sum.Stim <- VCAMF.V.stim1 + VCAMF.V.stim2 + VCAMF.V.stim3 + VCAMF.V.stim4 + VCAMF.V.stim5
VCAMF.V.sum.Hedo <- VCAMF.V.hedo1 + VCAMF.V.hedo2 + VCAMF.V.hedo3 + VCAMF.V.hedo4 + VCAMF.V.hedo5

VCAMF.V.sum.Secp <- VCAMF.V.secp1 + VCAMF.V.secp2 + VCAMF.V.secp3 + VCAMF.V.secp4 + VCAMF.V.secp5
VCAMF.V.sum.Secs <- VCAMF.V.secs1 + VCAMF.V.secs2 + VCAMF.V.secs3 + VCAMF.V.secs4 + VCAMF.V.secs5
VCAMF.V.sum.Trad <- VCAMF.V.trad1 + VCAMF.V.trad2 + VCAMF.V.trad3 + VCAMF.V.trad4 + VCAMF.V.trad5
VCAMF.V.sum.Conr <- VCAMF.V.conr1 + VCAMF.V.conr2 + VCAMF.V.conr3 + VCAMF.V.conr4 + VCAMF.V.conr5
VCAMF.V.sum.Coni <- VCAMF.V.coni1 + VCAMF.V.coni2 + VCAMF.V.coni3 + VCAMF.V.coni4 + VCAMF.V.coni5

# other values

VCAMF.V.sum.Face <-  VCAMF.V.face1 + VCAMF.V.face2 + VCAMF.V.face3 + VCAMF.V.face4 + VCAMF.V.face5
VCAMF.V.sum.Humi <-  VCAMF.V.humi1 + VCAMF.V.humi2 + VCAMF.V.humi3 + VCAMF.V.humi4 + VCAMF.V.humi5


# Satisfactions

VCAMF.S.sum.Unin <- VCAMF.S.unin1 + VCAMF.S.unin2 + VCAMF.S.unin3 + VCAMF.S.unin4 + VCAMF.S.unin5
VCAMF.S.sum.Unic <- VCAMF.S.unic1 + VCAMF.S.unic2 + VCAMF.S.unic3 + VCAMF.S.unic4 + VCAMF.S.unic5
VCAMF.S.sum.Unit <- VCAMF.S.unit1 + VCAMF.S.unit2 + VCAMF.S.unit3 + VCAMF.S.unit4 + VCAMF.S.unit5
VCAMF.S.sum.Benc <- VCAMF.S.benc1 + VCAMF.S.benc2 + VCAMF.S.benc3 + VCAMF.S.benc4 + VCAMF.S.benc5
VCAMF.S.sum.Bend <- VCAMF.S.bend1 + VCAMF.S.bend2 + VCAMF.S.bend3 + VCAMF.S.bend4 + VCAMF.S.bend5

VCAMF.S.sum.Achi <- VCAMF.S.achi1 + VCAMF.S.achi2 + VCAMF.S.achi3 + VCAMF.S.achi4 + VCAMF.S.achi5
VCAMF.S.sum.Powd <- VCAMF.S.powd1 + VCAMF.S.powd2 + VCAMF.S.powd3 + VCAMF.S.powd4 + VCAMF.S.powd5
VCAMF.S.sum.Powr <- VCAMF.S.powr1 + VCAMF.S.powr2 + VCAMF.S.powr3 + VCAMF.S.powr4 + VCAMF.S.powr5

VCAMF.S.sum.Sdt <- VCAMF.S.sdt1 + VCAMF.S.sdt2 + VCAMF.S.sdt3 + VCAMF.S.sdt4 + VCAMF.S.sdt5
VCAMF.S.sum.Sda <- VCAMF.S.sda1 + VCAMF.S.sda2 + VCAMF.S.sda3 + VCAMF.S.sda4 + VCAMF.S.sda5
VCAMF.S.sum.Stim <- VCAMF.S.stim1 + VCAMF.S.stim2 + VCAMF.S.stim3 + VCAMF.S.stim4 + VCAMF.S.stim5
VCAMF.S.sum.Hedo <- VCAMF.S.hedo1 + VCAMF.S.hedo2 + VCAMF.S.hedo3 + VCAMF.S.hedo4 + VCAMF.S.hedo5

VCAMF.S.sum.Secp <- VCAMF.S.secp1 + VCAMF.S.secp2 + VCAMF.S.secp3 + VCAMF.S.secp4 + VCAMF.S.secp5
VCAMF.S.sum.Secs <- VCAMF.S.secs1 + VCAMF.S.secs2 + VCAMF.S.secs3 + VCAMF.S.secs4 + VCAMF.S.secs5
VCAMF.S.sum.Trad <- VCAMF.S.trad1 + VCAMF.S.trad2 + VCAMF.S.trad3 + VCAMF.S.trad4 + VCAMF.S.trad5
VCAMF.S.sum.Conr <- VCAMF.S.conr1 + VCAMF.S.conr2 + VCAMF.S.conr3 + VCAMF.S.conr4 + VCAMF.S.conr5
VCAMF.S.sum.Coni <- VCAMF.S.coni1 + VCAMF.S.coni2 + VCAMF.S.coni3 + VCAMF.S.coni4 + VCAMF.S.coni5

# other values

VCAMF.S.sum.Face <-  VCAMF.S.face1 + VCAMF.S.face2 + VCAMF.S.face3 + VCAMF.S.face4 + VCAMF.S.face5
VCAMF.S.sum.Humi <-  VCAMF.S.humi1 + VCAMF.S.humi2 + VCAMF.S.humi3 + VCAMF.S.humi4 + VCAMF.S.humi5

# Interactions

A3Achi.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Achi*PVQR.sum.Achi))
summary(lm.beta(A3Achi.ViolFreqxValStr.Adjustment))

A3Benc.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Benc*PVQR.sum.Benc))
summary(lm.beta(A3Benc.ViolFreqxValStr.Adjustment))

A3Bend.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Bend*PVQR.sum.Bend))
summary(lm.beta(A3Bend.ViolFreqxValStr.Adjustment))

A3Coni.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Coni*PVQR.sum.Coni))
summary(lm.beta(A3Coni.ViolFreqxValStr.Adjustment))

A3Conr.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Conr*PVQR.sum.Conr))
summary(lm.beta(A3Conr.ViolFreqxValStr.Adjustment))

A3Face.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Face*PVQR.sum.Face))
summary(lm.beta(A3Face.ViolFreqxValStr.Adjustment))

A3Hedo.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Hedo*PVQR.sum.Hedo))
summary(lm.beta(A3Hedo.ViolFreqxValStr.Adjustment))

A3Humi.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Humi*PVQR.sum.Humi))
summary(lm.beta(A3Humi.ViolFreqxValStr.Adjustment))

A3Powd.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Powd*PVQR.sum.Powd))
summary(lm.beta(A3Powd.ViolFreqxValStr.Adjustment))

A3Powr.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Powr*PVQR.sum.Powr))
summary(lm.beta(A3Powr.ViolFreqxValStr.Adjustment))

A3Sda.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Sda*PVQR.sum.Sda))
summary(lm.beta(A3Sda.ViolFreqxValStr.Adjustment))

A3Sdt.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Sdt*PVQR.sum.Sdt))
summary(lm.beta(A3Sdt.ViolFreqxValStr.Adjustment))

A3Secp.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Secp*PVQR.sum.Secp))
summary(lm.beta(A3Secp.ViolFreqxValStr.Adjustment))

A3Secs.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Secs*PVQR.sum.Secs))
summary(lm.beta(A3Secs.ViolFreqxValStr.Adjustment))

A3Stim.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Stim*PVQR.sum.Stim))
summary(lm.beta(A3Stim.ViolFreqxValStr.Adjustment))

A3Trad.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Trad*PVQR.sum.Trad))
summary(lm.beta(A3Trad.ViolFreqxValStr.Adjustment))

A3Unic.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Unic*PVQR.sum.Unic))
summary(lm.beta(A3Unic.ViolFreqxValStr.Adjustment))

A3Unin.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Unin*PVQR.sum.Unin))
summary(lm.beta(A3Unin.ViolFreqxValStr.Adjustment))

A3Unit.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~VCAMF.V.sum.Unit*PVQR.sum.Unit))
summary(lm.beta(A3Unit.ViolFreqxValStr.Adjustment))

## Satisfactions

A3Achi.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Achi*VCAMF.S.sum.Achi))
summary(lm.beta(A3Achi.SatisFreqxValStr.Adjustment))

A3Benc.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Benc*VCAMF.S.sum.Benc))
summary(lm.beta(A3Benc.SatisFreqxValStr.Adjustment))

A3Bend.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Bend*VCAMF.S.sum.Bend))
summary(lm.beta(A3Bend.SatisFreqxValStr.Adjustment))

A3Coni.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Coni*VCAMF.S.sum.Coni))
summary(lm.beta(A3Coni.SatisFreqxValStr.Adjustment))

A3Conr.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Conr*VCAMF.S.sum.Conr))
summary(lm.beta(A3Conr.SatisFreqxValStr.Adjustment))

A3Face.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Face*VCAMF.S.sum.Face))
summary(lm.beta(A3Face.SatisFreqxValStr.Adjustment))

A3Hedo.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Hedo*VCAMF.S.sum.Hedo))
summary(lm.beta(A3Hedo.SatisFreqxValStr.Adjustment))

A3Humi.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Humi*VCAMF.S.sum.Humi))
summary(lm.beta(A3Humi.SatisFreqxValStr.Adjustment))

A3Powd.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Powd*VCAMF.S.sum.Powd))
summary(lm.beta(A3Powd.SatisFreqxValStr.Adjustment))

A3Powr.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Powr*VCAMF.S.sum.Powr))
summary(lm.beta(A3Powr.SatisFreqxValStr.Adjustment))

A3Sda.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Sda*VCAMF.S.sum.Sda))
summary(lm.beta(A3Sda.SatisFreqxValStr.Adjustment))

A3Sdt.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Sdt*VCAMF.S.sum.Sdt))
summary(lm.beta(A3Sdt.SatisFreqxValStr.Adjustment))

A3Secp.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Secp*VCAMF.S.sum.Secp))
summary(lm.beta(A3Secp.SatisFreqxValStr.Adjustment))

A3Secs.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Secs*VCAMF.S.sum.Secs))
summary(lm.beta(A3Secs.SatisFreqxValStr.Adjustment))

A3Stim.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Stim*VCAMF.S.sum.Stim))
summary(lm.beta(A3Stim.SatisFreqxValStr.Adjustment))

A3Trad.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Trad*VCAMF.S.sum.Trad))
summary(lm.beta(A3Trad.SatisFreqxValStr.Adjustment))

A3Unic.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Unic*VCAMF.S.sum.Unic))
summary(lm.beta(A3Unic.SatisFreqxValStr.Adjustment))

A3Unin.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Unin*VCAMF.S.sum.Unin))
summary(lm.beta(A3Unin.SatisFreqxValStr.Adjustment))

A3Unit.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.sum.Unit*VCAMF.S.sum.Unit))
summary(lm.beta(A3Unit.SatisFreqxValStr.Adjustment))


# Interactions by Quadrant

A3Conserv.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.Conserv*VCAMF.S.Conserv))
summary(lm.beta(A3Conserv.SatisFreqxValStr.Adjustment))

A3OpenTCh.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.OpenTCh*VCAMF.S.OpenTCh))
summary(lm.beta(A3OpenTCh.SatisFreqxValStr.Adjustment))

A3SelfEnh.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.SelfEnh*VCAMF.S.SelfEnh))
summary(lm.beta(A3SelfEnh.SatisFreqxValStr.Adjustment))

A3SelfTrans.SatisFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.SelfTrans*VCAMF.S.SelfTrans))
summary(lm.beta(A3SelfTrans.SatisFreqxValStr.Adjustment))


A3Conserv.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.Conserv*VCAMF.V.Conserv))
summary(lm.beta(A3Conserv.ViolFreqxValStr.Adjustment))

A3OpenTCh.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.OpenTCh*VCAMF.V.OpenTCh))
summary(lm.beta(A3OpenTCh.ViolFreqxValStr.Adjustment))

A3SelfEnh.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.SelfEnh*VCAMF.V.SelfEnh))
summary(lm.beta(A3SelfEnh.ViolFreqxValStr.Adjustment))

A3SelfTrans.ViolFreqxValStr.Adjustment <- (lm(DAS.adj~PVQR.SelfTrans*VCAMF.V.SelfTrans))
summary(lm.beta(A3SelfTrans.ViolFreqxValStr.Adjustment))


# (old) 4 interactions
# Negative Interactions Conformity-Rules, Security-Societal, Tradition
# Positive Interactions Hedonism

library(ggplot2)

?plotSlopes
library(rockchalk)

plotSlopes(A3Conr.ViolFreqxValStr.Adjustment, plotx = "VCAMF.V.sum.Conr", modx = "PVQR.sum.Conr", modxVals = "std.dev.")

#new Oct 2022

plotSlopes(A3SelfEnh.ViolFreqxValStr.Adjustment, plotx = "VCAMF.V.SelfEnh", modx = "PVQR.SelfEnh", modxVals = "std.dev.")


# if you hold ConR more strongly, then more violations will have a more pronounced negative relationship with your marital adjustment
# OTOH, if you hold Hedonism value more strongly, then more violations will have a less pronouncced negative relationship with your marital adjustment

plotSlopes(A3Hedo.ViolFreqxValStr.Adjustment, plotx = "VCAMF.V.sum.Hedo", modx = "PVQR.sum.Hedo", modxVals = "std.dev.")

plotSlopes(A3Unit.SatisFreqxValStr.Adjustment, plotx = "VCAMF.S.sum.Unit", modx = "PVQR.sum.Unit", modxVals = "std.dev.")




## A3b correlations

cor.test(TopVal.ViolFreq, DAS.adj)
cor.test(TopVal.SatisFreq, DAS.adj)
cor.test(BottomVal.ViolFreq, DAS.adj)
cor.test(BottomVal.SatisFreq, DAS.adj)

# Officially the same as the standardized betas


