## Trimming scales w/ poor Convergent / Divergent correlations

library(psych)
library(lavaan)
library(semPlot)
library(dplyr)
library(lm.beta)
library(GPArotation)
options(max.print=1000000)


###########   A5+ = New Analyses

#### set wd ####
setwd("C:/Users/joela/OneDrive/Values Project/1500 Combined Sample")

#Load data
A3A4 <- read.csv("A3A4type2.csv")

#Creating scales (from A3A4 code)

attach(A3A4)

# Creating scales for A4 regressions

## DAS Scales

DAS.consen <- 
  DAS.consen1 + DAS.consen2 + DAS.consen3 +
  DAS.consen4 + DAS.consen5 + DAS.consen6 +
  DAS.consen7 + DAS.consen8 + DAS.consen9 +
  DAS.consen10 + DAS.consen11 + DAS.consen12 +
  DAS.consen13

DAS.satis <- 
  DAS.satis1 + DAS.satis2 + DAS.satis3 +
  DAS.satis4 + DAS.satis5 + DAS.satis6 +
  DAS.satis7 + DAS.satis8 + DAS.satis9 +
  DAS.satis10

DAS.cohes <- 
  DAS.cohes1 + DAS.cohes2 + DAS.cohes3 +
  DAS.cohes4 + DAS.cohes5

DAS.affex <- 
  DAS.affex1 + DAS.affex2 + DAS.affex3 +
  DAS.affex4

DAS.adj <-
  DAS.consen1 + DAS.consen2 + DAS.consen3 +
  DAS.consen4 + DAS.consen5 + DAS.consen6 +
  DAS.consen7 + DAS.consen8 + DAS.consen9 +
  DAS.consen10 + DAS.consen11 + DAS.consen12 +
  DAS.consen13 +
  DAS.satis1 + DAS.satis2 + DAS.satis3 +
  DAS.satis4 + DAS.satis5 + DAS.satis6 +
  DAS.satis7 + DAS.satis8 + DAS.satis9 +
  DAS.satis10 +
  DAS.cohes1 + DAS.cohes2 + DAS.cohes3 +
  DAS.cohes4 + DAS.cohes5 +
  DAS.affex1 + DAS.affex2 + DAS.affex3 +
  DAS.affex4

## CCI scales

# positive communication

CCI.partner.collab <- 
  CCI.partner.collab1 + CCI.partner.collab2 +
  CCI.partner.collab4 + CCI.partner.collab4 +
  CCI.partner.collab5 + CCI.partner.collab6 +
  CCI.partner.collab7

CCI.self.collab <- 
  CCI.self.collab1 + CCI.self.collab2 +
  CCI.self.collab4 + CCI.self.collab4 +
  CCI.self.collab5 + CCI.self.collab6 +
  CCI.self.collab7

CCI.poscom <-
  CCI.partner.collab1 + CCI.partner.collab2 +
  CCI.partner.collab4 + CCI.partner.collab4 +
  CCI.partner.collab5 + CCI.partner.collab6 +
  CCI.partner.collab7 +
  CCI.self.collab1 + CCI.self.collab2 +
  CCI.self.collab4 + CCI.self.collab4 +
  CCI.self.collab5 + CCI.self.collab6 +
  CCI.self.collab7

# negative communication

CCI.partner.advers <- 
  CCI.partner.advers1 + CCI.partner.advers2 +
  CCI.partner.advers4 + CCI.partner.advers4 +
  CCI.partner.advers5 + CCI.partner.advers6 +
  CCI.partner.advers7

CCI.self.advers <- 
  CCI.self.advers1 + CCI.self.advers2 +
  CCI.self.advers4 + CCI.self.advers4 +
  CCI.self.advers5 + CCI.self.advers6 +
  CCI.self.advers7

CCI.negcom <-
  CCI.partner.advers1 + CCI.partner.advers2 +
  CCI.partner.advers4 + CCI.partner.advers4 +
  CCI.partner.advers5 + CCI.partner.advers6 +
  CCI.partner.advers7 +
  CCI.self.advers1 + CCI.self.advers2 +
  CCI.self.advers4 + CCI.self.advers4 +
  CCI.self.advers5 + CCI.self.advers6 +
  CCI.self.advers7


## CAC scales

## Absolute values used because 
#  desired change could be more 
#  or less of a behavior

#communication

CAC.com <- 
  abs(CAC.com1) + abs(CAC.com2) + abs(CAC.com3) +
  abs(CAC.com4) + abs(CAC.com5)

# Expectations

CAC.exp <- 
  abs(CAC.exp1) + abs(CAC.exp2)

# Affection

CAC.affec <- 
  abs(CAC.affec1) + abs(CAC.affec2) + abs(CAC.affec3) +
  abs(CAC.affec4)

# Loving Feelings

CAC.lovfeel <- 
  abs(CAC.lovfeel1) + abs(CAC.lovfeel2)

# Sex

CAC.sex <- 
  abs(CAC.sex1) + abs(CAC.sex2) + abs(CAC.sex3)

# Power Struggles

CAC.powstrug <- 
  abs(CAC.powstrug1) + abs(CAC.powstrug2)

# Problem Solving

CAC.probsolv <- 
  abs(CAC.probsolv1) + abs(CAC.probsolv2) + abs(CAC.probsolv3) +
  abs(CAC.probsolv4)

# Finances

CAC.fin <- 
  abs(CAC.fin1) + abs(CAC.fin2) + abs(CAC.fin3) +
  abs(CAC.fin4)

# Values

CAC.val <- 
  abs(CAC.val1) + abs(CAC.val2) + abs(CAC.val3)

# Roles

CAC.roles <- 
  abs(CAC.roles1) + abs(CAC.roles2)

# Children

CAC.child <- 
  abs(CAC.child1) + abs(CAC.child2) + abs(CAC.child3)

# Serious Individual Problems

CAC.indprob <- 
  abs(CAC.indprob1) + abs(CAC.indprob2) + abs(CAC.indprob3) +
  abs(CAC.indprob4) + abs(CAC.indprob5)

# Affairs

CAC.affair <- 
  abs(CAC.affair1) + abs(CAC.affair2)

# Household Management

CAC.housmgmt <- 
  abs(CAC.housmgmt1) + abs(CAC.housmgmt2) + abs(CAC.housmgmt3) +
  abs(CAC.housmgmt4)

# In-Laws / Relatives

CAC.inlaw <- 
  abs(CAC.inlaw1) + abs(CAC.inlaw2) + abs(CAC.inlaw3) +
  abs(CAC.inlaw4)

# Conventionality

CAC.conv <- 
  abs(CAC.conv1) + abs(CAC.conv2)

# Jealousy

CAC.jeal <- 
  abs(CAC.jeal1) + abs(CAC.jeal2)

# Employment

CAC.emp <- 
  abs(CAC.emp1) + abs(CAC.emp2) + abs(CAC.emp3) +
  abs(CAC.emp4)

# Leisure Time

CAC.leisure <- 
  abs(CAC.leisure1) + abs(CAC.leisure2) + abs(CAC.leisure3)

# Alcoholism

CAC.alc <- 
  abs(CAC.alc1) + abs(CAC.alc2)

# Prior-marriage

CAC.priormar <- 
  abs(CAC.priormar1) + abs(CAC.priormar2) + abs(CAC.priormar3)

# Psychosomatic Illnesses

CAC.psysom <- 
  abs(CAC.psysom1) + abs(CAC.psysom2)

# Friends

CAC.frnd <- 
  abs(CAC.frnd1) + abs(CAC.frnd2) + abs(CAC.frnd3)

# Addiction

CAC.addic <- 
  abs(CAC.addic1) + abs(CAC.addic2)

# Personal Habits/Appearance

CAC.appear <- 
  abs(CAC.appear1) + abs(CAC.appear2)

# Physical Abuse

CAC.physabu <- 
  abs(CAC.physabu1) + abs(CAC.physabu2)

# Religion

CAC.relig <- 
  abs(CAC.relig1) + abs(CAC.relig2)

# Health/Physical Handicaps

CAC.health <- 
  abs(CAC.health1) + abs(CAC.health2)

# Incest

CAC.incest <- 
  abs(CAC.incest1) + abs(CAC.incest2)


### Total Desired Change

CAC.deschan <- 
  abs(CAC.com1) + abs(CAC.com2) + abs(CAC.com3) +
  abs(CAC.com4) + abs(CAC.com5) +
  abs(CAC.exp1) + abs(CAC.exp2) +
  abs(CAC.affec1) + abs(CAC.affec2) + abs(CAC.affec3) +
  abs(CAC.affec4) +
  abs(CAC.lovfeel1) + abs(CAC.lovfeel2) +
  abs(CAC.sex1) + abs(CAC.sex2) + abs(CAC.sex3) +
  abs(CAC.powstrug1) + abs(CAC.powstrug2) +
  abs(CAC.probsolv1) + abs(CAC.probsolv2) + abs(CAC.probsolv3) +
  abs(CAC.probsolv4) +
  abs(CAC.fin1) + abs(CAC.fin2) + abs(CAC.fin3) +
  abs(CAC.fin4) +
  abs(CAC.val1) + abs(CAC.val2) + abs(CAC.val3) +
  abs(CAC.roles1) + abs(CAC.roles2) +
  abs(CAC.child1) + abs(CAC.child2) + abs(CAC.child3) +
  abs(CAC.indprob1) + abs(CAC.indprob2) + abs(CAC.indprob3) +
  abs(CAC.indprob4) + abs(CAC.indprob5) +
  abs(CAC.affair1) + abs(CAC.affair2) +
  abs(CAC.housmgmt1) + abs(CAC.housmgmt2) + abs(CAC.housmgmt3) +
  abs(CAC.housmgmt4) +
  abs(CAC.inlaw1) + abs(CAC.inlaw2) + abs(CAC.inlaw3) +
  abs(CAC.inlaw4) +
  abs(CAC.conv1) + abs(CAC.conv2) +
  abs(CAC.jeal1) + abs(CAC.jeal2) +
  abs(CAC.emp1) + abs(CAC.emp2) + abs(CAC.emp3) +
  abs(CAC.emp4) +
  abs(CAC.leisure1) + abs(CAC.leisure2) + abs(CAC.leisure3) +
  abs(CAC.alc1) + abs(CAC.alc2) +
  abs(CAC.priormar1) + abs(CAC.priormar2) + abs(CAC.priormar3) +
  abs(CAC.psysom1) + abs(CAC.psysom2) +
  abs(CAC.frnd1) + abs(CAC.frnd2) + abs(CAC.frnd3) +
  abs(CAC.addic1) + abs(CAC.addic2) +
  abs(CAC.appear1) + abs(CAC.appear2) +
  abs(CAC.physabu1) + abs(CAC.physabu2) +
  abs(CAC.relig1) + abs(CAC.relig2) +
  abs(CAC.health1) + abs(CAC.health2) +
  abs(CAC.incest1) + abs(CAC.incest2)




## RAM Scales

RAM.locus <- 
  RAM.locus.chore + RAM.locus.criticizes +
  RAM.locus.decisnoask + RAM.locus.distant +
  RAM.locus.intolerant + RAM.locus.lesstime +
  RAM.locus.nopayatt + RAM.locus.nosupport

RAM.stable <- 
  RAM.stable.chore + RAM.stable.criticizes +
  RAM.stable.decisnoask + RAM.stable.distant +
  RAM.stable.intolerant + RAM.stable.lesstime +
  RAM.stable.nopayatt + RAM.stable.nosupport

RAM.global <- 
  RAM.global.chore + RAM.global.criticizes +
  RAM.global.decisnoask + RAM.global.distant +
  RAM.global.intolerant + RAM.global.lesstime +
  RAM.global.nopayatt + RAM.global.nosupport

RAM.purpose <- 
  RAM.purpose.chore + RAM.purpose.criticizes +
  RAM.purpose.decisnoask + RAM.purpose.distant +
  RAM.purpose.intolerant + RAM.purpose.lesstime +
  RAM.purpose.nopayatt + RAM.purpose.nosupport

RAM.selfish <- 
  RAM.selfish.chore + RAM.selfish.criticizes +
  RAM.selfish.decisnoask + RAM.selfish.distant +
  RAM.selfish.intolerant + RAM.selfish.lesstime +
  RAM.selfish.nopayatt + RAM.selfish.nosupport

RAM.blame <- 
  RAM.blame.chore + RAM.blame.criticizes +
  RAM.blame.decisnoask + RAM.blame.distant +
  RAM.blame.intolerant + RAM.blame.lesstime +
  RAM.blame.nopayatt + RAM.blame.nosupport

## Total Negative Attributions

RAM.negatts <- 
  RAM.locus.chore + RAM.locus.criticizes +
  RAM.locus.decisnoask + RAM.locus.distant +
  RAM.locus.intolerant + RAM.locus.lesstime +
  RAM.locus.nopayatt + RAM.locus.nosupport +
  RAM.stable.chore + RAM.stable.criticizes +
  RAM.stable.decisnoask + RAM.stable.distant +
  RAM.stable.intolerant + RAM.stable.lesstime +
  RAM.stable.nopayatt + RAM.stable.nosupport +
  RAM.global.chore + RAM.global.criticizes +
  RAM.global.decisnoask + RAM.global.distant +
  RAM.global.intolerant + RAM.global.lesstime +
  RAM.global.nopayatt + RAM.global.nosupport +
  RAM.purpose.chore + RAM.purpose.criticizes +
  RAM.purpose.decisnoask + RAM.purpose.distant +
  RAM.purpose.intolerant + RAM.purpose.lesstime +
  RAM.purpose.nopayatt + RAM.purpose.nosupport +
  RAM.selfish.chore + RAM.selfish.criticizes +
  RAM.selfish.decisnoask + RAM.selfish.distant +
  RAM.selfish.intolerant + RAM.selfish.lesstime +
  RAM.selfish.nopayatt + RAM.selfish.nosupport +
  RAM.blame.chore + RAM.blame.criticizes +
  RAM.blame.decisnoask + RAM.blame.distant +
  RAM.blame.intolerant + RAM.blame.lesstime +
  RAM.blame.nopayatt + RAM.blame.nosupport 

# Making trimmed totalsats/viols scales

# Violations

TotalViolsTrimmed <- 
  VCAMF.V.unin1 + VCAMF.V.unin2 + VCAMF.V.unin3 + VCAMF.V.unin4 + VCAMF.V.unin5 +
  VCAMF.V.unic1 + VCAMF.V.unic2 + VCAMF.V.unic3 + VCAMF.V.unic4 + VCAMF.V.unic5 +
  VCAMF.V.unit1 + VCAMF.V.unit2 + VCAMF.V.unit3 + VCAMF.V.unit4 + VCAMF.V.unit5 +
  VCAMF.V.benc1 + VCAMF.V.benc2 + VCAMF.V.benc3 + VCAMF.V.benc4 + VCAMF.V.benc5 +
  VCAMF.V.achi1 + VCAMF.V.achi2 + VCAMF.V.achi3 + VCAMF.V.achi4 + VCAMF.V.achi5 +
  VCAMF.V.sda1 + VCAMF.V.sda2 + VCAMF.V.sda3 + VCAMF.V.sda4 + VCAMF.V.sda5 +
  VCAMF.V.stim1 + VCAMF.V.stim2 + VCAMF.V.stim3 + VCAMF.V.stim4 + VCAMF.V.stim5 +
  VCAMF.V.hedo1 + VCAMF.V.hedo2 + VCAMF.V.hedo3 + VCAMF.V.hedo4 + VCAMF.V.hedo5 +
  VCAMF.V.secp1 + VCAMF.V.secp2 + VCAMF.V.secp3 + VCAMF.V.secp4 + VCAMF.V.secp5 +
  VCAMF.V.secs1 + VCAMF.V.secs2 + VCAMF.V.secs3 + VCAMF.V.secs4 + VCAMF.V.secs5 +
  VCAMF.V.trad1 + VCAMF.V.trad2 + VCAMF.V.trad3 + VCAMF.V.trad4 + VCAMF.V.trad5 +
  VCAMF.V.conr1 + VCAMF.V.conr2 + VCAMF.V.conr3 + VCAMF.V.conr4 + VCAMF.V.conr5 +
  VCAMF.V.humi1 + VCAMF.V.humi2 + VCAMF.V.humi3 + VCAMF.V.humi4 + VCAMF.V.humi5 
    
#Satisfactions

TotalSatsTrimmed <- 
  VCAMF.S.unin1 + VCAMF.S.unin2 + VCAMF.S.unin3 + VCAMF.S.unin4 + VCAMF.S.unin5 +
  VCAMF.S.unic1 + VCAMF.S.unic2 + VCAMF.S.unic3 + VCAMF.S.unic4 + VCAMF.S.unic5 +
  VCAMF.S.unit1 + VCAMF.S.unit2 + VCAMF.S.unit3 + VCAMF.S.unit4 + VCAMF.S.unit5 +
  VCAMF.S.benc1 + VCAMF.S.benc2 + VCAMF.S.benc3 + VCAMF.S.benc4 + VCAMF.S.benc5 +
  VCAMF.S.bend1 + VCAMF.S.bend2 + VCAMF.S.bend3 + VCAMF.S.bend4 + VCAMF.S.bend5 +
  VCAMF.S.achi1 + VCAMF.S.achi2 + VCAMF.S.achi3 + VCAMF.S.achi4 + VCAMF.S.achi5 +
  VCAMF.S.powd1 + VCAMF.S.powd2 + VCAMF.S.powd3 + VCAMF.S.powd4 + VCAMF.S.powd5 +
  VCAMF.S.powr1 + VCAMF.S.powr2 + VCAMF.S.powr3 + VCAMF.S.powr4 + VCAMF.S.powr5 +
  VCAMF.S.sdt1 + VCAMF.S.sdt2 + VCAMF.S.sdt3 + VCAMF.S.sdt4 + VCAMF.S.sdt5 +
  VCAMF.S.stim1 + VCAMF.S.stim2 + VCAMF.S.stim3 + VCAMF.S.stim4 + VCAMF.S.stim5 +
  VCAMF.S.hedo1 + VCAMF.S.hedo2 + VCAMF.S.hedo3 + VCAMF.S.hedo4 + VCAMF.S.hedo5 +
  VCAMF.S.secp1 + VCAMF.S.secp2 + VCAMF.S.secp3 + VCAMF.S.secp4 + VCAMF.S.secp5 +
  VCAMF.S.secs1 + VCAMF.S.secs2 + VCAMF.S.secs3 + VCAMF.S.secs4 + VCAMF.S.secs5 +
  VCAMF.S.trad1 + VCAMF.S.trad2 + VCAMF.S.trad3 + VCAMF.S.trad4 + VCAMF.S.trad5 +
  VCAMF.S.conr1 + VCAMF.S.conr2 + VCAMF.S.conr3 + VCAMF.S.conr4 + VCAMF.S.conr5

#Actual Analyses

A3.TrimmedViols.Adjustment <- (lm(DAS.adj~TotalViolsTrimmed))
summary(lm.beta(A3.TrimmedViols.Adjustment))


A3.TrimmedSats.Adjustment <- (lm(DAS.adj~TotalSatsTrimmed))
summary(lm.beta(A3.TrimmedSats.Adjustment))



A4all.step1.trim <- (lm(DAS.adj~CAC.deschan+RAM.negatts+CCI.negcom+CCI.poscom))
summary(lm.beta(A4all.step1.trim))

A4all.step2.trim <- lm(DAS.adj~TotalViolsTrimmed+TotalSatsTrimmed+CAC.deschan+RAM.negatts+CCI.negcom+CCI.poscom)
summary(lm.beta(A4all.step2.trim))

anova(A4all.step1.trim, A4all.step2.trim)